local addonName,addonTable = ...
local DA = LibStub("AceAddon-3.0"):GetAddon("Skillet") -- for DebugAids.lua
--[[
Skillet: A tradeskill window replacement.

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
]]--

local isRetail = WOW_PROJECT_ID == WOW_PROJECT_MAINLINE
local isClassic = WOW_PROJECT_ID == WOW_PROJECT_CLASSIC
local isBCC = WOW_PROJECT_ID == WOW_PROJECT_BURNING_CRUSADE_CLASSIC

local PT = LibStub("LibPeriodicTable-3.1")

local skillColors = {
	["unknown"]		= { r = 1.00, g = 0.00, b = 0.00, level = 5, alttext="???", cstring = "|cffff0000"},
	["optimal"]		= { r = 1.00, g = 0.50, b = 0.25, level = 4, alttext="+++", cstring = "|cffff8040"},
	["medium"]		= { r = 1.00, g = 1.00, b = 0.00, level = 3, alttext="++",  cstring = "|cffffff00"},
	["easy"]		= { r = 0.25, g = 0.75, b = 0.25, level = 2, alttext="+",   cstring = "|cff40c000"},
	["trivial"]		= { r = 0.50, g = 0.50, b = 0.50, level = 1, alttext="",    cstring = "|cff808080"},
	["header"]		= { r = 1.00, g = 0.82, b = 0,    level = 0, alttext="",    cstring = "|cffffc800"},
}

--
-- function InitializeSkillLevels (which loads Skillet.db.global.SkillLevels) is 
-- at the end of this file.
--
-- Skillet-Classic table was scraped from https://tbc.wowhead.com/, Skillet from https://www.wowhead.com/
-- using ScrapeWowhead.js (follow instructions in file)
-- provided and maintained by Matthew Hively, https://github.com/matthewhively
--

--
-- Get TradeSkill Difficulty Levels
--
-- Note: MainFrame.lua uses both inputs, other calls just use itemID.
--   Old MainFrame.lua call: GetTradeSkillLevels((recipe.itemID>0 and recipe.itemID) or -recipe.spellID)
--
function Skillet:GetTradeSkillLevels(itemID, spellID)
	DA.DEBUG(0,"GetTradeSkillLevels("..tostring(itemID)..", "..tostring(spellID)..")")
	local a,b,c,d
	local skillLevels = Skillet.db.global.SkillLevels
	if itemID then 
		if tonumber(itemID) ~= nil and itemID ~= 0 then
			if self.isCraft or self.currentTrade == 7411 then  -- isCraft for Classic and BCC, Enchanting TradeID for retail
				itemID = -itemID
			end
			self.indexTradeSkillLevel = itemID
--
-- If there is an entry in our own table, use it
--
			if skillLevels and skillLevels[itemID] then
				local levels = skillLevels[itemID]
				if type(levels) == 'table' then
					if spellID then
						if isRetail then
							levels = skillLevels[itemID][spellID]
						else
							for spell, strng in pairs(levels) do
								name = GetSpellInfo(spell)
								DA.DEBUG(0,"GetTradeSkillLevels: name= "..tostring(name))
								if name == spellID then
									levels = strng
									break
								end
							end
						end
					end
				end
				DA.DEBUG(0,"GetTradeSkillLevels: levels= "..tostring(levels))
				if levels and type(levels) == 'string' then
					a,b,c,d = string.split("/", levels)
					a = tonumber(a) or 0
					b = tonumber(b) or 0
					c = tonumber(c) or 0
					d = tonumber(d) or 0
					self.sourceTradeSkillLevel = 1
					return a, b, c, d
				end
			end

--
-- The TradeskillInfo addon seems to be more accurate than LibPeriodicTable-3.1
--
			if isRetail and TradeskillInfo then
				local recipeSource = Skillet.db.global.itemRecipeSource[itemID]
				if not recipeSource then
					DA.DEBUG(0,"GetTradeSkillLevels: itemID= "..tostring(itemID)..", recipeSource= "..tostring(recipeSource))
					recipeSource = Skillet.db.global.itemRecipeSource[-itemID]
				end
				if type(recipeSource) == 'table' then
					DA.DEBUG(0,"GetTradeSkillLevels: itemID= "..tostring(itemID)..", recipeSource= "..DA.DUMP1(recipeSource))
					for recipeID in pairs(recipeSource) do
						DA.DEBUG(1,"GetTradeSkillLevels: recipeID= "..tostring(recipeID))
						local TSILevels = TradeskillInfo:GetCombineDifficulty(recipeID)
						if type(TSILevels) == 'table' then
							DA.DEBUG(1,"GetTradeSkillLevels: TSILevels="..DA.DUMP1(TSILevels))
							a = tonumber(TSILevels[1]) or 0
							b = tonumber(TSILevels[2]) or 0
							c = tonumber(TSILevels[3]) or 0
							d = tonumber(TSILevels[4]) or 0
							self.sourceTradeSkillLevel = 2
							return a, b, c, d
						end
					end
				else
					DA.DEBUG(0,"GetTradeSkillLevels: itemID= "..tostring(itemID)..", recipeSource= "..tostring(recipeSource))
				end
			end

--
-- Check LibPeriodicTable
-- Note: The itemID for Enchants is negative
--
			if PT then
				local levels = PT:ItemInSet(itemID,"TradeskillLevels")
				DA.DEBUG(0,"GetTradeSkillLevels (PT): itemID= "..tostring(itemID)..", levels= "..tostring(levels))
				if not levels then
					itemID = -itemID
					levels = PT:ItemInSet(itemID,"TradeskillLevels")
					DA.DEBUG(0,"GetTradeSkillLevels (PT): itemID= "..tostring(itemID)..", levels= "..tostring(levels))
				end
				if levels then
					a,b,c,d = string.split("/",levels)
					a = tonumber(a) or 0
					b = tonumber(b) or 0
					c = tonumber(c) or 0
					d = tonumber(d) or 0
					self.sourceTradeSkillLevel = 3
					return a, b, c, d
				end
			end
		else
			DA.DEBUG(0,"GetTradeSkillLevels: "..tostring(itemID).." is not a number")
			self.sourceTradeSkillLevel = 4
			self.indexTradeSkillLevel = nil
			return 0, 0, 0, 0 
		end
	else
		DA.DEBUG(0,"GetTradeSkillLevels: itemID is missing")
		self.sourceTradeSkillLevel = 4
		self.indexTradeSkillLevel = nil
		return 0, 0, 0, 0 
	end
	if not self.db.global.MissingSkillLevels then
		self.db.global.MissingSkillLevels = {}
	end
	self.db.global.MissingSkillLevels[itemID] = "0/0/0/0"
	self.sourceTradeSkillLevel = 5
	return 0, 0, 0, 0 
end

function Skillet:GetTradeSkillLevelColor(itemID, rank)
	--DA.DEBUG(0,"GetTradeSkillLevelColor("..tostring(itemID)..", "..tostring(rank)")")
	if itemID then
		local orange, yellow, green, gray = self:GetTradeSkillLevels(itemID)
		if rank >= gray then return skillColors["trivial"] end
		if rank >= green then return skillColors["easy"] end
		if rank >= yellow then return skillColors["moderate"] end
		if rank >= orange then return skillColors["optimal"] end
	end
	return skillColors["unknown"]
end

function Skillet:AddTradeSkillLevels(itemID, orange, yellow, green, gray, spellID)
	DA.DEBUG(0,"AddTradeSkillLevels("..tostring(itemID)..", "..tostring(orange)..", "..tostring(yellow)..", "..tostring(green)..", "..tostring(gray)..", "..tostring(spellID)..")")
	local skillLevels = Skillet.db.global.SkillLevels
--
-- We should add some sanity checking
--
	if itemID and spellID then
		if not skillLevels[itemID] then 
			skillLevels[itemID] = {}
		end
		skillLevels[itemID][spellID] = tostring(orange).."/"..tostring(yellow).."/"..tostring(green).."/"..tostring(gray)
	elseif itemID then
		skillLevels[itemID] = tostring(orange).."/"..tostring(yellow).."/"..tostring(green).."/"..tostring(gray)
	end
end

function Skillet:DelTradeSkillLevels(itemID)
	DA.DEBUG(0,"DelTradeSkillLevels("..tostring(itemID)..")")
	local skillLevels = Skillet.db.global.SkillLevels
	if itemID then
--
-- We could add some additional checking
--
		skillLevels[itemID] = nil
	end
end

--
-- Print the TradeSkillLevels(itemID) result including the actual index and the source.
--
-- index will be itemID or if the current profession is Enchanting, -itemID
--
-- source will be:
--    1 if from Skillet.db.global.SkillLevels
--    2 if from TradeskillInfo
--    3 if from LibPeriodicTable
--    4 if itemID was missing or not a number
--    5 if it wasn't found (and was added to Skillet.db.global.MissingSkillLevels)
--
function Skillet:PrintTradeSkillLevels(itemID, spellID)
	--DA.DEBUG(0,"PrintTradeSkillLevels("..tostring(itemID)..", "..tostring(spellID)..")")
	if itemID then
		local orange, yellow, green, gray = self:GetTradeSkillLevels(itemID, spellID)
		DA.CHAT("PrintTradeSkillLevels: itemID= "..tostring(itemID)..", spellID= "..tostring(spellID))
		DA.CHAT("PrintTradeSkillLevels: index= "..tostring(self.indexTradeSkillLevel)..", source= "..tostring(self.sourceTradeSkillLevel))
		DA.CHAT("PrintTradeSkillLevels: levels= "..tostring(orange).."/"..tostring(yellow).."/"..tostring(green).."/"..tostring(gray))
	end
end

--
-- Our own table of skill levels (Skillet.db.global.SkillLevels)
--   1) can be maintained manually
--      To scrape from Wowhead: Follow instructions in ScrapeWowhead.js
--
--   2) can be maintained with an external addon (using AddTradeSkillLevels, DelTradeSkillLevels)
--
-- Each entry is either [itemID] = "orange/yellow/green/gray" or 
--   a table of spellIDs with the same format
--   [itemID] = {[spellID1] = "orange/yellow/green/gray", [spellID2] = "orange/yellow/green/gray"},
--
--   itemID is the item made by the recipe or the recipeID of the Enchant
--   spellID(s) are the numeric recipeID(s) of each recipe that produces the itemID
--   orange is the (numeric) skill level below which recipe is orange
--   yellow is the (numeric) skill level below which the recipe is yellow
--   green  is the (numeric) skill level below which the recipe is green
--   gray   is the (numeric) skill level above which the recipe is gray
--
-- A global table, Skillet.db.global.MissingSkillLevels, is added to when
-- no other entry is found. The format of this table is the same as
-- the table Skillet.db.global.SkillLevels to facilitate adding to this table.
--
-- InitializeSkillLevels is only called if the table does not exist.
--
-- Force refresh with '/skillet initskilllevels'
-- or '/run Skillet:InitializeSkillLevels()'
-- or '/run Skillet.db.global.SkillLevels = nil'
--
function Skillet:InitializeSkillLevels()
	self.db.global.SkillLevels = {
		[0] = "orange/yellow/green/gray",
-- alchemy
[118] = "1/55/75/95",
[858] = "1/85/105/125",
[929] = "1/135/155/175",
[1710] = "1/175/195/215",
[2454] = "1/55/75/95",
[2455] = "1/65/85/105",
[2456] = "1/70/90/110",
[2457] = "1/80/100/120",
[2458] = "1/80/100/120",
[2459] = "1/90/110/130",
[3382] = "1/60/80/100",
[3383] = "1/120/140/160",
[3385] = "1/145/165/185",
[3386] = "1/145/165/185",
[3387] = "1/275/287/300",
[3388] = "1/150/170/190",
[3389] = "1/155/175/195",
[3390] = "1/165/185/205",
[3391] = "1/175/195/215",
[3577] = "1/240/260/280",
[3823] = "1/185/205/225",
[3824] = "1/190/210/230",
[3825] = "1/195/215/235",
[3826] = "1/200/220/240",
[3827] = "1/180/200/220",
[3828] = "1/215/235/255",
[3829] = "1/220/240/260",
[3928] = "1/230/250/270",
[4596] = "1/80/100/120",
[4623] = "1/230/250/270",
[5631] = "1/90/110/130",
[5633] = "1/195/215/235",
[5634] = "1/175/195/215",
[5996] = "1/120/140/160",
[5997] = "1/55/75/95",
[6037] = "1/240/260/280",
[6048] = "1/160/180/200",
[6049] = "1/210/230/250",
[6050] = "1/205/225/245",
[6051] = "1/130/150/170",
[6052] = "1/210/230/250",
[6149] = "1/220/240/260",
[6370] = "1/80/90/100",
[6371] = "1/150/160/170",
[6372] = "1/130/150/170",
[6373] = "1/165/185/205",
[6452] = "1/80/115/150",
[6453] = "1/130/165/200",
[6662] = "1/120/140/160",
[7068] = "1/300/300/300",
[7076] = {[17560] = "1/275/282/290", [17565] = "1/275/282/290"},
[7078] = "1/275/282/290",
[7080] = {[17561] = "1/275/282/290", [17563] = "1/275/282/290"},
[7082] = "1/275/282/290",
[8827] = "1/40/47/55",
[8949] = "1/205/225/245",
[8951] = "1/215/235/255",
[8956] = "1/220/240/260",
[9030] = "1/225/245/265",
[9061] = "1/225/245/265",
[9088] = "1/255/275/295",
[9144] = "1/240/260/280",
[9149] = "1/240/260/280",
[9154] = "1/245/265/285",
[9155] = "1/250/270/290",
[9172] = "1/250/270/290",
[9179] = "1/250/270/290",
[9187] = "1/255/275/295",
[9197] = "1/255/275/295",
[9206] = "1/260/280/300",
[9210] = "1/260/280/300",
[9224] = "1/265/282/300",
[9233] = "1/265/282/300",
[9264] = "1/265/282/300",
[10592] = "1/220/240/260",
[12190] = "1/245/265/285",
[12360] = "1/275/282/290",
[12803] = "1/275/282/290",
[12808] = "1/275/282/290",
[13423] = "1/250/255/260",
[13442] = "1/270/285/300",
[13443] = "1/275/287/300",
[13444] = "1/300/300/300",
[13445] = "1/280/290/300",
[13446] = "1/290/295/300",
[13447] = "1/285/292/300",
[13452] = "1/295/297/300",
[13453] = "275/290/295/300",
[13454] = "1/300/300/300",
[13455] = "1/295/297/300",
[13456] = "1/300/300/300",
[13457] = "1/300/300/300",
[13458] = "1/300/300/300",
[13459] = "1/300/300/300",
[13461] = "1/300/300/300",
[13462] = "1/300/300/300",
[13503] = "1/1/25/50",
[13506] = "1/300/300/300",
[13510] = "1/300/300/300",
[13511] = "1/300/300/300",
[13512] = "1/300/300/300",
[17708] = "1/210/230/250",
[18253] = "1/300/300/300",
[18294] = "1/230/250/270",
[19440] = "1/300/300/300",
[19931] = "1/300/300/300",
[20002] = "1/290/295/300",
[20004] = "1/300/300/300",
[20007] = "1/290/295/300",
[20008] = "1/300/300/300",
[21546] = "1/265/282/300",
[21884] = {[28566] = "1/65/70/75", [28582] = "1/75/75/75"},
[21885] = {[28567] = "1/65/70/75", [28580] = "1/75/75/75"},
[21886] = "1/75/75/75",
[22451] = "1/65/70/75",
[22452] = {[28568] = "1/65/70/75", [28584] = "1/75/75/75"},
[22456] = "1/75/75/75",
[22457] = "1/75/75/75",
[22823] = "1/20/27/35",
[22824] = "1/20/27/35",
[22825] = "1/25/32/40",
[22826] = "1/30/37/45",
[22827] = "1/35/42/50",
[22828] = "1/35/42/50",
[22829] = "1/40/47/55",
[22830] = "1/40/47/55",
[22831] = "1/45/52/60",
[22832] = "1/55/62/70",
[22833] = "1/60/67/75",
[22834] = "1/60/67/75",
[22835] = "1/65/70/75",
[22836] = "1/65/70/75",
[22837] = "1/65/70/75",
[22838] = "1/65/70/75",
[22839] = "1/65/70/75",
[22840] = "1/70/72/75",
[22841] = "1/75/75/75",
[22842] = "1/75/75/75",
[22844] = "1/75/75/75",
[22845] = "1/75/75/75",
[22846] = "1/75/75/75",
[22847] = "1/75/75/75",
[22848] = "1/75/75/75",
[22849] = "1/75/75/75",
[22850] = "1/75/75/75",
[22851] = "1/75/75/75",
[22853] = "1/75/75/75",
[22854] = "1/75/75/75",
[22861] = "1/75/75/75",
[22866] = "1/75/75/75",
[22871] = "1/50/57/65",
[23571] = "1/65/70/75",
[25867] = "1/65/70/75",
[25868] = "1/65/70/75",
[28100] = "1/15/22/30",
[28101] = "1/25/32/40",
[28102] = "1/15/22/30",
[28103] = "1/15/22/30",
[28104] = "1/30/37/45",
[31080] = "1/40/47/55",
[31676] = "1/60/67/75",
[31677] = "1/75/75/75",
[31679] = "1/50/57/65",
[32062] = "1/25/32/40",
[32063] = "1/35/42/50",
[32067] = "1/35/42/50",
[32068] = "1/45/52/60",
[32839] = "1/60/67/75",
[32849] = "1/60/67/75",
[32850] = "1/60/67/75",
[32851] = "1/60/67/75",
[32852] = "1/60/67/75",
[33447] = "1/35/42/50",
[33448] = "1/40/47/55",
[34440] = "1/35/42/50",
[35622] = {[53774] = "1/30/40/50", [53776] = "1/30/40/50"},
[35623] = {[53781] = "1/30/40/50", [53783] = "1/30/40/50"},
[35624] = {[53777] = "1/30/40/50", [53779] = "1/30/40/50"},
[35625] = {[53775] = "1/30/40/50", [53780] = "1/30/40/50"},
[35627] = {[53771] = "1/30/40/50", [53782] = "1/30/40/50"},
[35748] = "1/75/75/75",
[35749] = "1/75/75/75",
[35750] = "1/75/75/75",
[35751] = "1/75/75/75",
[36860] = {[53773] = "1/30/40/50", [53784] = "1/30/40/50"},
[36919] = "1/65/70/75",
[36922] = "1/65/70/75",
[36925] = "1/65/70/75",
[36928] = "1/65/70/75",
[36931] = "1/65/70/75",
[36934] = "1/65/70/75",
[39666] = "1/25/32/40",
[39671] = "1/1/3/5",
[40067] = "1/1/5/10",
[40068] = "1/1/5/10",
[40070] = "1/1/8/15",
[40072] = "1/15/20/25",
[40073] = "1/15/20/25",
[40076] = "1/5/10/15",
[40077] = "1/40/47/55",
[40078] = "1/20/25/30",
[40079] = "1/5/10/15",
[40081] = "1/10/15/20",
[40087] = "1/40/47/55",
[40093] = "1/40/47/55",
[40097] = "1/40/47/55",
[40109] = "1/40/47/55",
[40195] = "1/5/10/15",
[40211] = "1/40/47/55",
[40212] = "1/40/47/55",
[40213] = "1/35/40/45",
[40214] = "1/35/40/45",
[40215] = "1/35/40/45",
[40216] = "1/35/40/45",
[40217] = "1/400/400/400",
[41163] = "1/45/55/65",
[41266] = "1/65/70/75",
[41334] = "1/60/65/70",
[43569] = "1/35/37/40",
[43570] = "1/40/42/45",
[44322] = "1/45/50/55",
[44323] = "1/45/50/55",
[44324] = "1/45/50/55",
[44325] = "1/40/47/55",
[44327] = "1/40/47/55",
[44328] = "1/40/47/55",
[44329] = "1/40/47/55",
[44330] = "1/40/47/55",
[44331] = "1/40/47/55",
[44332] = "1/25/32/40",
[44958] = "1/5/10/15",
[45621] = "1/160/180/200",
[46376] = "1/75/75/75",
[46377] = "1/75/75/75",
[46378] = "1/75/75/75",
[46379] = "1/75/75/75",
[51950] = "1/75/75/75",
[52190] = "1/75/75/75",
[52191] = "1/70/72/75",
[52192] = "1/60/65/70",
[52193] = "1/65/70/75",
[52194] = "1/70/72/75",
[52195] = "1/75/75/75",
[52303] = "1/75/75/75",
[54464] = "1/60/65/70",
[56850] = "1/25/30/35",
[57099] = "1/25/30/35",
[57191] = "1/50/55/60",
[57192] = "1/40/45/50",
[57193] = "1/30/35/40",
[57194] = "1/20/25/30",
[58084] = "1/5/10/15",
[58085] = "1/55/60/65",
[58086] = "1/60/65/70",
[58087] = "1/65/70/75",
[58088] = "1/65/70/75",
[58089] = "1/10/15/20",
[58090] = "1/5/10/15",
[58091] = "1/15/20/25",
[58092] = "1/20/25/30",
[58093] = "1/30/35/40",
[58094] = "1/35/40/45",
[58142] = "1/10/15/20",
[58143] = "1/35/40/45",
[58144] = "1/45/50/55",
[58145] = "1/40/45/50",
[58146] = "1/45/50/55",
[58148] = "1/50/55/60",
[58480] = "1/75/75/75",
[58483] = "1/60/62/65",
[58487] = "1/75/75/75",
[58488] = "1/75/75/75",
[58489] = "1/20/25/30",
[62288] = "1/75/75/75",
[65460] = "1/75/75/75",
[65891] = "1/75/75/75",
[67415] = "1/1/5/10",
[67438] = "1/55/60/65",
[68775] = "1/60/62/65",
[68776] = "1/60/62/65",
[68777] = "1/60/62/65",
[72095] = "1/75/75/75",
[72104] = {[114780] = "1/75/75/75", [130326] = "1/75/75/75"},
[75274] = "1/1/5/10",
[75525] = "1/300/300/300",
[76075] = "1/15/27/40",
[76076] = "1/15/27/40",
[76077] = "1/15/27/40",
[76078] = "1/40/52/65",
[76079] = "1/40/52/65",
[76080] = "1/40/52/65",
[76081] = "1/40/52/65",
[76083] = "1/15/27/40",
[76084] = "1/75/75/75",
[76085] = "1/75/75/75",
[76086] = "1/75/75/75",
[76087] = "1/75/75/75",
[76088] = "1/75/75/75",
[76089] = "1/40/52/65",
[76090] = "1/15/27/40",
[76092] = "1/40/52/65",
[76093] = "1/15/27/40",
[76094] = "1/1/5/10",
[76095] = "1/40/52/65",
[76096] = "1/40/52/65",
[76097] = "1/1/5/10",
[76098] = "1/75/75/75",
[76131] = "1/75/75/75",
[76132] = "1/75/75/75",
[76138] = "1/75/75/75",
[76139] = "1/75/75/75",
[76140] = "1/75/75/75",
[76141] = "1/75/75/75",
[76142] = "1/75/75/75",
[87872] = "1/15/27/40",
[93351] = "1/75/75/75",
[108996] = "1/1/50/100",
[109123] = "1/50/55/60",
[109145] = "1/100/100/100",
[109147] = "1/100/100/100",
[109148] = "1/100/100/100",
[109152] = "1/100/100/100",
[109153] = "1/100/100/100",
[109155] = "1/100/100/100",
[109156] = "1/100/100/100",
[109160] = "1/100/100/100",
[109217] = "1/50/55/60",
[109218] = "1/50/55/60",
[109219] = "1/50/55/60",
[109220] = "1/50/55/60",
[109221] = "1/50/55/60",
[109222] = "1/50/55/60",
[109223] = "1/1/25/50",
[109226] = "1/50/55/60",
[109262] = "1/100/100/100",
[112090] = "1/50/55/60",
[113261] = {[181632] = "1/100/100/100", [181633] = "1/100/100/100", [181634] = "1/100/100/100"},
[113262] = {[181628] = "1/100/100/100", [181635] = "1/100/100/100", [181636] = "1/100/100/100"},
[113263] = {[181625] = "1/100/100/100", [181629] = "1/100/100/100", [181637] = "1/1/3/5"},
[113264] = {[181627] = "1/100/100/100", [181630] = "1/100/100/100", [181631] = "1/100/100/100"},
[115460] = "1/40/47/55",
[116266] = "1/50/55/60",
[116268] = "1/50/55/60",
[116271] = "1/50/55/60",
[116276] = "1/50/55/60",
[116979] = "1/50/75/100",
[116981] = "1/75/87/100",
[118472] = "1/5/7/10",
[118700] = "1/1/50/100",
[118704] = "1/50/55/60",
[118711] = "1/50/55/60",
[122601] = "1/1/3/5",
[122602] = "1/2/3/5",
[122603] = "1/3/4/5",
[122604] = "1/4/4/5",
[124124] = "1/20/50/80",
[127834] = {[188297] = "1/20/30/40", [188299] = "1/40/50/60", [188300] = "1/60/70/80"},
[127835] = {[188301] = "1/20/30/40", [188302] = "1/40/50/60", [188303] = "1/60/70/80"},
[127836] = {[188304] = "1/20/30/40", [188305] = "1/40/50/60", [188306] = "1/60/70/80"},
[127837] = {[188307] = "1/20/30/40", [188308] = "1/40/50/60", [188309] = "1/60/70/80"},
[127838] = {[188310] = "1/20/30/40", [188311] = "1/40/50/60", [188312] = "1/60/70/80"},
[127839] = {[188313] = "1/20/30/40", [188314] = "1/40/50/60", [188315] = "1/60/70/80"},
[127840] = {[188316] = "1/20/30/40", [188317] = "1/40/50/60", [188318] = "1/60/70/80"},
[127841] = {[188319] = "1/20/30/40", [188320] = "1/40/50/60", [188321] = "1/60/70/80"},
[127842] = {[188322] = "1/40/50/60", [188323] = "1/60/70/80", [188324] = "1/80/90/100"},
[127843] = {[188325] = "1/40/50/60", [188326] = "1/60/70/80", [188327] = "1/80/90/100"},
[127844] = {[188328] = "1/40/50/60", [188329] = "1/60/70/80", [188330] = "1/80/90/100"},
[127845] = {[188331] = "1/40/50/60", [188332] = "1/60/70/80", [188333] = "1/80/90/100"},
[127846] = {[188334] = "1/40/50/60", [188335] = "1/60/70/80", [188336] = "1/80/90/100"},
[127847] = {[188337] = "1/60/70/80", [188338] = "1/80/90/100", [188339] = "1/100/100/100"},
[127848] = {[188340] = "1/60/70/80", [188341] = "1/80/90/100", [188342] = "1/100/100/100"},
[127849] = {[188343] = "1/60/70/80", [188344] = "1/80/90/100", [188345] = "1/100/100/100"},
[127850] = {[188346] = "1/60/70/80", [188347] = "1/80/90/100", [188348] = "1/100/100/100"},
[127851] = {[188349] = "1/60/70/80", [188350] = "1/80/90/100", [188351] = "1/100/100/100"},
[136653] = "1/40/50/60",
[137590] = "1/20/50/80",
[137591] = "1/20/50/80",
[137592] = "1/20/50/80",
[137593] = {[213251] = "1/20/50/80", [213252] = "1/20/50/80", [213253] = "1/20/50/80"},
[137594] = "1/20/50/80",
[137599] = "1/20/50/80",
[137600] = "1/20/50/80",
[141323] = {[188800] = "1/20/50/80", [188801] = "1/20/50/80", [188802] = "1/20/50/80"},
[142117] = {[229217] = "1/60/70/80", [229218] = "1/80/90/100", [229220] = "1/100/100/100"},
[151568] = "1/20/50/80",
[151607] = {[247694] = "1/90/95/100", [247695] = "1/90/95/100", [247696] = "1/90/95/100"},
[151608] = {[247619] = "1/80/90/100", [247620] = "1/80/90/100", [247622] = "1/80/90/100"},
[151609] = {[247688] = "1/80/90/100", [247690] = "1/80/90/100", [247691] = "1/80/90/100"},
[152494] = {[252382] = "1/25/37/50", [252383] = "1/50/62/75", [252384] = "1/75/87/100"},
[152495] = {[252385] = "1/25/37/50", [252386] = "1/50/62/75", [252387] = "1/75/87/100"},
[152496] = {[252391] = "1/50/62/75", [252392] = "1/65/82/100", [252393] = "1/85/105/125"},
[152497] = {[252394] = "1/50/62/75", [252395] = "1/65/82/100", [252396] = "1/85/105/125"},
[152503] = {[252400] = "1/50/62/75", [252401] = "1/65/82/100", [252402] = "1/85/105/125"},
[152550] = {[252397] = "1/50/62/75", [252398] = "1/65/82/100", [252399] = "1/85/105/125"},
[152557] = {[252334] = "1/60/72/85", [252335] = "1/75/95/115", [252336] = "1/100/117/135"},
[152559] = {[252344] = "1/60/72/85", [252345] = "1/75/95/115", [252346] = "1/100/117/135"},
[152560] = {[252341] = "1/60/72/85", [252342] = "1/75/95/115", [252343] = "1/100/117/135"},
[152561] = {[252337] = "1/60/72/85", [252339] = "1/75/95/115", [252340] = "1/100/117/135"},
[152578] = "1/30/90/150",
[152580] = {[251306] = "1/30/90/150", [251310] = "1/30/90/150"},
[152581] = {[251311] = "1/30/90/150", [251822] = "1/30/90/150"},
[152582] = "1/30/90/150",
[152615] = {[251646] = "1/40/50/60", [251651] = "1/60/70/80", [251658] = "1/80/90/100"},
[152632] = {[252379] = "1/95/110/125", [252380] = "1/110/130/150", [252381] = "1/150/150/150"},
[152634] = {[252361] = "1/50/62/75", [252362] = "1/80/102/125", [252363] = "1/90/110/130"},
[152636] = {[252376] = "1/95/110/125", [252377] = "1/110/130/150", [252378] = "1/150/150/150"},
[152637] = {[252368] = "1/50/62/75", [252369] = "1/80/102/125", [252370] = "1/90/110/130"},
[152638] = {[252348] = "1/105/115/125", [252349] = "1/140/145/150", [252350] = "1/150/150/150"},
[152639] = {[252351] = "1/105/115/125", [252352] = "1/140/145/150", [252353] = "1/150/150/150"},
[152640] = {[252354] = "1/105/115/125", [252355] = "1/140/145/150", [252356] = "1/150/150/150"},
[152641] = {[252357] = "1/105/115/125", [252358] = "1/140/145/150", [252359] = "1/150/150/150"},
[152668] = "1/90/120/150",
[156631] = "1/150/150/150",
[160322] = "1/30/90/150",
[160325] = "1/30/90/150",
[162460] = "1/1/25/50",
[162461] = "1/1/25/50",
[162519] = {[276975] = "1/150/150/150", [276976] = "1/150/150/150", [276977] = "1/150/150/150"},
[163082] = {[252388] = "1/25/37/50", [252389] = "1/50/62/75", [252390] = "1/75/87/100"},
[163222] = {[279162] = "1/75/100/125", [279163] = "1/95/112/130", [279164] = "1/100/117/135"},
[163223] = {[279159] = "1/75/100/125", [279160] = "1/95/112/130", [279161] = "1/100/117/135"},
[163224] = {[279168] = "1/75/100/125", [279169] = "1/95/112/130", [279170] = "1/100/117/135"},
[163225] = {[279165] = "1/75/100/125", [279166] = "1/95/112/130", [279167] = "1/100/117/135"},
[165721] = "1/95/110/125",
[165744] = "1/95/110/125",
[165851] = "1/30/90/150",
[165926] = "1/150/150/150",
[165927] = "1/150/150/150",
[165928] = "1/150/150/150",
[166270] = {[287447] = "1/50/62/75", [287448] = "1/65/82/100", [287449] = "1/85/105/125"},
[166974] = "1/125/137/150",
[166975] = "1/130/140/150",
[166976] = "1/135/142/150",
[168489] = {[298729] = "1/165/170/175", [298730] = "1/170/172/175", [298731] = "1/175/175/175"},
[168498] = {[298741] = "1/165/170/175", [298742] = "1/170/172/175", [298743] = "1/175/175/175"},
[168499] = {[298747] = "1/165/170/175", [298748] = "1/170/172/175", [298749] = "1/175/175/175"},
[168500] = {[298750] = "1/165/170/175", [298751] = "1/170/172/175", [298752] = "1/175/175/175"},
[168501] = {[298734] = "1/165/170/175", [298735] = "1/170/172/175", [298736] = "1/175/175/175"},
[168506] = {[298744] = "1/165/170/175", [298745] = "1/170/172/175", [298746] = "1/175/175/175"},
[168529] = {[298726] = "1/165/170/175", [298727] = "1/170/172/175", [298728] = "1/175/175/175"},
[168651] = {[298842] = "1/170/172/175", [298843] = "1/175/175/175", [298845] = "1/175/175/175"},
[168652] = {[298846] = "1/170/172/175", [298847] = "1/175/175/175", [298848] = "1/175/175/175"},
[168653] = {[298850] = "1/170/172/175", [298851] = "1/175/175/175", [298852] = "1/175/175/175"},
[168654] = {[298853] = "1/170/172/175", [298854] = "1/175/175/175", [298855] = "1/175/175/175"},
[168656] = {[298862] = "1/175/175/175", [298863] = "1/175/175/175", [298864] = "1/175/175/175"},
[168674] = "1/175/175/175",
[168675] = "1/175/175/175",
[168676] = "1/175/175/175",
[169299] = {[300749] = "1/165/170/175", [300750] = "1/170/172/175", [300751] = "1/175/175/175"},
[169300] = {[300752] = "1/165/170/175", [300753] = "1/170/172/175", [300754] = "1/175/175/175"},
[169451] = {[301310] = "1/165/170/175", [301311] = "1/170/172/175", [301312] = "1/175/175/175"},
[171085] = "1/175/175/175",
[171087] = "1/175/175/175",
[171088] = "1/175/175/175",
[171263] = "1/60/77/95",
[171264] = "1/55/67/80",
[171266] = "1/45/57/70",
[171267] = "1/10/15/20",
[171268] = "1/10/15/20",
[171269] = "1/15/22/30",
[171270] = "1/165/170/175",
[171271] = "1/110/127/145",
[171272] = "1/110/127/145",
[171273] = "1/165/170/175",
[171274] = "1/165/170/175",
[171275] = "1/165/170/175",
[171276] = "1/170/172/175",
[171278] = "1/170/172/175",
[171284] = "1/175/175/175",
[171285] = "1/20/35/50",
[171286] = "1/20/35/50",
[171287] = "1/25/32/40",
[171288] = "1/90/97/105",
[171289] = "1/115/122/130",
[171290] = "1/55/62/70",
[171291] = "1/25/37/50",
[171292] = "1/70/77/85",
[171301] = "1/15/22/30",
[171320] = "1/200/200/200",
[171323] = "1/175/175/175",
[171349] = "1/135/152/170",
[171350] = "1/135/152/170",
[171351] = "1/145/160/175",
[171352] = "1/145/160/175",
[171370] = "1/70/87/105",
[171428] = "1/175/175/175",
[173381] = "1/155/157/160",
[173382] = "1/175/177/180",
[173383] = "1/190/192/195",
[173384] = "1/200/200/200",
[176811] = "1/120/137/155",
[180457] = "1/175/175/175",
[180751] = "1/10/15/20",
[183823] = "1/60/77/95",
[183942] = "1/130/132/135",
[184090] = "1/100/117/135",
[186694] = "1/175/175/175",
[186697] = "1/100/112/125",
[186698] = "1/100/112/125",
[186699] = "1/100/112/125",
[186700] = "1/100/112/125",
[186701] = "1/100/112/125",
-- Invalid recipe: Shadowlands Alchemy (59) - Potion of Hibernal Rest (338190)
-- Invalid recipe: Shadowlands Alchemy (59) - Liquid Sleep (338191)
-- Invalid recipe: Shadowlands Alchemy (59) - Powdered Dreamroot (338192)
-- Invalid recipe: Shadowlands Alchemy (59) - Flask of Measured Discipline (338194)
-- Invalid recipe: Shadowlands Alchemy (59) - Distilled Resolve (338195)
-- Invalid recipe: Shadowlands Alchemy (59) - Pulverized Breezebloom (338196)
-- Invalid recipe: Shadowlands Alchemy (59) - Draught of Grotesque Strength (338198)
-- Invalid recipe: Shadowlands Alchemy (59) - Brutal Oil (338199)
-- Invalid recipe: Shadowlands Alchemy (59) - Crushed Bones (338200)
-- Invalid recipe: Shadowlands Alchemy (59) - Elixir of Humility (338202)
-- Invalid recipe: Shadowlands Alchemy (59) - Refined Submission (338203)
-- Invalid recipe: Shadowlands Alchemy (59) - Bramblethorn Juice (338204)



-- blacksmithing
[2844] = "1/55/75/95",
[2845] = "1/60/80/100",
[2847] = "1/65/85/105",
[2848] = "1/140/155/170",
[2849] = "1/145/160/175",
[2850] = "1/150/165/180",
[2851] = "1/75/95/115",
[2852] = "1/50/70/90",
[2853] = "1/20/40/60",
[2854] = "1/115/127/140",
[2857] = "1/110/130/150",
[2862] = "1/15/35/55",
[2863] = "1/65/72/80",
[2864] = "1/120/140/160",
[2865] = "1/145/160/175",
[2866] = "1/145/160/175",
[2868] = "1/150/165/180",
[2869] = "1/160/175/190",
[2870] = "1/175/190/205",
[2871] = "1/125/132/140",
[3239] = "1/15/35/55",
[3240] = "1/65/72/80",
[3241] = "1/125/132/140",
[3469] = "1/60/80/100",
[3470] = "1/45/65/85",
[3471] = "1/75/95/115",
[3472] = "1/80/100/120",
[3473] = "1/85/105/125",
[3474] = "1/100/120/140",
[3478] = "1/75/87/100",
[3480] = "1/140/155/170",
[3481] = "1/155/170/185",
[3482] = "1/160/175/190",
[3483] = "1/165/180/195",
[3484] = "1/175/190/205",
[3485] = "1/180/195/210",
[3486] = "1/125/137/150",
[3487] = "1/135/155/175",
[3488] = "1/75/95/115",
[3489] = "1/110/130/150",
[3490] = "1/155/170/185",
[3491] = "1/160/175/190",
[3492] = "1/175/190/205",
[3835] = "1/190/202/215",
[3836] = "1/195/207/220",
[3837] = "1/215/227/240",
[3840] = "1/185/197/210",
[3841] = "1/200/212/225",
[3842] = "1/180/192/205",
[3843] = "1/195/207/220",
[3844] = "1/205/217/230",
[3845] = "1/220/232/245",
[3846] = "1/210/222/235",
[3847] = "1/225/237/250",
[3848] = "1/135/150/165",
[3849] = "1/185/197/210",
[3850] = "1/200/212/225",
[3851] = "1/180/192/205",
[3852] = "1/195/207/220",
[3853] = "1/205/217/230",
[3854] = "1/225/237/250",
[3855] = "1/210/222/235",
[3856] = "1/225/237/250",
[5540] = "1/140/155/170",
[5541] = "1/170/185/200",
[6040] = "1/210/222/235",
[6041] = "1/215/227/240",
[6042] = "1/180/195/210",
[6043] = "1/190/202/215",
[6214] = "1/105/125/145",
[6350] = "1/125/140/155",
[6731] = "1/140/160/180",
[7071] = "1/150/152/155",
[7166] = "1/70/90/110",
[7913] = "1/185/197/210",
[7914] = "1/185/197/210",
[7915] = "1/200/212/225",
[7916] = "1/205/217/230",
[7917] = "1/210/222/235",
[7918] = "1/225/235/245",
[7919] = "1/225/235/245",
[7920] = "1/230/240/250",
[7921] = "1/230/240/250",
[7922] = "1/235/245/255",
[7924] = "1/235/245/255",
[7926] = "1/240/250/260",
[7927] = "1/240/250/260",
[7928] = "1/245/255/265",
[7929] = "1/250/260/270",
[7930] = "1/250/260/270",
[7931] = "1/250/260/270",
[7932] = "1/255/265/275",
[7933] = "1/255/265/275",
[7934] = "1/255/265/275",
[7935] = "1/260/270/280",
[7936] = "1/265/275/285",
[7937] = "1/265/275/285",
[7938] = "1/245/255/265",
[7939] = "1/265/275/285",
[7941] = "1/235/247/260",
[7942] = "1/245/257/270",
[7943] = "1/250/262/275",
[7944] = "1/265/277/290",
[7945] = "1/255/267/280",
[7946] = "1/270/282/295",
[7947] = "1/280/290/300",
[7954] = "1/260/272/285",
[7955] = "1/70/90/110",
[7956] = "1/155/170/185",
[7957] = "1/160/175/190",
[7958] = "1/165/180/195",
[7959] = "1/275/287/300",
[7960] = "1/285/292/300",
[7961] = "1/270/282/295",
[7963] = "1/225/237/250",
[7964] = "1/200/205/210",
[7965] = "1/200/205/210",
[7966] = "1/200/205/210",
[7967] = "1/235/245/255",
[7969] = "1/255/265/275",
[9060] = "1/225/237/250",
[9366] = "1/225/235/245",
[10421] = "1/15/35/55",
[10423] = "1/180/192/205",
[11604] = "1/300/300/300",
[11605] = "1/300/300/300",
[11606] = "1/290/295/300",
[11607] = "1/295/297/300",
[11608] = "1/285/292/300",
[12259] = "1/205/217/230",
[12260] = "1/215/227/240",
[12404] = "1/255/257/260",
[12405] = "1/270/280/290",
[12406] = "1/270/280/290",
[12408] = "1/275/285/295",
[12409] = "1/300/300/300",
[12410] = "1/300/300/300",
[12414] = "1/300/300/300",
[12415] = "1/290/295/300",
[12416] = "1/280/290/300",
[12417] = "1/300/300/300",
[12418] = "1/300/300/300",
[12419] = "1/300/300/300",
[12420] = "1/300/300/300",
[12422] = "1/300/300/300",
[12424] = "1/285/292/300",
[12425] = "1/290/295/300",
[12426] = "1/300/300/300",
[12427] = "1/300/300/300",
[12428] = "1/285/292/300",
[12429] = "1/300/300/300",
[12610] = "1/300/300/300",
[12611] = "1/300/300/300",
[12612] = "1/300/300/300",
[12613] = "1/300/300/300",
[12614] = "1/300/300/300",
[12618] = "1/300/300/300",
[12619] = "1/300/300/300",
[12620] = "1/300/300/300",
[12624] = "1/290/295/300",
[12625] = "1/300/300/300",
[12628] = "1/300/300/300",
[12631] = "1/300/300/300",
[12632] = "1/300/300/300",
[12633] = "1/300/300/300",
[12636] = "1/300/300/300",
[12639] = "1/300/300/300",
[12640] = "1/300/300/300",
[12641] = "1/300/300/300",
[12643] = "1/255/257/260",
[12644] = "1/255/257/260",
[12645] = "1/295/297/300",
[12773] = "1/300/300/300",
[12774] = "1/300/300/300",
[12775] = "1/300/300/300",
[12776] = "1/300/300/300",
[12777] = "1/300/300/300",
[12781] = "1/300/300/300",
[12782] = "1/300/300/300",
[12783] = "1/300/300/300",
[12784] = "1/300/300/300",
[12790] = "1/300/300/300",
[12792] = "1/300/300/300",
[12794] = "1/300/300/300",
[12796] = "1/300/300/300",
[12797] = "1/300/300/300",
[12798] = "1/300/300/300",
[15869] = "1/100/110/120",
[15870] = "1/150/160/170",
[15871] = "1/200/210/220",
[15872] = "1/275/280/285",
[16988] = "1/300/300/300",
[16989] = "1/300/300/300",
[17013] = "1/300/300/300",
[17014] = "1/300/300/300",
[17015] = "1/300/300/300",
[17016] = "1/300/300/300",
[17193] = "1/300/300/300",
[17704] = "1/215/227/240",
[18262] = "1/300/300/300",
[19043] = "1/300/300/300",
[19048] = "1/300/300/300",
[19051] = "1/300/300/300",
[19057] = "1/300/300/300",
[19148] = "1/300/300/300",
[19164] = "1/300/300/300",
[19166] = "1/300/300/300",
[19167] = "1/300/300/300",
[19168] = "1/300/300/300",
[19169] = "1/300/300/300",
[19170] = "1/300/300/300",
[19690] = "1/300/300/300",
[19691] = "1/300/300/300",
[19692] = "1/300/300/300",
[19693] = "1/300/300/300",
[19694] = "1/300/300/300",
[19695] = "1/300/300/300",
[20039] = "1/300/300/300",
[20549] = "1/300/300/300",
[20550] = "1/300/300/300",
[20551] = "1/300/300/300",
[22191] = "1/300/300/300",
[22194] = "1/300/300/300",
[22195] = "1/300/300/300",
[22196] = "1/300/300/300",
[22197] = "1/300/300/300",
[22198] = "1/300/300/300",
[22383] = "1/300/300/300",
[22384] = "1/300/300/300",
[22385] = "1/300/300/300",
[22669] = "1/300/300/300",
[22670] = "1/300/300/300",
[22671] = "1/300/300/300",
[22762] = "1/300/300/300",
[22763] = "1/300/300/300",
[22764] = "1/300/300/300",
[23482] = "1/10/20/30",
[23484] = "1/15/25/35",
[23487] = "1/25/35/45",
[23488] = "1/25/35/45",
[23489] = "1/35/45/55",
[23490] = "1/30/40/50",
[23491] = "1/20/30/40",
[23493] = "1/10/20/30",
[23494] = "1/25/35/45",
[23497] = "1/20/30/40",
[23498] = "1/25/35/45",
[23499] = "1/30/40/50",
[23502] = "1/35/45/55",
[23503] = "1/40/50/60",
[23504] = "1/40/50/60",
[23505] = "1/45/55/65",
[23506] = "1/45/55/65",
[23507] = "1/50/60/70",
[23508] = "1/45/55/65",
[23509] = "1/70/72/75",
[23510] = "1/65/67/70",
[23511] = "1/65/67/70",
[23512] = "1/70/72/75",
[23513] = "1/70/72/75",
[23514] = "1/70/72/75",
[23515] = "1/60/65/70",
[23516] = "1/65/67/70",
[23517] = "1/70/72/75",
[23518] = "1/70/72/75",
[23519] = "1/70/72/75",
[23520] = "1/70/72/75",
[23521] = "1/70/72/75",
[23522] = "1/70/72/75",
[23523] = "1/70/72/75",
[23524] = "1/70/72/75",
[23525] = "1/70/72/75",
[23526] = "1/70/72/75",
[23527] = "1/70/72/75",
[23528] = "1/1/5/10",
[23529] = "1/50/55/60",
[23530] = "1/70/72/75",
[23531] = "1/70/72/75",
[23532] = "1/70/72/75",
[23533] = "1/70/72/75",
[23534] = "1/70/72/75",
[23535] = "1/70/72/75",
[23536] = "1/70/72/75",
[23537] = "1/70/72/75",
[23538] = "1/70/72/75",
[23539] = "1/70/72/75",
[23540] = "1/70/72/75",
[23541] = "1/70/72/75",
[23542] = "1/70/72/75",
[23543] = "1/70/72/75",
[23544] = "1/70/72/75",
[23546] = "1/70/72/75",
[23554] = "1/70/72/75",
[23555] = "1/70/72/75",
[23556] = "1/70/72/75",
[23559] = "1/25/30/35",
[23563] = "1/60/65/70",
[23564] = "1/70/72/75",
[23565] = "1/70/72/75",
[23575] = "1/40/45/50",
[23576] = "1/70/72/75",
[25521] = "1/50/55/60",
[28420] = "1/1/5/10",
[28421] = "1/50/55/60",
[28425] = "1/60/65/70",
[28426] = "1/70/72/75",
[28427] = "1/70/72/75",
[28428] = "1/60/65/70",
[28429] = "1/70/72/75",
[28430] = "1/70/72/75",
[28431] = "1/60/65/70",
[28432] = "1/70/72/75",
[28433] = "1/70/72/75",
[28434] = "1/60/65/70",
[28435] = "1/70/72/75",
[28436] = "1/70/72/75",
[28437] = "1/60/65/70",
[28438] = "1/70/72/75",
[28439] = "1/70/72/75",
[28440] = "1/60/65/70",
[28441] = "1/70/72/75",
[28442] = "1/70/72/75",
[28483] = "1/60/65/70",
[28484] = "1/70/72/75",
[28485] = "1/70/72/75",
[30031] = "1/70/72/75",
[30032] = "1/70/72/75",
[30033] = "1/70/72/75",
[30034] = "1/70/72/75",
[30069] = "1/1/3/5",
[30070] = "1/1/3/5",
[30071] = "1/300/300/300",
[30072] = "1/1/3/5",
[30073] = "1/1/3/5",
[30074] = "1/40/50/60",
[30076] = "1/40/50/60",
[30077] = "1/40/50/60",
[30086] = "1/40/50/60",
[30087] = "1/40/50/60",
[30088] = "1/40/50/60",
[30089] = "1/40/50/60",
[30093] = "1/40/50/60",
[31364] = "1/70/72/75",
[31367] = "1/70/72/75",
[31368] = "1/70/72/75",
[31369] = "1/70/72/75",
[31370] = "1/70/72/75",
[31371] = "1/70/72/75",
[32401] = "1/70/72/75",
[32402] = "1/70/72/75",
[32403] = "1/70/72/75",
[32404] = "1/70/72/75",
[32568] = "1/375/375/375",
[32570] = "1/70/72/75",
[32571] = "1/375/375/375",
[32573] = "1/70/72/75",
[32854] = "1/70/72/75",
[33173] = "1/70/72/75",
[33185] = "1/45/50/55",
[33791] = "1/75/95/115",
[34377] = "1/365/365/365",
[34378] = "1/365/365/365",
[34379] = "1/70/72/75",
[34380] = "1/365/365/365",
[39083] = "1/1/3/5",
[39084] = "1/1/5/10",
[39085] = "1/5/10/15",
[39086] = "1/1/5/10",
[39087] = "1/1/3/5",
[39088] = "1/1/3/5",
[40668] = "1/1/3/5",
[40669] = "1/25/30/35",
[40670] = "1/20/25/30",
[40671] = "1/30/35/40",
[40672] = "1/30/35/40",
[40673] = "1/35/40/45",
[40674] = "1/25/30/35",
[40675] = "1/35/40/45",
[40942] = "1/5/10/15",
[40943] = "1/25/30/35",
[40949] = "1/10/15/20",
[40950] = "1/15/20/25",
[40951] = "1/15/20/25",
[40952] = "1/20/25/30",
[40953] = "1/25/30/35",
[40954] = "1/30/35/40",
[40955] = "1/30/35/40",
[40956] = "1/20/25/30",
[40957] = "1/30/35/40",
[40958] = "1/35/40/45",
[40959] = "1/40/45/50",
[41113] = "1/40/45/50",
[41114] = "1/45/50/55",
[41116] = "1/40/45/50",
[41117] = "1/20/25/30",
[41126] = "1/25/30/35",
[41127] = "1/30/35/40",
[41128] = "1/35/40/45",
[41129] = "1/45/50/55",
[41181] = "1/20/25/30",
[41182] = "1/25/30/35",
[41183] = "1/30/35/40",
[41184] = "1/35/40/45",
[41185] = "1/40/45/50",
[41186] = "1/45/50/55",
[41187] = "1/45/50/55",
[41188] = "1/45/50/55",
[41189] = "1/45/50/55",
[41190] = "1/45/50/55",
[41239] = "1/10/15/20",
[41240] = "1/10/15/20",
[41242] = "1/15/20/25",
[41243] = "1/20/25/30",
[41245] = "1/40/45/50",
[41257] = "1/75/75/75",
[41344] = "1/60/70/80",
[41345] = "1/60/70/80",
[41346] = "1/60/70/80",
[41347] = "1/60/70/80",
[41348] = "1/55/65/75",
[41349] = "1/55/65/75",
[41350] = "1/60/70/80",
[41351] = "1/55/65/75",
[41352] = "1/55/65/75",
[41353] = "1/60/70/80",
[41354] = "1/50/55/60",
[41355] = "1/50/55/60",
[41356] = "1/55/65/75",
[41357] = "1/55/65/75",
[41383] = "1/75/75/75",
[41384] = "1/75/75/75",
[41386] = "1/75/75/75",
[41387] = "1/75/75/75",
[41388] = "1/75/75/75",
[41391] = "1/75/75/75",
[41392] = "1/75/75/75",
[41394] = "1/75/75/75",
[41611] = "1/45/50/55",
[41974] = "1/1/3/5",
[41975] = "1/5/10/15",
[41976] = "1/50/55/60",
[42435] = "1/75/75/75",
[42443] = "1/40/45/50",
[42500] = "1/50/55/60",
[42508] = "1/75/75/75",
[42723] = "1/50/55/60",
[42724] = "1/55/65/75",
[42725] = "1/60/70/80",
[42726] = "1/60/70/80",
[42727] = "1/55/65/75",
[42728] = "1/60/70/80",
[42729] = "1/55/65/75",
[42730] = "1/55/65/75",
[43586] = "1/60/70/80",
[43587] = "1/55/65/75",
[43588] = "1/55/65/75",
[43853] = "1/60/65/70",
[43854] = "1/1/3/5",
[43860] = "1/25/30/35",
[43864] = "1/30/35/40",
[43865] = "1/35/40/45",
[43870] = "1/45/50/55",
[43871] = "1/40/45/50",
[44936] = "1/75/75/75",
[45085] = "1/75/75/75",
[45550] = "1/75/75/75",
[45551] = "1/75/75/75",
[45552] = "1/75/75/75",
[45559] = "1/75/75/75",
[45560] = "1/75/75/75",
[45561] = "1/75/75/75",
[47570] = "1/75/75/75",
[47571] = "1/75/75/75",
[47572] = "1/75/75/75",
[47573] = "1/75/75/75",
[47574] = "1/75/75/75",
[47575] = "1/75/75/75",
[47589] = "1/75/75/75",
[47590] = "1/75/75/75",
[47591] = "1/75/75/75",
[47592] = "1/75/75/75",
[47593] = "1/75/75/75",
[47594] = "1/75/75/75",
[49902] = "1/100/100/100",
[49903] = "1/100/100/100",
[49904] = "1/100/100/100",
[49905] = "1/100/100/100",
[49906] = "1/100/100/100",
[49907] = "1/100/100/100",
[54850] = "1/10/12/15",
[54852] = "1/425/425/425",
[54853] = "1/425/425/425",
[54854] = "1/425/425/425",
[54876] = "1/425/425/425",
[55022] = "1/425/425/425",
[55023] = "1/425/425/425",
[55024] = "1/425/425/425",
[55025] = "1/425/425/425",
[55026] = "1/425/425/425",
[55027] = "1/425/425/425",
[55028] = "1/425/425/425",
[55029] = "1/425/425/425",
[55030] = "1/425/425/425",
[55031] = "1/425/425/425",
[55032] = "1/425/425/425",
[55033] = "1/425/425/425",
[55034] = "1/425/425/425",
[55035] = "1/425/425/425",
[55036] = "1/425/425/425",
[55037] = "1/425/425/425",
[55038] = "1/425/425/425",
[55039] = "1/425/425/425",
[55040] = "1/425/425/425",
[55041] = "1/425/425/425",
[55042] = "1/425/425/425",
[55043] = "1/425/425/425",
[55044] = "1/425/425/425",
[55045] = "1/425/425/425",
[55046] = "1/425/425/425",
[55052] = "1/425/425/425",
[55053] = "1/425/425/425",
[55054] = "1/75/75/75",
[55055] = "1/425/425/425",
[55056] = "1/75/75/75",
[55057] = "1/55/60/65",
[55058] = "1/75/75/75",
[55059] = "1/70/72/75",
[55060] = "1/75/75/75",
[55061] = "1/70/72/75",
[55062] = "1/75/75/75",
[55063] = "1/70/72/75",
[55064] = "1/75/75/75",
[55065] = "1/75/75/75",
[55066] = "1/75/75/75",
[55067] = "1/75/75/75",
[55068] = "1/75/75/75",
[55069] = "1/75/75/75",
[55070] = "1/75/75/75",
[55246] = "1/425/425/425",
[65365] = "1/1/3/5",
[67602] = "1/75/75/75",
[67605] = "1/75/75/75",
[69936] = "1/75/75/75",
[69937] = "1/75/75/75",
[69938] = "1/75/75/75",
[69946] = "1/75/75/75",
[69947] = "1/75/75/75",
[69948] = "1/75/75/75",
[70155] = "1/75/75/75",
[70156] = "1/75/75/75",
[70157] = "1/75/75/75",
[70158] = "1/75/75/75",
[70162] = "1/75/75/75",
[70163] = "1/75/75/75",
[70164] = "1/75/75/75",
[70165] = "1/75/75/75",
[71982] = "1/75/75/75",
[71983] = "1/75/75/75",
[71984] = "1/75/75/75",
[71991] = "1/75/75/75",
[71992] = "1/75/75/75",
[71993] = "1/75/75/75",
[75118] = "1/70/72/75",
[75119] = "1/80/82/85",
[75120] = "1/75/75/75",
[75121] = "1/65/67/70",
[75122] = "1/65/67/70",
[75123] = "1/70/72/75",
[75124] = "1/60/62/65",
[75125] = "1/60/62/65",
[75126] = "1/75/75/75",
[75128] = "1/75/75/75",
[75129] = "1/75/75/75",
[75132] = "1/75/75/75",
[75133] = "1/75/75/75",
[75134] = "1/80/82/85",
[75135] = "1/75/75/75",
[75136] = "1/75/75/75",
[82903] = "1/40/57/75",
[82904] = "1/25/50/75",
[82905] = "1/40/57/75",
[82906] = "1/15/45/75",
[82907] = "1/20/47/75",
[82908] = "1/1/38/75",
[82909] = "1/20/47/75",
[82910] = "1/15/45/75",
[82919] = "1/75/75/75",
[82920] = "1/75/75/75",
[82921] = "1/75/75/75",
[82922] = "1/75/75/75",
[82923] = "1/75/75/75",
[82924] = "1/75/75/75",
[82925] = "1/75/75/75",
[82926] = "1/75/75/75",
[82943] = "1/75/75/75",
[82944] = "1/75/75/75",
[82945] = "1/75/75/75",
[82946] = "1/75/75/75",
[82947] = "1/75/75/75",
[82948] = "1/75/75/75",
[82949] = "1/75/75/75",
[82950] = "1/75/75/75",
[82951] = "1/75/75/75",
[82952] = "1/75/75/75",
[82953] = "1/75/75/75",
[82954] = "1/75/75/75",
[82955] = "1/75/75/75",
[82956] = "1/75/75/75",
[82957] = "1/75/75/75",
[82958] = "1/75/75/75",
[82960] = "1/1/3/5",
[82961] = "1/25/50/75",
[82962] = "1/30/52/75",
[82963] = "1/35/55/75",
[82964] = "1/40/57/75",
[82965] = "1/45/60/75",
[82966] = "1/50/62/75",
[82967] = "1/50/62/75",
[82968] = "1/75/75/75",
[82969] = "1/75/75/75",
[82970] = "1/75/75/75",
[82971] = "1/75/75/75",
[82972] = "1/75/75/75",
[82973] = "1/75/75/75",
[82974] = "1/75/75/75",
[82975] = "1/75/75/75",
[82976] = "1/75/75/75",
[82977] = "1/75/75/75",
[82978] = "1/75/75/75",
[82979] = "1/75/75/75",
[82980] = "1/75/75/75",
[86597] = "1/75/75/75",
[86599] = "1/25/32/40",
[87402] = "1/75/75/75",
[87403] = "1/75/75/75",
[87404] = "1/75/75/75",
[87405] = "1/75/75/75",
[87406] = "1/75/75/75",
[87407] = "1/75/75/75",
[90046] = "1/75/75/75",
[93453] = "1/75/75/75",
[93454] = "1/75/75/75",
[93455] = "1/75/75/75",
[93456] = "1/75/75/75",
[93457] = "1/75/75/75",
[93527] = "1/75/75/75",
[93528] = "1/75/75/75",
[93529] = "1/75/75/75",
[93530] = "1/75/75/75",
[93531] = "1/75/75/75",
[93532] = "1/75/75/75",
[93533] = "1/75/75/75",
[93534] = "1/75/75/75",
[93535] = "1/75/75/75",
[93536] = "1/75/75/75",
[93537] = "1/75/75/75",
[93538] = "1/75/75/75",
[93539] = "1/75/75/75",
[93540] = "1/75/75/75",
[93541] = "1/75/75/75",
[93542] = "1/75/75/75",
[93543] = "1/75/75/75",
[93544] = "1/75/75/75",
[93545] = "1/75/75/75",
[93546] = "1/75/75/75",
[93547] = "1/75/75/75",
[93548] = "1/75/75/75",
[93620] = "1/75/75/75",
[93621] = "1/75/75/75",
[93622] = "1/75/75/75",
[93623] = "1/75/75/75",
[93624] = "1/75/75/75",
[94111] = "1/75/75/75",
[94263] = "1/75/75/75",
[94264] = "1/75/75/75",
[94265] = "1/75/75/75",
[94266] = "1/75/75/75",
[94267] = "1/75/75/75",
[94268] = "1/75/75/75",
[94575] = "1/75/75/75",
[94576] = "1/75/75/75",
[94577] = "1/75/75/75",
[94578] = "1/75/75/75",
[94579] = "1/75/75/75",
[94580] = "1/75/75/75",
[94581] = "1/75/75/75",
[94582] = "1/75/75/75",
[94583] = "1/75/75/75",
[94584] = "1/75/75/75",
[94585] = "1/75/75/75",
[94586] = "1/75/75/75",
[94587] = "1/75/75/75",
[94588] = "1/75/75/75",
[94589] = "1/75/75/75",
[94590] = "1/75/75/75",
[94591] = "1/75/75/75",
[94592] = "1/75/75/75",
[98602] = "1/75/75/75",
[98606] = "1/75/75/75",
[98607] = "1/75/75/75",
[98611] = "1/75/75/75",
[98615] = "1/75/75/75",
[98616] = "1/75/75/75",
[98717] = {[143255] = "1/75/75/75", [146921] = "1/75/75/75"},
[98776] = "1/75/75/75",
[98784] = "1/75/75/75",
[98785] = "1/75/75/75",
[98786] = "1/75/75/75",
[98787] = "1/75/75/75",
[98788] = "1/75/75/75",
[98810] = "1/75/75/75",
[98843] = "1/75/75/75",
[98844] = "1/75/75/75",
[98845] = "1/75/75/75",
[98846] = "1/75/75/75",
[98847] = "1/75/75/75",
[98848] = "1/75/75/75",
[98849] = "1/75/75/75",
[98850] = "1/75/75/75",
[98851] = "1/75/75/75",
[98852] = "1/75/75/75",
[98853] = "1/75/75/75",
[98854] = "1/75/75/75",
[98855] = "1/75/75/75",
[98856] = "1/75/75/75",
[98857] = "1/75/75/75",
[98858] = "1/75/75/75",
[98859] = "1/75/75/75",
[98860] = "1/75/75/75",
[98861] = "1/75/75/75",
[98862] = "1/75/75/75",
[98863] = "1/75/75/75",
[98864] = "1/75/75/75",
[98920] = "1/75/75/75",
[98926] = "1/75/75/75",
[98927] = "1/75/75/75",
[98928] = "1/75/75/75",
[98929] = "1/75/75/75",
[98930] = "1/75/75/75",
[108257] = {[171690] = "1/1/50/100", [182116] = "1/100/100/100"},
[114230] = "1/100/100/101",
[114231] = "1/100/100/101",
[114232] = "1/100/100/101",
[114233] = "1/100/100/101",
[114234] = "1/100/100/101",
[114235] = "1/100/100/101",
[114236] = "1/100/100/101",
[114237] = "1/100/100/101",
[116425] = "1/50/55/60",
[116426] = "1/50/55/60",
[116427] = "1/50/55/60",
[116428] = "1/100/100/100",
[116453] = "1/100/100/100",
[116454] = "1/100/100/100",
[116644] = "1/100/100/100",
[116646] = "1/100/100/100",
[116647] = "1/100/100/100",
[116654] = "1/100/100/100",
[118720] = "1/1/50/100",
[119328] = "1/100/100/100",
[120259] = "1/100/100/100",
[120261] = "1/100/100/100",
[123891] = {[182935] = "1/20/30/40", [182969] = "1/40/50/60", [182973] = "1/60/70/80"},
[123892] = {[182934] = "1/20/30/40", [182968] = "1/40/50/60", [191928] = "1/60/70/80"},
[123893] = {[182933] = "1/20/30/40", [182967] = "1/40/50/60", [191930] = "1/60/70/80"},
[123894] = {[182932] = "1/20/30/40", [182966] = "1/40/50/60", [191929] = "1/60/70/80"},
[123895] = {[182931] = "1/20/30/40", [182965] = "1/40/50/60", [191931] = "1/60/70/80"},
[123896] = {[182930] = "1/20/30/40", [182964] = "1/40/50/60", [182972] = "1/60/70/80"},
[123897] = {[182929] = "1/20/30/40", [182963] = "1/40/50/60", [182971] = "1/60/70/80"},
[123898] = {[182928] = "1/20/30/40", [182962] = "1/40/50/60", [182970] = "1/60/70/80"},
[123910] = {[182951] = "1/60/70/80", [182981] = "1/80/90/100", [182989] = "1/100/100/100"},
[123911] = {[182950] = "1/60/70/80", [182980] = "1/80/90/100", [182988] = "1/100/100/100"},
[123912] = {[182949] = "1/60/70/80", [182979] = "1/80/90/100", [182987] = "1/100/100/100"},
[123913] = {[182948] = "1/60/70/80", [182978] = "1/80/90/100", [182986] = "1/100/100/100"},
[123914] = {[182947] = "1/60/70/80", [182977] = "1/80/90/100", [182985] = "1/100/100/100"},
[123915] = {[182946] = "1/60/70/80", [182976] = "1/80/90/100", [182984] = "1/100/100/100"},
[123916] = {[182945] = "1/60/70/80", [182975] = "1/80/90/100", [182983] = "1/100/100/100"},
[123917] = {[182944] = "1/60/70/80", [182974] = "1/80/90/100", [182982] = "1/100/100/100"},
[123956] = "1/20/32/45",
[124006] = "1/1/1/1",
[124007] = "1/1/1/1",
[124009] = "1/1/1/1",
[124010] = "1/1/1/1",
[124049] = "1/1/1/1",
[124393] = "1/1/1/1",
[124394] = "1/1/1/1",
[124395] = "1/1/1/1",
[124396] = "1/1/1/1",
[124397] = "1/1/1/1",
[124405] = "1/1/1/1",
[124406] = "1/1/1/1",
[124407] = "1/1/1/1",
[124408] = "1/1/1/1",
[124409] = "1/1/1/1",
[124410] = "1/1/1/1",
[124411] = "1/1/1/1",
[124418] = "1/1/1/1",
[124419] = "1/1/1/1",
[124420] = "1/1/1/1",
[124421] = "1/1/1/1",
[124422] = "1/1/1/1",
[124423] = "1/1/1/1",
[124424] = "1/1/1/1",
[124426] = "1/1/1/1",
[124427] = "1/1/1/1",
[124428] = "1/1/1/1",
[124429] = "1/1/1/1",
[124430] = "1/1/1/1",
[124431] = "1/1/1/1",
[124432] = "1/1/1/1",
[124433] = "1/1/1/1",
[124434] = "1/1/1/1",
[124435] = "1/1/1/1",
[124450] = "1/1/1/1",
[124452] = "1/1/1/1",
[124453] = "1/1/1/1",
[124454] = "1/1/1/1",
[124455] = "1/1/1/1",
[124461] = "1/60/67/75",
[128777] = "1/1/1/1",
[136683] = "1/20/45/70",
[136684] = "1/20/45/70",
[136685] = "1/20/45/70",
[136686] = "1/20/45/70",
[136708] = "1/20/32/45",
[137686] = "1/100/105/110",
[146667] = "1/100/100/100",
[151239] = "1/20/32/45",
[151576] = {[247710] = "1/90/95/100", [247713] = "1/90/95/100", [247714] = "1/90/95/100"},
[151872] = "1/1/1/1",
[151923] = "1/1/1/1",
[151924] = "1/1/1/1",
[151925] = "1/1/1/1",
[152802] = "1/80/90/100",
[152803] = "1/25/37/50",
[152804] = "1/15/32/50",
[152805] = "1/30/47/65",
[152806] = "1/45/72/100",
[152807] = "1/50/70/90",
[152808] = "1/25/37/50",
[152809] = "1/10/17/25",
[152812] = {[253110] = "1/80/90/100", [286015] = "1/100/105/110", [286016] = "1/110/115/120"},
[152813] = "1/80/90/100",
[152818] = "1/30/47/65",
[152819] = {[253116] = "1/110/130/150", [253117] = "1/125/137/150", [253118] = "1/135/142/150"},
[152827] = "1/15/32/50",
[152828] = "1/45/72/100",
[152831] = "1/45/72/100",
[152832] = "1/15/32/50",
[152833] = "1/45/72/100",
[152834] = {[253159] = "1/110/130/150", [253160] = "1/125/137/150", [253161] = "1/135/142/150"},
[152835] = {[253156] = "1/110/130/150", [253157] = "1/125/137/150", [253158] = "1/135/142/150"},
[152839] = "1/150/150/150",
[158887] = "1/165/170/175",
[159826] = "1/20/60/100",
[159851] = {[269458] = "1/110/130/150", [269459] = "1/120/135/150", [269460] = "1/130/140/150"},
[159853] = {[269464] = "1/100/110/120", [269465] = "1/110/122/135", [269466] = "1/120/132/145"},
[159855] = {[269470] = "1/115/132/150", [269471] = "1/125/137/150", [269472] = "1/135/142/150"},
[159857] = {[269476] = "1/100/110/120", [269477] = "1/110/122/135", [269478] = "1/120/132/145"},
[159858] = {[269479] = "1/115/132/150", [269480] = "1/125/137/150", [269481] = "1/135/142/150"},
[159860] = {[269424] = "1/110/130/150", [269425] = "1/120/135/150", [269426] = "1/130/140/150"},
[159861] = {[269421] = "1/100/110/120", [269422] = "1/110/122/135", [269423] = "1/120/132/145"},
[159863] = {[269444] = "1/115/132/150", [269446] = "1/125/137/150", [269447] = "1/135/142/150"},
[159865] = {[269448] = "1/110/130/150", [269449] = "1/120/135/150", [269450] = "1/130/140/150"},
[159866] = {[269451] = "1/100/110/120", [269452] = "1/110/122/135", [269453] = "1/120/132/145"},
[161888] = "1/150/150/150",
[161889] = "1/150/150/150",
[162460] = "1/1/25/50",
[162461] = "1/1/25/50",
[162464] = "1/150/150/150",
[162466] = "1/150/150/150",
[162491] = "1/150/150/150",
[162492] = "1/150/150/150",
[162652] = {[253144] = "1/120/132/145", [253149] = "1/110/122/135", [256786] = "1/100/110/120"},
[162655] = {[278131] = "1/110/130/150", [278132] = "1/125/137/150", [278133] = "1/135/142/150"},
[164648] = {[282876] = "1/135/142/150", [282878] = "1/140/145/150", [282879] = "1/145/147/150"},
[164649] = {[282871] = "1/135/142/150", [282872] = "1/140/145/150", [282873] = "1/145/147/150"},
[164650] = {[282868] = "1/135/142/150", [282869] = "1/140/145/150", [282870] = "1/145/147/150"},
[164651] = {[282862] = "1/135/142/150", [282863] = "1/140/145/150", [282864] = "1/145/147/150"},
[164652] = {[282859] = "1/135/142/150", [282860] = "1/140/145/150", [282861] = "1/145/147/150"},
[164653] = {[283249] = "1/135/142/150", [283250] = "1/140/145/150", [283251] = "1/145/147/150"},
[164654] = {[283245] = "1/135/142/150", [283247] = "1/140/145/150", [283248] = "1/145/147/150"},
[164655] = {[283242] = "1/135/142/150", [283243] = "1/140/145/150", [283244] = "1/145/147/150"},
[164656] = {[283239] = "1/135/142/150", [283240] = "1/140/145/150", [283241] = "1/145/147/150"},
[164657] = {[282889] = "1/135/142/150", [283237] = "1/140/145/150", [283238] = "1/145/147/150"},
[164719] = {[282865] = "1/135/142/150", [282866] = "1/140/145/150", [282867] = "1/145/147/150"},
[165379] = "1/150/150/150",
[165389] = "1/150/150/150",
[165397] = "1/150/150/150",
[165406] = "1/150/150/150",
[165414] = "1/150/150/150",
[165422] = "1/150/150/150",
[165740] = "1/95/110/125",
[165746] = "1/95/110/125",
[165748] = "1/95/110/125",
[167937] = {[294766] = "1/165/170/175", [294767] = "1/170/172/175", [294768] = "1/175/175/175"},
[167939] = {[294769] = "1/165/170/175", [294770] = "1/170/172/175", [294771] = "1/175/175/175"},
[167965] = {[294763] = "1/165/170/175", [294764] = "1/170/172/175", [294765] = "1/175/175/175"},
[167967] = {[294748] = "1/165/170/175", [294749] = "1/170/172/175", [294750] = "1/175/175/175"},
[167969] = {[294751] = "1/165/170/175", [294752] = "1/170/172/175", [294753] = "1/175/175/175"},
[167971] = {[294754] = "1/165/170/175", [294755] = "1/170/172/175", [294756] = "1/175/175/175"},
[167973] = {[294760] = "1/165/170/175", [294761] = "1/170/172/175", [294762] = "1/175/175/175"},
[167975] = {[294778] = "1/165/170/175", [294779] = "1/170/172/175", [294780] = "1/175/175/175"},
[167989] = {[294775] = "1/165/170/175", [294776] = "1/170/172/175", [294777] = "1/175/175/175"},
[167991] = {[294757] = "1/165/170/175", [294758] = "1/170/172/175", [294759] = "1/175/175/175"},
[167995] = {[294772] = "1/165/170/175", [294773] = "1/170/172/175", [294774] = "1/175/175/175"},
[168417] = "1/165/170/175",
[168677] = "1/175/175/175",
[168678] = "1/175/175/175",
[168679] = "1/175/175/175",
[168680] = "1/175/175/175",
[168681] = "1/175/175/175",
[168682] = "1/175/175/175",
[170285] = {[304307] = "1/165/170/175", [306086] = "1/165/170/175", [306087] = "1/165/170/175"},
[170286] = {[304308] = "1/165/170/175", [306084] = "1/165/170/175", [306085] = "1/165/170/175"},
[170287] = {[304312] = "1/165/170/175", [306082] = "1/165/170/175", [306083] = "1/165/170/175"},
[170288] = {[304315] = "1/165/170/175", [306080] = "1/165/170/175", [306081] = "1/165/170/175"},
[170289] = {[304317] = "1/165/170/175", [306078] = "1/165/170/175", [306079] = "1/165/170/175"},
[170290] = {[304324] = "1/165/170/175", [305844] = "1/165/170/175", [305845] = "1/165/170/175"},
[170291] = {[304323] = "1/165/170/175", [305846] = "1/165/170/175", [305847] = "1/165/170/175"},
[170292] = {[304322] = "1/165/170/175", [305848] = "1/165/170/175", [305849] = "1/165/170/175"},
[170293] = {[304320] = "1/165/170/175", [305850] = "1/165/170/175", [305851] = "1/165/170/175"},
[170294] = {[304318] = "1/165/170/175", [305852] = "1/165/170/175", [305853] = "1/165/170/175"},
[170364] = {[304314] = "1/165/170/175", [306310] = "1/165/170/175", [306312] = "1/165/170/175"},
[170386] = "1/175/175/175",
[170387] = "1/175/175/175",
[170388] = "1/175/175/175",
[170389] = "1/175/175/175",
[170390] = "1/175/175/175",
[170391] = "1/175/175/175",
[171320] = "1/200/200/200",
[171374] = "1/25/30/35",
[171375] = "1/5/10/15",
[171376] = "1/15/20/25",
[171377] = "1/30/35/40",
[171378] = "1/35/40/45",
[171379] = "1/40/45/50",
[171380] = "1/10/15/20",
[171381] = "1/5/10/15",
[171382] = "1/15/20/25",
[171383] = "1/30/35/40",
[171384] = "1/10/15/20",
[171385] = "1/5/10/15",
[171386] = "1/20/25/30",
[171387] = "1/25/30/35",
[171388] = "1/30/35/40",
[171389] = "1/20/25/30",
[171390] = "1/40/45/50",
[171391] = "1/20/25/30",
[171392] = "1/35/40/45",
[171412] = {[307712] = "1/100/100/100", [332013] = "1/100/100/100", [332048] = "1/100/100/100", [338968] = "1/100/100/100"},
[171413] = {[307711] = "1/100/100/100", [332012] = "1/100/100/100", [332047] = "1/100/100/100", [338969] = "1/100/100/100"},
[171414] = {[307710] = "1/100/100/100", [332011] = "1/100/100/100", [332046] = "1/100/100/100", [338970] = "1/100/100/100"},
[171415] = {[307709] = "1/100/100/100", [332010] = "1/100/100/100", [332045] = "1/100/100/100", [338971] = "1/100/100/100"},
[171416] = {[307708] = "1/100/100/100", [332009] = "1/100/100/100", [332044] = "1/100/100/100", [338972] = "1/100/100/100"},
[171417] = {[307707] = "1/100/100/100", [332008] = "1/100/100/100", [332043] = "1/100/100/100", [338974] = "1/100/100/100"},
[171418] = {[307706] = "1/100/100/100", [332007] = "1/100/100/100", [332042] = "1/100/100/100", [338975] = "1/100/100/100"},
[171419] = {[307705] = "1/100/100/100", [332006] = "1/100/100/100", [332041] = "1/100/100/100", [338976] = "1/100/100/100"},
[171428] = "1/57/58/60",
[171436] = "1/5/7/10",
[171437] = "1/55/57/60",
[171438] = "1/5/7/10",
[171439] = "1/60/62/65",
[171441] = "1/17/18/20",
[171442] = "1/90/95/100",
[171443] = "1/65/70/75",
[171444] = "1/75/80/85",
[171445] = "1/85/90/95",
[171446] = "1/100/100/100",
[171447] = "1/100/100/100",
[171448] = "1/70/75/80",
[171449] = "1/60/65/70",
[173381] = "1/55/60/65",
[173382] = "1/75/80/85",
[173383] = "1/90/92/95",
[173384] = "1/200/200/200",
[180055] = {[330134] = "1/1/10/20", [330144] = "1/1/10/20", [330149] = "1/1/10/20", [330154] = "1/1/10/20", [330159] = "1/1/10/20", [330164] = "1/1/10/20", [330169] = "1/1/10/20", [330174] = "1/1/10/20"},
[180057] = {[330140] = "1/1/10/20", [330145] = "1/1/10/20", [330150] = "1/1/10/20", [330155] = "1/1/10/20", [330160] = "1/1/10/20", [330165] = "1/1/10/20", [330170] = "1/1/10/20", [330175] = "1/1/10/20"},
[180058] = {[330141] = "1/1/10/20", [330146] = "1/1/10/20", [330151] = "1/1/10/20", [330156] = "1/1/10/20", [330161] = "1/1/10/20", [330166] = "1/1/10/20", [330171] = "1/1/10/20", [330176] = "1/1/10/20"},
[180059] = {[330142] = "1/1/10/20", [330147] = "1/1/10/20", [330152] = "1/1/10/20", [330157] = "1/1/10/20", [330162] = "1/1/10/20", [330167] = "1/1/10/20", [330172] = "1/1/10/20", [330177] = "1/1/10/20"},
[180060] = {[330143] = "1/1/10/20", [330148] = "1/1/10/20", [330153] = "1/1/10/20", [330158] = "1/1/10/20", [330163] = "1/1/10/20", [330168] = "1/1/10/20", [330173] = "1/1/10/20", [330178] = "1/1/10/20"},
[181378] = "1/1/1/1",
[181784] = "1/1/1/1",
[181787] = "1/1/1/1",
[181788] = "1/1/1/1",
[181790] = "1/1/1/1",
[181791] = "1/1/1/1",
[181792] = "1/1/1/1",
[181862] = "1/1/1/1",
[182086] = "1/1/1/1",
[182087] = "1/1/1/1",
[182090] = "1/1/1/1",
[182092] = "1/1/1/1",
[182093] = "1/1/1/1",
[183942] = "1/50/55/60",
[185960] = "1/100/100/100",



-- enchanting
[-7418] = "1/70/90/110",
[-7420] = "1/70/90/110",
[-7421] = "1/5/7/10",
[-7426] = "1/90/110/130",
[-7428] = "1/80/100/120",
[-7443] = "1/80/100/120",
[-7457] = "1/100/120/140",
[-7745] = "1/130/150/170",
[-7748] = "1/105/125/145",
[-7766] = "1/105/125/145",
[-7771] = "1/110/130/150",
[-7776] = "1/115/135/155",
[-7779] = "1/115/135/155",
[-7782] = "1/115/135/155",
[-7786] = "1/120/140/160",
[-7788] = "1/120/140/160",
[-7793] = "1/130/150/170",
[-7857] = "1/145/165/185",
[-7859] = "1/145/165/185",
[-7863] = "1/150/170/190",
[-7867] = "1/425/425/425",
[-13378] = "1/130/150/170",
[-13380] = "1/135/155/175",
[-13419] = "1/135/155/175",
[-13421] = "1/140/160/180",
[-13464] = "1/140/160/180",
[-13485] = "1/155/175/195",
[-13501] = "1/155/175/195",
[-13503] = "1/165/185/205",
[-13529] = "1/170/190/210",
[-13536] = "1/165/185/205",
[-13538] = "1/165/185/205",
[-13607] = "1/170/190/210",
[-13612] = "1/170/190/210",
[-13617] = "1/170/190/210",
[-13620] = "1/170/190/210",
[-13622] = "1/175/195/215",
[-13626] = "1/175/195/215",
[-13631] = "1/175/195/215",
[-13635] = "1/175/195/215",
[-13637] = "1/180/200/220",
[-13640] = "1/180/200/220",
[-13642] = "1/185/205/225",
[-13644] = "1/190/210/230",
[-13646] = "1/190/210/230",
[-13648] = "1/190/210/230",
[-13653] = "1/195/215/235",
[-13655] = "1/195/215/235",
[-13659] = "1/200/220/240",
[-13661] = "1/200/220/240",
[-13663] = "1/205/225/245",
[-13687] = "1/210/230/250",
[-13689] = "1/215/235/255",
[-13693] = "1/215/235/255",
[-13695] = "1/220/240/260",
[-13698] = "1/220/240/260",
[-13700] = "1/220/240/260",
[-13746] = "1/225/245/265",
[-13815] = "1/230/250/270",
[-13817] = "1/230/250/270",
[-13822] = "1/230/250/270",
[-13836] = "1/235/255/275",
[-13841] = "1/235/255/275",
[-13846] = "1/240/260/280",
[-13858] = "1/240/260/280",
[-13868] = "1/245/265/285",
[-13882] = "1/245/265/285",
[-13887] = "1/245/265/285",
[-13890] = "1/245/265/285",
[-13898] = "1/285/292/300",
[-13905] = "1/250/270/290",
[-13915] = "1/250/270/290",
[-13917] = "1/250/270/290",
[-13931] = "1/255/275/295",
[-13935] = "1/255/275/295",
[-13937] = "1/260/280/300",
[-13939] = "1/260/280/300",
[-13941] = "1/265/282/300",
[-13943] = "1/265/282/300",
[-13945] = "1/265/282/300",
[-13947] = "1/270/285/300",
[-13948] = "1/270/285/300",
[-14293] = "1/75/95/115",
[-14807] = "1/110/130/150",
[-14809] = "1/175/195/215",
[-14810] = "1/195/215/235",
[-15596] = "1/285/292/300",
[-17180] = "1/250/255/260",
[-17181] = "1/250/255/260",
[-20008] = "1/275/287/300",
[-20009] = "1/290/295/300",
[-20010] = "1/300/300/300",
[-20011] = "1/300/300/300",
[-20012] = "1/290/295/300",
[-20013] = "1/300/300/300",
[-20015] = "1/300/300/300",
[-20016] = "1/300/300/300",
[-20017] = "1/285/292/300",
[-20020] = "1/280/290/300",
[-20023] = "1/300/300/300",
[-20024] = "1/295/297/300",
[-20025] = "1/300/300/300",
[-20026] = "1/295/297/300",
[-20028] = "1/300/300/300",
[-20029] = "1/300/300/300",
[-20030] = "1/300/300/300",
[-20031] = "1/300/300/300",
[-20032] = "1/300/300/300",
[-20033] = "1/300/300/300",
[-20034] = "1/300/300/300",
[-20035] = "1/300/300/300",
[-20036] = "1/300/300/300",
[-21931] = "1/210/230/250",
[-22749] = "1/300/300/300",
[-22750] = "1/300/300/300",
[-23799] = "1/300/300/300",
[-23800] = "1/300/300/300",
[-23801] = "1/300/300/300",
[-23802] = "1/300/300/300",
[-23803] = "1/300/300/300",
[-23804] = "1/300/300/300",
[-25072] = "1/1/25/50",
[-25073] = "1/300/300/300",
[-25074] = "1/300/300/300",
[-25078] = "1/300/300/300",
[-25079] = "1/300/300/300",
[-25080] = "1/1/25/50",
[-25083] = "1/1/25/50",
[-25084] = "1/1/25/50",
[-25086] = "1/1/25/50",
[-25124] = "1/55/65/75",
[-25125] = "1/160/170/180",
[-25126] = "1/210/220/230",
[-25127] = "1/260/270/280",
[-25128] = "1/285/292/300",
[-25129] = "1/300/300/300",
[-25130] = "1/300/300/300",
[-27837] = "1/300/300/300",
[-27899] = "1/15/30/45",
[-27905] = "1/25/40/55",
[-27906] = "1/30/45/60",
[-27911] = "1/35/50/65",
[-27913] = "1/45/55/65",
[-27914] = "1/70/72/75",
[-27917] = "1/70/72/75",
[-27944] = "1/20/35/50",
[-27945] = "1/35/50/65",
[-27946] = "1/50/62/75",
[-27948] = "1/15/30/45",
[-27950] = "1/30/45/60",
[-27951] = "1/50/62/75",
[-27954] = "1/75/75/75",
[-27957] = "1/25/40/55",
[-27958] = "1/1/5/10",
[-27960] = "1/55/65/75",
[-27961] = "1/20/35/50",
[-27967] = "1/50/62/75",
[-27968] = "1/50/62/75",
[-27971] = "1/70/72/75",
[-27972] = "1/70/72/75",
[-27975] = "1/70/72/75",
[-27977] = "1/70/72/75",
[-27981] = "1/75/75/75",
[-27982] = "1/75/75/75",
[-27984] = "1/75/75/75",
[-28003] = "1/70/72/75",
[-28004] = "1/70/72/75",
[-28016] = "1/10/20/30",
[-28019] = "1/40/50/60",
[-28022] = "1/1/3/5",
[-28027] = "1/25/30/35",
[-28028] = "1/70/72/75",
[-33990] = "1/30/45/60",
[-33991] = "1/10/25/40",
[-33992] = "1/55/65/75",
[-33993] = "1/15/30/45",
[-33994] = "1/70/72/75",
[-33995] = "1/50/62/75",
[-33996] = "1/20/35/50",
[-33997] = "1/70/72/75",
[-33999] = "1/70/72/75",
[-34001] = "1/15/30/45",
[-34002] = "1/10/25/40",
[-34003] = "1/35/50/65",
[-34004] = "1/20/35/50",
[-34007] = "1/70/72/75",
[-34008] = "1/70/72/75",
[-34009] = "1/35/50/65",
[-34010] = "1/70/72/75",
[-42615] = "1/15/25/35",
[-42620] = "1/60/67/75",
[-42974] = "1/375/375/375",
[-44383] = "1/40/52/65",
[-44484] = "1/40/50/60",
[-44488] = "1/50/57/65",
[-44489] = "1/55/65/75",
[-44492] = "1/30/40/50",
[-44500] = "1/30/40/50",
[-44506] = "1/15/20/25",
[-44508] = "1/50/57/65",
[-44509] = "1/55/65/75",
[-44510] = "1/50/57/65",
[-44513] = "1/30/40/50",
[-44524] = "1/60/67/75",
[-44528] = "1/25/30/35",
[-44529] = "1/50/60/70",
[-44555] = "1/10/17/25",
[-44575] = "1/65/70/75",
[-44576] = "1/60/67/75",
[-44582] = "1/20/27/35",
[-44584] = "1/40/50/60",
[-44588] = "1/60/67/75",
[-44589] = "1/50/60/70",
[-44591] = "1/70/72/75",
[-44592] = "1/1/5/10",
[-44593] = "1/55/65/75",
[-44595] = "1/65/70/75",
[-44598] = "1/50/60/70",
[-44616] = "1/35/45/55",
[-44621] = "1/65/70/75",
[-44623] = "1/5/15/25",
[-44625] = "1/70/72/75",
[-44629] = "1/30/40/50",
[-44630] = "1/25/35/45",
[-44631] = "1/75/75/75",
[-44633] = "1/50/57/65",
[-44635] = "1/30/40/50",
[-45765] = "1/60/62/65",
[-46578] = "1/50/57/65",
[-46594] = "1/70/72/75",
[-47051] = "1/75/75/75",
[-47672] = "1/65/70/75",
[-47766] = "1/35/45/55",
[-47898] = "1/65/70/75",
[-47899] = "1/75/75/75",
[-47900] = "1/60/67/75",
[-47901] = "1/75/75/75",
[-59619] = "1/75/75/75",
[-59621] = "1/75/75/75",
[-59625] = "1/75/75/75",
[-60606] = "1/10/20/30",
[-60609] = "1/1/5/10",
[-60616] = "1/1/5/10",
[-60621] = "1/15/25/35",
[-60623] = "1/20/30/40",
[-60653] = "1/30/40/50",
[-60663] = "1/55/65/75",
[-60668] = "1/60/67/75",
[-60691] = "1/65/70/75",
[-60692] = "1/75/75/75",
[-60707] = "1/70/72/75",
[-60714] = "1/70/72/75",
[-60763] = "1/75/75/75",
[-60767] = "1/75/75/75",
[-62256] = "1/75/75/75",
[-62948] = "1/75/75/75",
[-62959] = "1/20/30/40",
[-63746] = "1/245/265/285",
[-64441] = "1/75/75/75",
[-64579] = "1/75/75/75",
[-69412] = "1/25/30/35",
[-71692] = "1/1/13/25",
[-74132] = "1/1/5/10",
[-74189] = "1/1/5/10",
[-74191] = "1/1/5/10",
[-74192] = "1/1/10/20",
[-74193] = "1/1/10/20",
[-74195] = "1/10/12/15",
[-74197] = "1/10/12/15",
[-74198] = "1/15/25/35",
[-74199] = "1/15/25/35",
[-74200] = "1/20/30/40",
[-74201] = "1/20/30/40",
[-74202] = "1/25/35/45",
[-74207] = "1/25/35/45",
[-74211] = "1/30/40/50",
[-74212] = "1/30/40/50",
[-74213] = "1/35/45/55",
[-74214] = "1/35/45/55",
[-74220] = "1/40/50/60",
[-74223] = "1/40/50/60",
[-74225] = "1/45/55/65",
[-74226] = "1/45/55/65",
[-74229] = "1/50/60/70",
[-74230] = "1/50/60/70",
[-74231] = "1/55/65/75",
[-74232] = "1/55/65/75",
[-74234] = "1/60/67/75",
[-74235] = "1/60/67/75",
[-74236] = "1/60/62/65",
[-74237] = "1/65/70/75",
[-74238] = "1/70/72/75",
[-74239] = "1/70/72/75",
[-74240] = "1/70/72/75",
[-74242] = "1/75/75/75",
[-74244] = "1/75/75/75",
[-74246] = "1/75/75/75",
[-74247] = "1/75/75/75",
[-74248] = "1/75/75/75",
[-74250] = "1/75/75/75",
[-74251] = "1/75/75/75",
[-74252] = "1/75/75/75",
[-74253] = "1/75/75/75",
[-74254] = "1/75/75/75",
[-74255] = "1/75/75/75",
[-74256] = "1/75/75/75",
[-93841] = "1/75/75/75",
[-93843] = "1/75/75/75",
[-95471] = "1/30/40/50",
[-96261] = "1/75/75/75",
[-96262] = "1/75/75/75",
[-96264] = "1/75/75/75",
[-104338] = "1/1/5/10",
[-104385] = "1/25/42/60",
[-104389] = "1/75/75/75",
[-104390] = "1/75/75/75",
[-104391] = "1/75/75/75",
[-104392] = "1/25/42/60",
[-104393] = "1/25/42/60",
[-104395] = "1/75/75/75",
[-104397] = "1/50/62/75",
[-104398] = "1/50/62/75",
[-104401] = "1/75/75/75",
[-104403] = "1/25/42/60",
[-104404] = "1/1/5/10",
[-104407] = "1/50/62/75",
[-104408] = "1/25/42/60",
[-104409] = "1/50/62/75",
[-104414] = "1/75/75/75",
[-104416] = "1/25/42/60",
[-104417] = "1/50/62/75",
[-104419] = "1/75/75/75",
[-104420] = "1/75/75/75",
[-104425] = "1/50/62/75",
[-104427] = "1/75/75/75",
[-104430] = "1/25/42/60",
[-104434] = "1/75/75/75",
[-104440] = "1/75/75/75",
[-104442] = "1/75/75/75",
[-104445] = "1/75/75/75",
[-104698] = "1/15/32/50",
[-116497] = "1/1/3/5",
[-116498] = "1/1/3/5",
[-116499] = "1/1/3/5",
[-118237] = "1/1/3/5",
[-118238] = "1/1/3/5",
[-118239] = "1/1/3/5",
[-130758] = "1/75/75/75",
[-158877] = "1/25/27/30",
[-158878] = "1/25/27/30",
[-158879] = "1/25/27/30",
[-158881] = "1/25/27/30",
[-158884] = "1/100/100/100",
[-158885] = "1/100/100/100",
[-158886] = "1/100/100/100",
[-158889] = "1/100/100/100",
[-158892] = "1/25/27/30",
[-158893] = "1/25/27/30",
[-158894] = "1/25/27/30",
[-158896] = "1/25/27/30",
[-158899] = "1/100/100/100",
[-158900] = "1/100/100/100",
[-158901] = "1/100/100/100",
[-158903] = "1/100/100/100",
[-158907] = "1/25/27/30",
[-158908] = "1/25/27/30",
[-158909] = "1/25/27/30",
[-158911] = "1/25/27/30",
[-158914] = "1/100/100/100",
[-158915] = "1/100/100/100",
[-158916] = "1/100/100/100",
[-158918] = "1/100/100/100",
[-159235] = "1/100/100/100",
[-159236] = "1/100/100/100",
[-159671] = "1/100/100/100",
[-159672] = "1/100/100/100",
[-159673] = "1/100/100/100",
[-159674] = "1/100/100/100",
[-162948] = "1/50/75/100",
[-169091] = "1/25/27/30",
[-169092] = "1/1/50/100",
[-173323] = "1/100/100/100",
[-177043] = "1/1/50/100",
[-182129] = "1/100/100/100",
[-190866] = "1/20/30/40",
[-190867] = "1/20/30/40",
[-190868] = "1/20/30/40",
[-190869] = "1/20/30/40",
[-190870] = "1/60/70/80",
[-190871] = "1/60/70/80",
[-190872] = "1/60/70/80",
[-190873] = "1/60/70/80",
[-190874] = "1/20/30/40",
[-190875] = "1/20/30/40",
[-190876] = "1/20/30/40",
[-190877] = "1/60/70/80",
[-190878] = "1/60/70/80",
[-190879] = "1/60/70/80",
[-190892] = "1/40/50/60",
[-190893] = "1/40/50/60",
[-190894] = "1/40/50/60",
[-190954] = "1/20/40/60",
[-190988] = "1/20/45/70",
[-190989] = "1/20/45/70",
[-190990] = "1/20/45/70",
[-190991] = "1/20/45/70",
[-190992] = "1/40/50/60",
[-190993] = "1/40/50/60",
[-190994] = "1/40/50/60",
[-190995] = "1/40/50/60",
[-190996] = "1/80/90/100",
[-190997] = "1/80/90/100",
[-190998] = "1/80/90/100",
[-190999] = "1/80/90/100",
[-191000] = "1/40/50/60",
[-191001] = "1/40/50/60",
[-191002] = "1/40/50/60",
[-191003] = "1/80/90/100",
[-191004] = "1/80/90/100",
[-191005] = "1/80/90/100",
[-191006] = "1/60/70/80",
[-191007] = "1/60/70/80",
[-191008] = "1/60/70/80",
[-191009] = "1/60/70/80",
[-191010] = "1/60/70/80",
[-191011] = "1/60/70/80",
[-191012] = "1/60/70/80",
[-191013] = "1/100/100/100",
[-191014] = "1/100/100/100",
[-191015] = "1/100/100/100",
[-191016] = "1/100/100/100",
[-191017] = "1/60/70/80",
[-191018] = "1/60/70/80",
[-191019] = "1/60/70/80",
[-191020] = "1/100/100/100",
[-191021] = "1/100/100/100",
[-191022] = "1/100/100/100",
[-191023] = "1/80/90/100",
[-191024] = "1/80/90/100",
[-191025] = "1/80/90/100",
[-191074] = "1/20/40/60",
[-191075] = "1/20/40/60",
[-191076] = "1/20/40/60",
[-191078] = "1/20/40/60",
[-209507] = "1/20/45/70",
[-209509] = "1/20/45/70",
[-217637] = "1/290/295/300",
[-217641] = "1/70/72/75",
[-217644] = "1/70/72/75",
[-217645] = "1/70/72/75",
[-217649] = "1/70/72/75",
[-217650] = "1/70/72/75",
[-217651] = "1/70/72/75",
[-217655] = "1/90/95/100",
[-224199] = "1/1/3/5",
[-228402] = "1/40/50/60",
[-228403] = "1/60/70/80",
[-228404] = "1/80/90/100",
[-228405] = "1/40/50/60",
[-228406] = "1/60/70/80",
[-228407] = "1/80/90/100",
[-228408] = "1/40/50/60",
[-228409] = "1/60/70/80",
[-228410] = "1/80/90/100",
[-235695] = "1/40/50/60",
[-235696] = "1/40/50/60",
[-235697] = "1/40/50/60",
[-235698] = "1/40/50/60",
[-235699] = "1/50/60/70",
[-235700] = "1/50/60/70",
[-235701] = "1/50/60/70",
[-235702] = "1/50/60/70",
[-235703] = "1/60/70/80",
[-235704] = "1/60/70/80",
[-235705] = "1/60/70/80",
[-235706] = "1/60/70/80",
[-252106] = "1/60/70/80",
[-255035] = "1/10/30/50",
[-255040] = "1/10/30/50",
[-255065] = "1/10/30/50",
[-255066] = "1/10/30/50",
[-255068] = "1/35/55/75",
[-255070] = "1/10/30/50",
[-255071] = "1/25/37/50",
[-255072] = "1/25/37/50",
[-255073] = "1/25/37/50",
[-255074] = "1/25/37/50",
[-255075] = "1/100/117/135",
[-255076] = "1/100/117/135",
[-255077] = "1/100/117/135",
[-255078] = "1/100/117/135",
[-255086] = "1/40/57/75",
[-255087] = "1/40/57/75",
[-255088] = "1/40/57/75",
[-255089] = "1/40/57/75",
[-255090] = "1/120/135/150",
[-255091] = "1/120/135/150",
[-255092] = "1/120/135/150",
[-255093] = "1/120/135/150",
[-255094] = "1/75/87/100",
[-255095] = "1/75/87/100",
[-255096] = "1/75/87/100",
[-255097] = "1/75/87/100",
[-255098] = "1/115/132/150",
[-255099] = "1/115/132/150",
[-255100] = "1/115/132/150",
[-255101] = "1/115/132/150",
[-255103] = "1/75/87/100",
[-255104] = "1/105/120/135",
[-255105] = "1/115/130/145",
[-255110] = "1/75/87/100",
[-255111] = "1/105/120/135",
[-255112] = "1/115/130/145",
[-255129] = "1/75/87/100",
[-255130] = "1/105/120/135",
[-255131] = "1/115/130/145",
[-255141] = "1/75/87/100",
[-255142] = "1/105/120/135",
[-255143] = "1/115/130/145",
[-265105] = "1/30/40/50",
[-265106] = "1/50/75/100",
[-265110] = "1/100/125/150",
[-265111] = "1/125/137/150",
[-265112] = "1/125/137/150",
[-267458] = "1/10/30/50",
[-267482] = "1/10/30/50",
[-267486] = "1/10/30/50",
[-267490] = "1/10/30/50",
[-267495] = "1/35/55/75",
[-267498] = "1/10/30/50",
[-268852] = "1/75/95/115",
[-268878] = "1/150/150/150",
[-268879] = "1/150/150/150",
[-268894] = "1/75/95/115",
[-268895] = "1/150/150/150",
[-268897] = "1/150/150/150",
[-268901] = "1/75/95/115",
[-268902] = "1/150/150/150",
[-268903] = "1/150/150/150",
[-268907] = "1/75/95/115",
[-268908] = "1/150/150/150",
[-268909] = "1/150/150/150",
[-268913] = "1/75/95/115",
[-268914] = "1/150/150/150",
[-268915] = "1/150/150/150",
[-269715] = "1/100/117/135",
[-269716] = "1/110/127/145",
[-269719] = "1/115/132/150",
[-271366] = "1/35/55/75",
[-271433] = "1/35/55/75",
[-278418] = "1/95/110/125",
[-282851] = "1/135/142/150",
[-282855] = "1/140/145/150",
[-282857] = "1/145/147/150",
[-285644] = "1/140/145/150",
[-286644] = "1/1/25/50",
[-286665] = "1/100/100/100",
[-287270] = "1/1/25/50",
[-287494] = "1/150/150/150",
[-290360] = "1/1/50/100",
[-290361] = "1/1/75/150",
[-294781] = "1/165/170/175",
[-294782] = "1/170/172/175",
[-294783] = "1/175/175/175",
[-297989] = "1/165/170/175",
[-297991] = "1/170/172/175",
[-297993] = "1/165/170/175",
[-297994] = "1/170/172/175",
[-297995] = "1/165/170/175",
[-297999] = "1/175/175/175",
[-298001] = "1/170/172/175",
[-298002] = "1/175/175/175",
[-298009] = "1/165/170/175",
[-298010] = "1/170/172/175",
[-298011] = "1/175/175/175",
[-298016] = "1/175/175/175",
[-298433] = "1/175/175/175",
[-298437] = "1/175/175/175",
[-298438] = "1/175/175/175",
[-298439] = "1/175/175/175",
[-298440] = "1/175/175/175",
[-298441] = "1/175/175/175",
[-298442] = "1/175/175/175",
[-298515] = "1/175/175/175",
[-300769] = "1/175/175/175",
[-300770] = "1/175/175/175",
[-300788] = "1/175/175/175",
[-300789] = "1/175/175/175",
[-301412] = "1/165/170/175",
[-305936] = "1/165/170/175",
[-305937] = "1/165/170/175",
[-305938] = "1/165/170/175",
[-309524] = "1/10/17/25",
[-309525] = "1/20/25/30",
[-309526] = "1/85/90/95",
[-309528] = "1/35/42/50",
[-309530] = "1/35/42/50",
[-309531] = "1/35/42/50",
[-309532] = "1/20/25/30",
[-309534] = "1/85/90/95",
[-309535] = "1/70/75/80",
[-309608] = "1/20/25/30",
[-309609] = "1/85/90/95",
[-309610] = "1/10/17/25",
[-309612] = "1/45/55/65",
[-309613] = "1/50/60/70",
[-309614] = "1/55/65/75",
[-309615] = "1/60/65/70",
[-309616] = "1/90/95/100",
[-309617] = "1/90/95/100",
[-309618] = "1/90/95/100",
[-309619] = "1/90/95/100",
[-309620] = "1/110/130/150",
[-309621] = "1/110/130/150",
[-309622] = "1/110/130/150",
[-309623] = "1/110/130/150",
[-309627] = "1/35/42/50",
[-309636] = "1/115/132/150",
[-309637] = "1/115/132/150",
[-309638] = "1/115/132/150",
[-309644] = "1/1/1/1",
[-309645] = "1/1/1/1",
[-323609] = "1/10/17/25",
[-323755] = "1/65/70/75",
[-323760] = "1/105/127/150",
[-323761] = "1/105/127/150",
[-323762] = "1/40/50/60",
[-324773] = "1/100/125/150",
[-342316] = "1/70/75/80",
[-343680] = "1/45/47/50",
[-343683] = "1/70/72/75",
[-343684] = "1/50/52/55",
[-355184] = "1/50/62/75",
-- Invalid recipe: Shadowlands Enchanting (46) - True Aim Spear (338121)
-- Invalid recipe: Shadowlands Enchanting (46) - Unbreakable Crystal (338123)
-- Invalid recipe: Shadowlands Enchanting (46) - Everburning Brand (338125)
-- Invalid recipe: Shadowlands Enchanting (46) - Boundless Basket (346026)



-- engineering
[4357] = "1/20/30/40",
[4358] = "1/30/45/60",
[4359] = "1/45/52/60",
[4360] = "1/60/75/90",
[4362] = "1/80/95/110",
[4364] = "1/85/90/95",
[4365] = "1/95/100/105",
[4366] = "1/115/130/145",
[4367] = "1/130/145/160",
[4368] = "1/130/145/160",
[4369] = "1/130/142/155",
[4370] = "1/125/140/155",
[4371] = "1/115/135/155",
[4372] = "1/145/157/170",
[4373] = "1/145/157/170",
[4374] = "1/120/145/170",
[4375] = "1/125/150/175",
[4376] = "1/125/150/175",
[4377] = "1/125/135/145",
[4378] = "1/125/135/145",
[4379] = "1/155/167/180",
[4380] = "1/140/165/190",
[4381] = "1/165/177/190",
[4382] = "1/145/170/195",
[4383] = "1/170/182/195",
[4384] = "1/175/187/200",
[4385] = "1/175/187/200",
[4386] = "1/175/185/195",
[4387] = "1/160/170/180",
[4388] = "1/180/190/200",
[4389] = "1/170/190/210",
[4390] = "1/175/195/215",
[4391] = "1/175/195/215",
[4392] = "1/185/205/225",
[4393] = "1/205/215/225",
[4394] = "1/190/210/230",
[4395] = "1/215/225/235",
[4396] = "1/220/230/240",
[4397] = "1/220/230/240",
[4398] = "1/200/220/240",
[4401] = "1/105/120/135",
[4403] = "1/185/195/205",
[4404] = "1/110/125/140",
[4405] = "1/90/105/120",
[4406] = "1/135/147/160",
[4407] = "1/200/210/220",
[4852] = "1/185/205/225",
[5507] = "1/160/172/185",
[6219] = "1/70/80/90",
[6533] = "1/150/160/170",
[6712] = "1/125/125/125",
[6714] = "1/115/122/130",
[7148] = "1/160/180/200",
[7189] = "1/245/255/265",
[7191] = "1/275/280/285",
[7506] = "1/150/162/175",
[9312] = "1/150/162/175",
[9313] = "1/150/162/175",
[9318] = "1/150/162/175",
[10498] = "1/175/195/215",
[10499] = "1/195/205/215",
[10500] = "1/225/235/245",
[10501] = "1/240/250/260",
[10502] = "1/245/255/265",
[10503] = "1/250/260/270",
[10504] = "1/265/275/285",
[10505] = "1/175/185/195",
[10506] = "1/250/260/270",
[10507] = "1/175/185/195",
[10508] = "1/225/235/245",
[10510] = "1/240/250/260",
[10514] = "1/215/235/255",
[10518] = "1/245/255/265",
[10542] = "1/225/235/245",
[10543] = "1/225/235/245",
[10545] = "1/230/240/250",
[10546] = "1/230/240/250",
[10548] = "1/260/270/280",
[10558] = "1/150/170/190",
[10559] = "1/195/215/235",
[10560] = "1/200/220/240",
[10561] = "1/215/235/255",
[10562] = "1/235/255/275",
[10576] = "1/270/280/290",
[10577] = "1/225/235/245",
[10586] = "1/235/255/275",
[10587] = "1/230/250/270",
[10588] = "1/265/275/285",
[10644] = "1/205/205/205",
[10645] = "1/260/270/280",
[10646] = "1/205/225/245",
[10713] = "1/195/195/195",
[10716] = "1/225/235/245",
[10720] = "1/230/240/250",
[10721] = "1/235/245/255",
[10724] = "1/245/255/265",
[10725] = "1/250/260/270",
[10726] = "1/255/265/275",
[10727] = "1/260/270/280",
[11590] = "1/200/220/240",
[11825] = "1/205/205/205",
[11826] = "1/205/205/205",
[15992] = "1/250/255/260",
[15993] = "1/280/290/300",
[15994] = "1/280/290/300",
[15995] = "1/280/290/300",
[15996] = "1/285/292/300",
[15999] = "1/290/295/300",
[16000] = "1/295/297/300",
[16004] = "1/295/297/300",
[16005] = "1/300/300/300",
[16006] = "1/300/300/300",
[16007] = "1/300/300/300",
[16008] = "1/300/300/300",
[16009] = "1/300/300/300",
[16022] = "1/300/300/300",
[16023] = "1/295/297/300",
[16040] = "1/300/300/300",
[17716] = "1/190/210/230",
[18168] = "1/300/300/300",
[18232] = "1/300/300/300",
[18282] = "1/300/300/300",
[18283] = "1/300/300/300",
[18587] = "1/285/292/300",
[18588] = "1/200/210/220",
[18594] = "1/275/285/295",
[18631] = "1/270/275/280",
[18634] = "1/280/290/300",
[18637] = "1/285/290/295",
[18638] = "1/300/300/300",
[18639] = "1/300/300/300",
[18641] = "1/250/260/270",
[18645] = "1/275/280/285",
[18660] = "1/260/265/270",
[18984] = "1/285/292/300",
[18986] = "1/285/292/300",
[19026] = "1/250/260/270",
[19998] = "1/300/300/300",
[19999] = "1/300/300/300",
[21277] = "1/300/300/300",
[21557] = "1/125/137/150",
[21558] = "1/125/137/150",
[21559] = "1/125/137/150",
[21569] = "1/245/255/265",
[21570] = "1/295/297/300",
[21571] = "1/225/237/250",
[21574] = "1/225/237/250",
[21576] = "1/225/237/250",
[21589] = "1/175/187/200",
[21590] = "1/175/187/200",
[21592] = "1/175/187/200",
[21714] = "1/275/280/285",
[21716] = "1/275/280/285",
[21718] = "1/275/280/285",
[22728] = "1/275/280/285",
[23736] = "1/20/30/40",
[23737] = "1/35/45/55",
[23742] = "1/30/40/50",
[23746] = "1/60/65/70",
[23747] = "1/70/72/75",
[23748] = "1/75/75/75",
[23758] = "1/50/60/70",
[23761] = "1/50/60/70",
[23762] = "1/60/65/70",
[23763] = "1/70/72/75",
[23764] = "1/45/55/65",
[23765] = "1/70/72/75",
[23766] = "1/75/75/75",
[23767] = "1/35/45/55",
[23768] = "1/35/45/55",
[23771] = "1/35/45/55",
[23774] = "1/25/35/45",
[23775] = "1/50/57/65",
[23781] = "1/1/10/20",
[23782] = "1/1/10/20",
[23783] = "1/1/5/10",
[23784] = "1/25/30/35",
[23785] = "1/50/60/70",
[23786] = "1/50/60/70",
[23787] = "1/50/60/70",
[23819] = "1/50/55/60",
[23821] = "1/5/15/25",
[23824] = "1/65/67/70",
[23825] = "1/60/65/70",
[23826] = "1/25/35/45",
[23827] = "1/40/50/60",
[23828] = "1/75/75/75",
[23829] = "1/75/75/75",
[23835] = "1/60/65/70",
[23836] = "1/60/65/70",
[23838] = "1/75/75/75",
[23839] = "1/75/75/75",
[23841] = "1/35/45/55",
[25886] = "1/35/45/55",
[30542] = "1/50/60/70",
[30544] = "1/50/60/70",
[32413] = "1/45/55/65",
[32423] = "1/35/40/45",
[32461] = "1/70/72/75",
[32472] = "1/70/72/75",
[32473] = "1/70/72/75",
[32474] = "1/70/72/75",
[32475] = "1/70/72/75",
[32476] = "1/70/72/75",
[32478] = "1/70/72/75",
[32479] = "1/70/72/75",
[32480] = "1/70/72/75",
[32494] = "1/70/72/75",
[32495] = "1/70/72/75",
[32756] = "1/75/75/75",
[33092] = "1/30/40/50",
[33093] = "1/45/55/65",
[34060] = "1/1/38/75",
[34061] = "1/75/75/75",
[34113] = "1/70/72/75",
[34353] = "1/75/75/75",
[34354] = "1/75/75/75",
[34355] = "1/75/75/75",
[34356] = "1/15/35/55",
[34357] = "1/75/75/75",
[34847] = "1/75/75/75",
[35181] = "1/75/75/75",
[35182] = "1/75/75/75",
[35183] = "1/75/75/75",
[35184] = "1/75/75/75",
[35185] = "1/75/75/75",
[35581] = "1/65/67/70",
[37567] = "1/40/45/50",
[39681] = "1/1/3/5",
[39682] = "1/5/10/15",
[39683] = "1/20/25/30",
[39688] = "1/30/35/40",
[39690] = "1/1/5/10",
[40536] = "1/10/15/20",
[40727] = "1/75/75/75",
[40767] = "1/60/65/70",
[40768] = "1/55/57/60",
[40769] = "1/40/42/45",
[40771] = "1/1/8/15",
[40772] = "1/65/70/75",
[40865] = "1/60/65/70",
[40892] = "1/5/10/15",
[40893] = "1/5/10/15",
[40895] = "1/55/60/65",
[41112] = "1/50/57/65",
[41121] = "1/55/60/65",
[41146] = "1/55/57/60",
[41167] = "1/60/67/75",
[41168] = "1/75/75/75",
[41508] = "1/75/75/75",
[42546] = "1/45/50/55",
[42549] = "1/75/75/75",
[42550] = "1/75/75/75",
[42551] = "1/75/75/75",
[42552] = "1/75/75/75",
[42553] = "1/75/75/75",
[42554] = "1/75/75/75",
[42555] = "1/75/75/75",
[42641] = "1/50/55/60",
[44413] = "1/75/75/75",
[44504] = "1/75/75/75",
[44739] = "1/25/32/40",
[44740] = "1/50/57/65",
[44741] = "1/50/57/65",
[44742] = "1/50/57/65",
[44949] = "1/75/75/75",
[44951] = "1/35/40/45",
[45631] = "1/270/280/290",
[47828] = "1/40/45/50",
[48933] = "1/75/75/75",
[49040] = "1/75/75/75",
[59359] = "1/75/75/75",
[59364] = "1/75/75/75",
[59367] = "1/75/75/75",
[59448] = "1/75/75/75",
[59449] = "1/75/75/75",
[59453] = "1/75/75/75",
[59455] = "1/75/75/75",
[59456] = "1/75/75/75",
[59458] = "1/75/75/75",
[59594] = "1/75/75/75",
[59595] = "1/45/47/50",
[59596] = "1/45/47/50",
[59597] = "1/70/72/75",
[59598] = "1/75/75/75",
[59599] = "1/75/75/75",
[60216] = "1/70/72/75",
[60217] = "1/70/72/75",
[60218] = "1/65/67/70",
[60222] = "1/30/32/35",
[60223] = "1/55/55/55",
[60224] = "1/10/17/25",
[60403] = "1/75/75/75",
[60853] = "1/35/42/50",
[60854] = "1/70/72/75",
[60858] = "1/65/70/75",
[63396] = "1/75/75/75",
[67494] = "1/25/27/30",
[67749] = "1/30/35/40",
[68049] = "1/75/75/75",
[70139] = "1/75/75/75",
[71077] = "1/75/75/75",
[77467] = "1/1/13/25",
[77468] = "1/1/13/25",
[77527] = "1/40/45/50",
[77528] = "1/75/75/75",
[77529] = "1/75/75/75",
[77530] = "1/50/62/75",
[77531] = "1/50/62/75",
[77532] = "1/1/3/5",
[77533] = "1/75/75/75",
[77534] = "1/75/75/75",
[77535] = "1/75/75/75",
[77536] = "1/75/75/75",
[77537] = "1/75/75/75",
[77538] = "1/75/75/75",
[77539] = "1/75/75/75",
[77540] = "1/10/22/35",
[77541] = "1/10/22/35",
[77542] = "1/10/22/35",
[77543] = "1/10/22/35",
[77544] = "1/10/22/35",
[77545] = "1/10/22/35",
[77546] = "1/10/22/35",
[77547] = "1/10/22/35",
[77589] = "1/25/37/50",
[86607] = "1/40/45/50",
[87213] = "1/75/75/75",
[87214] = "1/75/75/75",
[87215] = "1/75/75/75",
[87216] = "1/50/62/75",
[87250] = "1/75/75/75",
[87251] = "1/75/75/75",
[87526] = "1/75/75/75",
[87764] = "1/1/13/25",
[88491] = "1/1/13/25",
[88493] = "1/1/13/25",
[89888] = "1/1/13/25",
[89893] = "1/1/13/25",
[89991] = "1/1/13/25",
[90146] = "1/50/55/60",
[92747] = "1/600/600/600",
[94113] = "1/600/600/600",
[94903] = "1/600/600/600",
[95416] = "1/600/600/600",
[100905] = "1/600/600/600",
[108745] = "1/100/100/100",
[109076] = "1/25/27/30",
[109120] = "1/100/100/100",
[109122] = "1/100/100/100",
[109167] = "1/100/100/100",
[109168] = "1/100/100/100",
[109171] = "1/100/100/100",
[109172] = "1/100/100/100",
[109173] = "1/100/100/100",
[109174] = "1/100/100/100",
[109183] = "1/100/100/100",
[109184] = "1/25/27/30",
[109253] = "1/100/100/100",
[111366] = {[169080] = "1/1/50/100", [182120] = "1/100/100/100"},
[111402] = "1/100/100/100",
[111820] = "1/100/100/100",
[111821] = "1/100/100/100",
[112057] = "1/100/100/100",
[112059] = "1/100/100/100",
[114056] = "1/100/100/100",
[114943] = "1/100/100/100",
[116147] = "1/1/3/5",
[116148] = "1/1/3/5",
[116149] = "1/1/3/5",
[118006] = "1/25/27/30",
[118007] = "1/25/27/30",
[118008] = "1/100/100/100",
[118741] = "1/100/100/100",
[119299] = "1/1/50/100",
[132500] = {[198939] = "1/20/30/40", [198991] = "1/40/50/60", [199005] = "1/60/70/80"},
[132501] = {[198965] = "1/20/30/40", [198992] = "1/40/50/60", [199006] = "1/60/70/80"},
[132502] = {[198966] = "1/20/30/40", [198993] = "1/40/50/60", [199007] = "1/60/70/80"},
[132503] = {[198967] = "1/20/30/40", [198994] = "1/40/50/60", [199008] = "1/60/70/80"},
[132504] = {[198968] = "1/60/70/80", [198995] = "1/100/100/100", [199009] = "1/90/95/100"},
[132505] = {[198969] = "1/60/70/80", [198996] = "1/100/100/100", [199010] = "1/90/95/100"},
[132506] = {[198970] = "1/60/70/80", [198997] = "1/100/100/100", [199011] = "1/90/95/100"},
[132507] = {[198971] = "1/60/70/80", [198998] = "1/100/100/100", [199012] = "1/90/95/100"},
[132509] = {[198972] = "1/40/50/60", [198999] = "1/60/70/80", [199013] = "1/80/90/100"},
[132510] = {[198973] = "1/40/50/60", [199000] = "1/60/70/80", [199014] = "1/80/90/100"},
[132511] = {[198974] = "1/40/50/60", [199001] = "1/60/70/80", [199015] = "1/80/90/100"},
[132513] = {[198975] = "1/40/50/60", [199002] = "1/60/70/80", [199016] = "1/80/90/100"},
[132514] = {[198976] = "1/40/50/60", [199003] = "1/60/70/80", [199017] = "1/80/90/100"},
[132515] = {[198977] = "1/40/50/60", [199004] = "1/60/70/80", [199018] = "1/80/90/100"},
[132516] = "1/20/40/60",
[132517] = "1/20/40/60",
[132518] = "1/80/90/100",
[132519] = "1/90/95/100",
[132523] = "1/20/30/40",
[132524] = "1/20/40/60",
[132525] = "1/20/40/60",
[132526] = "1/20/40/60",
[132528] = "1/20/40/60",
[132529] = "1/20/40/60",
[132530] = "1/20/40/60",
[132531] = "1/20/40/60",
[132982] = "1/20/40/60",
[134125] = "1/20/40/60",
[136606] = "1/20/40/60",
[136687] = "1/20/45/70",
[136688] = "1/20/45/70",
[144331] = "1/100/100/100",
[144332] = "1/100/100/100",
[144333] = "1/100/100/100",
[144334] = "1/100/100/100",
[144341] = "1/60/70/80",
[151651] = "1/20/40/60",
[151652] = "1/75/87/100",
[152830] = "1/25/60/95",
[152837] = {[253150] = "1/125/137/150", [253151] = "1/135/142/150", [253152] = "1/145/147/150"},
[153487] = {[255407] = "1/25/37/50", [255408] = "1/50/67/85", [255409] = "1/75/87/100"},
[153490] = {[255392] = "1/25/37/50", [255393] = "1/50/67/85", [255394] = "1/75/87/100"},
[153494] = {[255395] = "1/25/37/50", [255396] = "1/50/67/85", [255397] = "1/75/87/100"},
[153506] = {[255457] = "1/125/137/150", [255458] = "1/135/142/150", [255459] = "1/145/147/150"},
[153510] = {[256080] = "1/35/67/100", [256082] = "1/80/97/115", [256084] = "1/95/110/125"},
[153512] = {[256073] = "1/35/67/100", [256074] = "1/80/97/115", [256075] = "1/95/110/125"},
[153573] = {[256070] = "1/35/67/100", [256071] = "1/80/97/115", [256072] = "1/95/110/125"},
[153597] = {[256154] = "1/35/67/100", [256155] = "1/80/97/115", [256156] = "1/95/110/125"},
[158203] = {[265097] = "1/50/75/100", [265098] = "1/100/112/125", [265099] = "1/115/125/135"},
[158212] = {[264960] = "1/50/82/115", [264961] = "1/100/112/125", [264962] = "1/115/125/135"},
[158327] = {[264964] = "1/50/82/115", [264966] = "1/100/112/125", [264967] = "1/115/125/135"},
[158377] = {[265100] = "1/50/75/100", [265101] = "1/100/112/125", [265102] = "1/115/125/135"},
[158379] = {[283914] = "1/100/125/150", [283915] = "1/125/137/150", [283916] = "1/145/147/150"},
[158886] = "1/170/172/175",
[159936] = {[269727] = "1/125/137/150", [269728] = "1/125/137/150", [269729] = "1/135/142/150"},
[159937] = {[269724] = "1/125/137/150", [269725] = "1/125/137/150", [269726] = "1/135/142/150"},
[160488] = {[272056] = "1/130/140/150", [272057] = "1/140/145/150", [272058] = "1/150/150/150"},
[160489] = {[272059] = "1/130/140/150", [272060] = "1/140/145/150", [272061] = "1/150/150/150"},
[160490] = {[272062] = "1/130/140/150", [272063] = "1/140/145/150", [272064] = "1/150/150/150"},
[160491] = {[272065] = "1/130/140/150", [272066] = "1/140/145/150", [272067] = "1/150/150/150"},
[161134] = "1/150/150/150",
[162460] = "1/1/25/50",
[162461] = "1/1/25/50",
[164679] = {[282809] = "1/135/142/150", [282810] = "1/140/145/150", [282811] = "1/145/147/150"},
[164680] = {[282806] = "1/135/142/150", [282807] = "1/140/145/150", [282808] = "1/145/147/150"},
[164740] = "1/150/150/150",
[164913] = "1/150/150/150",
[164914] = "1/150/150/150",
[164915] = "1/150/150/150",
[165738] = "1/95/110/125",
[165742] = "1/95/110/125",
[165849] = "1/135/140/145",
[165885] = "1/150/150/150",
[165886] = "1/150/150/150",
[165887] = "1/150/150/150",
[165888] = "1/150/150/150",
[165890] = "1/150/150/150",
[165891] = "1/150/150/150",
[165892] = "1/150/150/150",
[165893] = "1/150/150/150",
[165895] = "1/150/150/150",
[165896] = "1/150/150/150",
[165897] = "1/150/150/150",
[165898] = "1/150/150/150",
[166979] = "1/125/137/150",
[166980] = "1/130/140/150",
[166981] = "1/125/137/150",
[166982] = "1/130/140/150",
[166983] = "1/125/137/150",
[166984] = "1/130/140/150",
[166985] = "1/125/137/150",
[166986] = "1/130/140/150",
[167940] = {[294784] = "1/165/170/175", [294785] = "1/170/172/175", [294786] = "1/175/175/175"},
[167997] = {[294787] = "1/165/170/175", [294788] = "1/170/172/175", [294789] = "1/175/175/175"},
[168521] = "1/150/162/175",
[168522] = "1/150/162/175",
[168523] = "1/150/162/175",
[168667] = "1/175/175/175",
[168689] = "1/175/175/175",
[168690] = "1/175/175/175",
[168691] = "1/175/175/175",
[168692] = "1/175/175/175",
[168693] = "1/175/175/175",
[168694] = "1/175/175/175",
[168695] = "1/175/175/175",
[168696] = "1/175/175/175",
[168697] = "1/175/175/175",
[168698] = "1/175/175/175",
[168699] = "1/175/175/175",
[168700] = "1/175/175/175",
[168807] = "1/155/157/160",
[168808] = "1/155/157/160",
[170313] = {[305861] = "1/165/170/175", [305862] = "1/165/170/175", [305863] = "1/165/170/175"},
[170314] = {[305858] = "1/165/170/175", [305859] = "1/165/170/175", [305860] = "1/165/170/175"},
[171003] = "1/175/175/175",
[171004] = "1/175/175/175",
[171005] = "1/175/175/175",
[171006] = "1/175/175/175",
[171007] = "1/175/175/175",
[171008] = "1/175/175/175",
[171009] = "1/175/175/175",
[171010] = "1/175/175/175",
[171011] = "1/175/175/175",
[171012] = "1/175/175/175",
[171013] = "1/175/175/175",
[171014] = "1/175/175/175",
[171320] = "1/200/200/200",
[172902] = "1/30/37/45",
[172903] = "1/20/27/35",
[172904] = "1/25/32/40",
[172905] = "1/95/97/100",
[172906] = "1/95/97/100",
[172907] = "1/95/97/100",
[172908] = "1/95/97/100",
[172912] = "1/75/77/80",
[172914] = "1/70/75/80",
[172915] = "1/55/60/65",
[172920] = "1/90/92/95",
[172921] = "1/90/92/95",
[172923] = "1/40/45/50",
[172924] = "1/85/90/95",
[172934] = "1/10/17/25",
[172935] = "1/10/17/25",
[172936] = "1/45/47/50",
[172937] = "1/75/77/80",
[173381] = "1/55/60/65",
[173382] = "1/75/80/85",
[173383] = "1/90/92/95",
[173384] = "1/200/200/200",
[180208] = "1/115/117/120",
[183942] = "1/35/37/40",
[184308] = "1/55/62/70",
-- Unknown item created by: Northrend Engineering (48) - EMP Generator (54736)
-- Unknown item created by: Northrend Engineering (48) - Frag Belt (54793)
-- Unknown item created by: Northrend Engineering (48) - Flexweave Underlay (55002)
-- Unknown item created by: Northrend Engineering (48) - Nitro Boosts (55016)
-- Unknown item created by: Northrend Engineering (48) - Mind Amplification Dish (67839)
-- Unknown item created by: Cataclysm Engineering (36) - Spinal Healing Injector (82200)
-- Unknown item created by: Cataclysm Engineering (36) - Invisibility Field (84424)
-- Unknown item created by: Cataclysm Engineering (36) - Cardboard Assassin (84425)
-- Unknown item created by: Cataclysm Engineering (36) - Grounded Plasma Shield (84427)
-- Unknown item created by: Pandaria Engineering (46) - Watergliding Jets (109099)
-- Unknown item created by: Pandaria Engineering (46) - Goblin Glider (126392)
-- Unknown item created by: Kul Tiran Engineering (147) - Belt Enchant: Holographic Horror Projector (255936)
-- Unknown item created by: Kul Tiran Engineering (147) - Belt Enchant: Personal Space Amplifier (255940)
-- Unknown item created by: Kul Tiran Engineering (147) - Belt Enchant: Miniaturized Plasma Shield (269123)
-- Invalid recipe: Kul Tiran Engineering (147) - Magical Intrusion Dampener (280732)
-- Invalid recipe: Kul Tiran Engineering (147) - Magical Intrusion Dampener (280733)
-- Invalid recipe: Kul Tiran Engineering (147) - Magical Intrusion Dampener (280734)
-- Unknown item created by: Shadowlands Engineering (40) - Dimensional Shifter (310495)
-- Unknown item created by: Shadowlands Engineering (40) - Electro-Jump (310496)
-- Unknown item created by: Shadowlands Engineering (40) - Damage Retaliator (310497)
-- Invalid recipe: Shadowlands Engineering (40) - Bug Zapifier (338119)
-- Invalid recipe: Shadowlands Engineering (40) - Energized Battery (338210)
-- Invalid recipe: Shadowlands Engineering (40) - Electro Cable (338212)
-- Invalid recipe: Shadowlands Engineering (40) - Power Hammer (338213)
-- Invalid recipe: Shadowlands Engineering (40) - Piston Assembly (338214)
-- Invalid recipe: Shadowlands Engineering (40) - Hardened Bolts (338216)
-- Invalid recipe: Shadowlands Engineering (40) - Boneclad Stake Launcher (338217)
-- Invalid recipe: Shadowlands Engineering (40) - Bone Reinforced Oxxein Tubing (338218)
-- Invalid recipe: Shadowlands Engineering (40) - Handful of Oxxein Bolts (338219)
-- Invalid recipe: Shadowlands Engineering (40) - Duelist's Pistol (338220)
-- Invalid recipe: Shadowlands Engineering (40) - Sinvyr Barrel (338222)
-- Invalid recipe: Shadowlands Engineering (40) - Sinvyr Trigger Mechanism (338223)



-- inscription
[954] = "15/65/70/75",
[955] = "1/65/70/75",
[1180] = "1/65/70/75",
[1181] = "1/65/70/75",
[1477] = "85/85/90/95",
[1711] = "75/75/80/85",
[1712] = "75/75/80/85",
[2289] = "80/80/85/90",
[2290] = "75/75/80/85",
[3012] = "15/65/70/75",
[4419] = "165/170/175/180",
[4422] = "155/160/165/170",
[4424] = "160/165/170/175",
[4425] = "175/180/185/190",
[4426] = "170/175/180/185",
[10306] = "210/215/220/225",
[10307] = "205/210/215/220",
[10308] = "215/220/225/230",
[10309] = "225/230/235/240",
[10310] = "220/225/230/235",
[27498] = "270/275/280/285",
[27499] = "260/265/270/275",
[27501] = "255/260/265/270",
[27502] = "250/255/260/265",
[27503] = "265/270/275/280",
[33457] = "1/20/25/30",
[33458] = "1/10/15/20",
[33460] = "295/300/300/300",
[33461] = "290/300/300/300",
[33462] = "1/15/20/25",
[37091] = "1/1/10/20",
[37092] = "1/40/45/50",
[37093] = "1/1/10/20",
[37094] = "1/30/35/40",
[37097] = "1/1/10/20",
[37098] = "1/35/40/45",
[37118] = "35/75/80/85",
[37168] = "85/125/137/150",
[38322] = "1/50/62/75",
[38682] = "35/75/87/100",
[39469] = "1/45/60/75",
[39774] = "75/75/77/80",
[40919] = "1/1/10/20",
[41100] = "1/300/300/300",
[42459] = "1/1/38/75",
[42751] = "1/1/10/20",
[43115] = "85/85/90/95",
[43116] = "1/100/100/105",
[43117] = "125/125/130/135",
[43118] = "1/150/150/155",
[43119] = "1/175/175/180",
[43120] = "1/200/200/205",
[43121] = "1/225/225/230",
[43122] = "1/250/250/255",
[43123] = "275/290/295/300",
[43124] = "1/1/3/5",
[43125] = "1/20/25/30",
[43126] = "1/1/10/20",
[43127] = "1/1/10/20",
[43334] = "1/1/10/20",
[43350] = "1/1/10/20",
[43366] = "1/300/300/300",
[43369] = "1/300/300/300",
[43373] = "1/300/300/300",
[43386] = "1/300/300/300",
[43394] = "1/300/300/300",
[43398] = "1/300/300/300",
[43400] = "1/300/300/300",
[43463] = "1/1/10/20",
[43464] = "1/50/55/60",
[43465] = "1/1/10/20",
[43466] = "1/45/50/55",
[43515] = "85/125/137/150",
[43535] = "1/300/300/300",
[43551] = "1/300/300/300",
[43654] = "125/150/162/175",
[43655] = "125/150/162/175",
[43656] = "175/200/205/210",
[43657] = "175/200/205/210",
[43660] = "225/250/255/260",
[43661] = "225/250/255/260",
[43663] = "275/290/295/300",
[43664] = "275/290/295/300",
[43666] = "1/40/45/50",
[43667] = "1/40/45/50",
[43850] = "200/205/210/215",
[44142] = "125/150/162/175",
[44161] = "175/200/205/210",
[44163] = "225/250/255/260",
[44210] = "1/50/62/75",
[44314] = "200/215/220/225",
[44315] = "1/1/10/20",
[44316] = "275/290/295/300",
[44317] = "1/50/62/75",
[44318] = "1/75/75/75",
[44922] = "1/300/300/300",
[45768] = "1/1/10/20",
[45789] = "1/300/300/300",
[45849] = "1/1/10/20",
[45854] = "1/1/10/20",
[49084] = "1/1/10/20",
[49632] = "1/50/62/75",
[60838] = "1/10/17/25",
[61978] = "1/1/1/1",
[61981] = "1/30/32/35",
[61987] = "1/75/75/75",
[62056] = "1/75/75/75",
[62231] = "1/35/37/40",
[62233] = "1/35/37/40",
[62234] = "1/70/72/75",
[62235] = "1/70/72/75",
[62236] = "1/70/72/75",
[62238] = "1/30/40/50",
[62239] = "1/20/30/40",
[62251] = "1/55/60/65",
[63246] = "1/40/50/60",
[63276] = "1/75/75/75",
[63303] = "1/25/30/35",
[63304] = "1/20/25/30",
[63305] = "1/1/5/10",
[63306] = "1/15/20/25",
[63307] = "1/10/15/20",
[63308] = "1/5/10/15",
[64670] = "75/90/100/110",
[77101] = "1/300/300/300",
[79254] = "1/10/15/20",
[79255] = "1/10/15/20",
[79257] = "1/75/75/75",
[79318] = "1/75/75/75",
[79333] = "1/45/50/55",
[79334] = "1/75/75/75",
[79335] = "1/75/75/75",
[79339] = "1/45/50/55",
[79340] = "1/75/75/75",
[79341] = "1/75/75/75",
[79342] = "1/45/50/55",
[79343] = "1/75/75/75",
[79538] = "1/1/10/20",
[79731] = "1/75/75/75",
[80587] = "1/300/300/300",
[80588] = "1/1/10/20",
[83006] = "1/75/75/75",
[83007] = "1/75/75/75",
[85221] = "1/300/300/300",
[87277] = "1/1/10/20",
[87392] = "1/1/10/20",
[87559] = "1/75/75/75",
[87560] = "1/75/75/75",
[87561] = "1/75/75/75",
[87562] = "1/75/75/75",
[87565] = "1/50/52/55",
[87566] = "1/65/70/75",
[87577] = "1/25/25/25",
[87578] = "1/25/25/25",
[87579] = "1/25/25/25",
[87580] = "1/25/25/25",
[87581] = "1/75/75/75",
[87582] = "1/75/75/75",
[87584] = "1/75/75/75",
[87585] = "1/75/75/75",
[87647] = "1/75/75/75",
[87648] = "1/75/75/75",
[87811] = "1/75/75/75",
[87814] = "1/75/75/75",
[87831] = "1/75/75/75",
[87881] = "1/1/10/20",
[87883] = "1/1/10/20",
[87885] = "1/300/300/300",
[87888] = "1/1/10/20",
[88806] = "1/75/75/75",
[89367] = "1/75/75/75",
[89368] = "1/75/75/75",
[89868] = "1/300/300/300",
[102483] = "1/70/72/75",
[104099] = "1/300/300/300",
[104104] = "1/300/300/300",
[104105] = "1/300/300/300",
[104108] = "1/1/10/20",
[104120] = "1/1/38/75",
[104122] = "1/300/300/300",
[104126] = "1/300/300/300",
[104127] = "1/300/300/300",
[104138] = "1/300/300/300",
[111526] = "1/100/100/100",
[112270] = "1/100/100/100",
[112377] = {[169081] = "1/1/50/100", [182125] = "1/100/100/100"},
[113111] = "1/1/1/1",
[113131] = "1/100/100/100",
[113134] = "1/100/100/100",
[113270] = "1/100/100/100",
[113289] = "1/100/100/100",
[113355] = "1/100/100/100",
[113992] = "1/1/3/5",
[114931] = {[190381] = "1/1/8/15", [190382] = "1/1/8/15", [190383] = "1/1/8/15", [190384] = "1/1/8/15", [190385] = "1/1/8/15", [190386] = "1/1/8/15"},
[114942] = "1/1/1/1",
[118061] = "1/1/1/1",
[118601] = "1/1/3/5",
[118602] = "1/1/3/5",
[118603] = "1/1/3/5",
[119126] = "1/1/1/1",
[119297] = "1/1/50/100",
[128304] = "1/1/8/15",
[128712] = {[191659] = "1/40/50/60", [192859] = "1/60/70/80", [192890] = "1/80/90/100"},
[128978] = {[192854] = "1/60/70/80", [192855] = "1/80/90/100", [192856] = "1/100/100/100"},
[128979] = "1/20/50/80",
[128980] = "1/20/40/60",
[128987] = {[192808] = "1/40/50/60", [192860] = "1/60/70/80", [192891] = "1/80/90/100"},
[128988] = {[192809] = "1/40/50/60", [192861] = "1/60/70/80", [192892] = "1/80/90/100"},
[128989] = {[192810] = "1/40/50/60", [192862] = "1/60/70/80", [192893] = "1/80/90/100"},
[128990] = {[192811] = "1/40/50/60", [192863] = "1/60/70/80", [192894] = "1/80/90/100"},
[128991] = {[192812] = "1/40/50/60", [192864] = "1/60/70/80", [192895] = "1/80/90/100"},
[128992] = {[192813] = "1/40/50/60", [192865] = "1/60/70/80", [192896] = "1/80/90/100"},
[128993] = {[192814] = "1/40/50/60", [192866] = "1/60/70/80", [192897] = "1/80/90/100"},
[128994] = {[192815] = "1/60/70/80", [192867] = "1/80/90/100", [192898] = "1/100/100/100"},
[128995] = {[192816] = "1/60/70/80", [192868] = "1/80/90/100", [192899] = "1/100/100/100"},
[128996] = {[192817] = "1/60/70/80", [192869] = "1/80/90/100", [192900] = "1/100/100/100"},
[128997] = {[192818] = "1/60/70/80", [192870] = "1/80/90/100", [192901] = "1/100/100/100"},
[128998] = {[192819] = "1/60/70/80", [192871] = "1/80/90/100", [192902] = "1/100/100/100"},
[128999] = {[192820] = "1/60/70/80", [192872] = "1/80/90/100", [192903] = "1/100/100/100"},
[129000] = {[192821] = "1/60/70/80", [192873] = "1/80/90/100", [192904] = "1/100/100/100"},
[129001] = {[192822] = "1/60/70/80", [192874] = "1/80/90/100", [192905] = "1/100/100/100"},
[129002] = {[192823] = "1/60/70/80", [192875] = "1/80/90/100", [192906] = "1/100/100/100"},
[129003] = {[192824] = "1/60/70/80", [192876] = "1/80/90/100", [192907] = "1/100/100/100"},
[129017] = "1/20/45/70",
[129018] = "1/20/45/70",
[129019] = "1/20/45/70",
[129020] = "1/20/45/70",
[129021] = "1/20/45/70",
[129022] = "1/20/45/70",
[129028] = "1/20/45/70",
[129029] = "1/20/45/70",
[129032] = {[209661] = "1/1/8/15", [209662] = "1/1/8/15", [210116] = "1/1/8/15"},
[129034] = {[209664] = "1/1/8/15", [247861] = "1/1/8/15"},
[129100] = "1/1/8/15",
[129211] = "1/20/40/60",
[136692] = "1/20/45/70",
[136693] = "1/20/45/70",
[136825] = "1/20/45/70",
[136826] = "1/20/45/70",
[136852] = "1/50/70/90",
[136856] = "1/50/70/90",
[136857] = "1/50/70/90",
[136926] = "1/1/8/15",
[137188] = "1/20/45/70",
[137191] = "1/20/45/70",
[137238] = "1/20/45/70",
[137239] = "1/20/45/70",
[137249] = "1/20/45/70",
[137250] = "1/20/45/70",
[137267] = "1/20/45/70",
[137269] = "1/20/45/70",
[137274] = "1/20/45/70",
[137287] = "1/20/45/70",
[137288] = "1/20/45/70",
[137289] = "1/20/45/70",
[137293] = "1/20/45/70",
[139270] = "1/20/45/70",
[139271] = "1/20/45/70",
[139278] = "1/20/45/70",
[139288] = "1/20/45/70",
[139289] = "1/20/45/70",
[139310] = "1/20/45/70",
[139311] = "1/20/45/70",
[139312] = "1/20/45/70",
[139315] = "1/20/45/70",
[139338] = "1/20/45/70",
[139339] = "1/20/45/70",
[139348] = "1/20/45/70",
[139352] = "1/20/45/70",
[139358] = "1/20/45/70",
[139362] = "1/20/45/70",
[139417] = "1/20/45/70",
[139435] = "1/20/45/70",
[139436] = "1/20/45/70",
[139437] = "1/20/45/70",
[139438] = "1/20/45/70",
[139442] = "1/20/45/70",
[140567] = "1/50/70/90",
[140568] = "1/50/70/90",
[140630] = "1/20/45/70",
[141333] = {[226248] = "1/50/60/70", [227239] = "1/50/60/70", [227240] = "1/50/60/70"},
[141446] = "1/20/40/60",
[141640] = "1/1/20/40",
[141641] = "1/1/35/70",
[141644] = {[165304] = "1/175/225/275", [165456] = "1/200/250/300", [165460] = "1/250/275/300", [165461] = "1/300/300/300", [165463] = "1/300/300/300", [165464] = "1/75/75/75", [165465] = "1/75/75/75", [165466] = "1/75/75/75", [165467] = "1/70/72/75", [165564] = "1/125/175/225"},
[141898] = "1/20/45/70",
[142101] = {[229177] = "1/60/70/80", [229180] = "1/60/70/80", [229183] = "1/80/90/100"},
[142102] = {[229178] = "1/60/70/80", [229181] = "1/60/70/80", [229184] = "1/80/90/100"},
[142103] = {[229179] = "1/60/70/80", [229182] = "1/60/70/80", [229185] = "1/80/90/100"},
[143588] = "1/20/45/70",
[143750] = "1/20/45/70",
[146406] = {[238577] = "1/40/50/60", [238578] = "1/60/70/80", [238579] = "1/80/90/100"},
[147119] = "1/20/45/70",
[149755] = "1/1/10/20",
[151538] = "1/20/45/70",
[151540] = "1/20/45/70",
[151542] = "1/20/45/70",
[151610] = {[247614] = "1/80/90/100", [247615] = "1/80/90/100", [247616] = "1/80/90/100"},
[152505] = "1/70/75/80",
[152506] = "1/70/75/80",
[152507] = "1/70/75/80",
[152508] = "1/70/75/80",
[152509] = "1/70/75/80",
[152510] = "1/70/75/80",
[152511] = "1/70/75/80",
[153031] = "1/20/45/70",
[153033] = "1/20/45/70",
[153036] = "1/20/45/70",
[153598] = {[256245] = "1/150/150/150", [256246] = "1/150/150/150", [278527] = "1/110/130/150"},
[153643] = {[256247] = "1/110/122/135", [256248] = "1/150/150/150", [256249] = "1/150/150/150"},
[153646] = {[256232] = "1/95/110/125", [256233] = "1/110/130/150", [256234] = "1/125/137/150"},
[153647] = {[256235] = "1/25/50/75", [256236] = "1/80/95/110", [256237] = "1/75/92/110"},
[153661] = {[256275] = "1/95/115/135", [256276] = "1/105/125/145", [256277] = "1/115/132/150"},
[153662] = {[256278] = "1/95/115/135", [256279] = "1/105/125/145", [256280] = "1/115/132/150"},
[153663] = {[256281] = "1/95/115/135", [256282] = "1/105/125/145", [256283] = "1/115/132/150"},
[153664] = {[256284] = "1/95/115/135", [256285] = "1/105/125/145", [256286] = "1/115/132/150"},
[153665] = {[256287] = "1/95/115/135", [256288] = "1/105/125/145", [256289] = "1/115/132/150"},
[153666] = {[256290] = "1/95/115/135", [256291] = "1/105/125/145", [256293] = "1/115/132/150"},
[153667] = {[256294] = "1/95/115/135", [256295] = "1/105/125/145", [256296] = "1/115/132/150"},
[153668] = {[256297] = "1/95/115/135", [256298] = "1/105/125/145", [256299] = "1/115/132/150"},
[153670] = "1/150/150/150",
[153673] = {[256303] = "1/150/150/150", [256304] = "1/150/150/150", [256305] = "1/150/150/150"},
[156563] = "1/150/150/150",
[156636] = "1/150/150/150",
[156637] = "1/150/150/150",
[156638] = "1/150/150/150",
[158187] = "1/25/37/50",
[158188] = "1/25/37/50",
[158189] = "1/25/37/50",
[158201] = "1/50/75/100",
[158202] = "1/50/87/125",
[158204] = "1/50/75/100",
[159825] = "1/45/60/75",
[159940] = {[269740] = "1/110/122/135", [269741] = "1/115/130/145", [269742] = "1/125/137/150"},
[162022] = "1/75/100/125",
[162027] = "1/75/100/125",
[162029] = "1/150/150/150",
[162460] = "1/1/25/50",
[162461] = "1/1/25/50",
[164682] = {[282803] = "1/135/142/150", [282804] = "1/140/145/150", [282805] = "1/145/147/150"},
[165016] = {[284292] = "1/125/137/150", [284293] = "1/135/142/150", [284294] = "1/145/147/150"},
[165017] = {[284295] = "1/125/137/150", [284296] = "1/135/142/150", [284297] = "1/145/147/150"},
[165692] = {[285639] = "1/150/150/150", [285640] = "1/150/150/150", [285641] = "1/150/150/150"},
[165733] = {[285925] = "1/150/150/150", [285926] = "1/150/150/150", [285927] = "1/150/150/150"},
[165745] = "1/95/110/125",
[166583] = "1/150/150/150",
[166664] = "1/150/150/150",
[167539] = "1/1/10/20",
[167942] = {[294790] = "1/165/170/175", [294791] = "1/170/172/175", [294792] = "1/175/175/175"},
[168487] = "1/150/162/175",
[168583] = "1/55/60/65",
[168586] = "1/55/60/65",
[168589] = "1/55/60/65",
[168624] = {[298625] = "1/165/170/175", [298647] = "1/170/172/175", [298648] = "1/175/175/175"},
[168663] = "1/125/150/175",
[168956] = "1/165/170/175",
[168959] = "1/165/170/175",
[168960] = "1/165/170/175",
[169301] = "1/175/175/175",
[169302] = "1/175/175/175",
[169321] = "1/175/175/175",
[169328] = "1/175/175/175",
[169701] = "1/55/60/65",
[170164] = "1/150/162/175",
[170165] = "1/150/162/175",
[170168] = "1/150/162/175",
[170173] = "1/150/162/175",
[170316] = {[305952] = "1/165/170/175", [305953] = "1/165/170/175", [305954] = "1/165/170/175"},
[170554] = "1/55/60/65",
[171203] = {[306481] = "1/175/175/175", [306482] = "1/175/175/175", [306483] = "1/175/175/175"},
[171315] = "1/55/60/65",
[172008] = "1/175/175/175",
[172010] = "1/175/175/175",
[172449] = "1/175/175/175",
[173048] = "1/70/72/75",
[173049] = "1/30/32/35",
[173050] = "1/30/35/40",
[173051] = "1/80/85/90",
[173053] = "1/80/85/90",
[173054] = "1/40/45/50",
[173058] = "1/15/20/25",
[173059] = "1/15/20/25",
[173062] = "1/80/85/90",
[173065] = "1/25/30/35",
[173066] = "1/95/110/125",
[173067] = "1/115/120/125",
[173160] = "1/85/92/100",
[173161] = "1/85/92/100",
[173162] = "1/85/92/100",
[173163] = "1/85/92/100",
[173381] = "1/50/52/55",
[173382] = "1/70/72/75",
[173428] = "1/40/45/50",
[175924] = "1/80/85/90",
[175970] = "1/65/70/75",
[177873] = "1/95/110/125",
[177874] = "1/95/110/125",
[177875] = "1/95/110/125",
[177876] = "1/95/110/125",
[180755] = "1/100/105/110",
[183942] = "1/45/47/50",
[184096] = "1/150/150/150",
[184097] = "1/150/150/150",
[184100] = "1/150/150/150",
[186522] = "1/100/100/100",
[186662] = "1/115/120/125",
-- Unknown item created by: Northrend Inscription (29) - Master's Inscription of the Axe (61117)
-- Unknown item created by: Northrend Inscription (29) - Master's Inscription of the Crag (61118)
-- Unknown item created by: Northrend Inscription (29) - Master's Inscription of the Pinnacle (61119)
-- Unknown item created by: Northrend Inscription (29) - Master's Inscription of the Storm (61120)
-- Unknown item created by: Cataclysm Inscription (38) - Swiftsteel Inscription (86375)
-- Unknown item created by: Cataclysm Inscription (38) - Lionsmane Inscription (86401)
-- Unknown item created by: Cataclysm Inscription (38) - Inscription of the Earth Prince (86402)
-- Unknown item created by: Cataclysm Inscription (38) - Felfire Inscription (86403)
-- Invalid recipe: Shadowlands Inscription (47) - Hymnal of Respite (338225)
-- Invalid recipe: Shadowlands Inscription (47) - Scroll of Calming Lyrics (338226)
-- Invalid recipe: Shadowlands Inscription (47) - Ardenberry Ink (338227)
-- Invalid recipe: Shadowlands Inscription (47) - Invocation of Duty (338228)
-- Invalid recipe: Shadowlands Inscription (47) - Poem on Duty (338229)
-- Invalid recipe: Shadowlands Inscription (47) - Opalescent Ink (338230)
-- Invalid recipe: Shadowlands Inscription (47) - Litany of Might (338231)
-- Invalid recipe: Shadowlands Inscription (47) - Scroll of Unyielding Strength (338232)
-- Invalid recipe: Shadowlands Inscription (47) - Necrotic Ink (338233)
-- Invalid recipe: Shadowlands Inscription (47) - Catalog of Sins (338234)
-- Invalid recipe: Shadowlands Inscription (47) - Scroll of Castigation (338235)
-- Invalid recipe: Shadowlands Inscription (47) - Prideful Ink (338236)



-- jewelcrafting
[20816] = "1/20/35/50",
[20817] = "50/70/80/90",
[20818] = "50/80/95/110",
[20820] = "60/90/105/120",
[20821] = "30/60/75/90",
[20823] = "70/100/115/130",
[20826] = "90/120/135/150",
[20827] = "80/110/125/140",
[20828] = "100/130/145/160",
[20830] = "1/140/155/170",
[20831] = "1/180/195/210",
[20832] = "120/150/165/180",
[20833] = "1/155/170/185",
[20906] = "1/30/45/60",
[20907] = "50/80/95/110",
[20909] = "110/140/155/170",
[20950] = "120/150/165/180",
[20954] = "125/155/170/185",
[20955] = "135/165/180/195",
[20958] = "150/180/195/210",
[20959] = "1/200/215/230",
[20960] = "170/200/215/230",
[20961] = "180/210/225/240",
[20963] = "150/170/180/190",
[20964] = "210/235/250/265",
[20966] = "1/190/205/220",
[20967] = "1/220/235/250",
[20969] = "1/250/265/280",
[21748] = "200/225/240/255",
[21752] = "225/235/245/255",
[21753] = "1/275/287/300",
[21754] = "1/270/285/300",
[21755] = "220/245/260/275",
[21756] = "1/225/240/255",
[21758] = "1/240/255/270",
[21760] = "1/250/265/280",
[21763] = "1/260/275/290",
[21764] = "235/260/275/290",
[21765] = "240/265/280/295",
[21766] = "1/275/287/300",
[21767] = "260/280/290/300",
[21768] = "275/285/292/300",
[21769] = "1/280/290/300",
[21774] = "1/285/292/300",
[21775] = "280/290/295/300",
[21777] = "1/295/297/300",
[21778] = "1/295/297/300",
[21779] = "1/20/30/40",
[21784] = "1/300/300/300",
[21789] = "1/300/300/300",
[21790] = "280/290/295/300",
[21791] = "290/300/300/300",
[21792] = "1/15/25/35",
[21931] = "1/30/45/60",
[21932] = "5/35/50/65",
[21933] = "50/80/95/110",
[21934] = "30/60/75/90",
[23094] = "1/300/300/300",
[23095] = "1/5/25/45",
[23098] = "1/1/20/40",
[23099] = "1/5/25/45",
[23100] = "1/15/35/55",
[23101] = "1/25/40/55",
[23103] = "1/1/20/40",
[23104] = "1/5/25/45",
[23105] = "1/15/35/55",
[23108] = "1/1/13/25",
[23109] = "1/325/325/325",
[23110] = "1/325/325/325",
[23111] = "1/25/40/55",
[23114] = "1/325/325/325",
[23115] = "1/15/35/55",
[23116] = "1/325/325/325",
[23118] = "1/1/20/40",
[23119] = "1/305/305/305",
[23120] = "1/15/35/55",
[24027] = "1/50/60/70",
[24028] = "1/350/350/350",
[24030] = "1/350/350/350",
[24032] = "1/350/350/350",
[24033] = "1/50/60/70",
[24035] = "1/350/350/350",
[24036] = "1/50/60/70",
[24039] = "1/50/60/70",
[24048] = "1/350/350/350",
[24051] = "1/350/350/350",
[24053] = "1/50/60/70",
[24054] = "1/50/60/70",
[24055] = "1/350/350/350",
[24056] = "1/50/60/70",
[24058] = "1/50/60/70",
[24059] = "1/50/60/70",
[24060] = "1/50/60/70",
[24061] = "1/350/350/350",
[24065] = "1/50/60/70",
[24066] = "1/50/60/70",
[24067] = "1/50/60/70",
[24074] = "1/20/30/40",
[24075] = "1/20/35/50",
[24076] = "1/30/40/50",
[24077] = "1/45/55/65",
[24078] = "1/45/55/65",
[24079] = "1/60/67/75",
[24080] = "1/65/70/75",
[24082] = "1/65/70/75",
[24085] = "1/70/72/75",
[24086] = "1/70/72/75",
[24087] = "1/55/65/75",
[24088] = "1/65/70/75",
[24089] = "1/75/75/75",
[24092] = "1/70/72/75",
[24093] = "1/70/72/75",
[24095] = "1/70/72/75",
[24097] = "1/70/72/75",
[24098] = "1/70/72/75",
[24106] = "1/65/70/75",
[24110] = "1/65/70/75",
[24114] = "1/70/72/75",
[24116] = "1/70/72/75",
[24117] = "1/75/75/75",
[24121] = "1/75/75/75",
[24122] = "1/75/75/75",
[24123] = "1/75/75/75",
[24124] = "1/75/75/75",
[24125] = "1/75/75/75",
[24126] = "1/75/75/75",
[24127] = "1/75/75/75",
[24128] = "1/75/75/75",
[25438] = "20/50/65/80",
[25439] = "20/50/65/80",
[25498] = "1/30/40/50",
[25880] = "50/70/80/90",
[25881] = "110/120/130/140",
[25882] = "175/175/185/195",
[25883] = "225/225/235/245",
[25890] = "1/75/75/75",
[25893] = "1/75/75/75",
[25894] = "1/75/75/75",
[25895] = "1/75/75/75",
[25896] = "1/75/75/75",
[25897] = "1/75/75/75",
[25898] = "1/75/75/75",
[25899] = "1/75/75/75",
[25901] = "1/75/75/75",
[28595] = "1/305/305/305",
[29157] = "180/190/200/210",
[29158] = "200/210/220/230",
[29159] = "280/290/295/300",
[29160] = "290/300/300/300",
[30419] = "75/105/120/135",
[30420] = "105/135/150/165",
[30421] = "230/255/270/285",
[30422] = "265/285/292/300",
[30804] = "65/95/110/125",
[30825] = "1/70/72/75",
[31079] = "1/25/35/45",
[31154] = "80/110/125/140",
[31398] = "1/75/75/75",
[31399] = "1/75/75/75",
[31866] = "1/25/40/55",
[31867] = "1/50/60/70",
[31868] = "1/50/60/70",
[31869] = "1/25/40/55",
[32193] = "1/75/75/75",
[32194] = "1/375/375/375",
[32196] = "1/375/375/375",
[32198] = "1/375/375/375",
[32199] = "1/75/75/75",
[32200] = "1/75/75/75",
[32201] = "1/375/375/375",
[32203] = "1/75/75/75",
[32205] = "1/375/375/375",
[32206] = "1/375/375/375",
[32209] = "1/75/75/75",
[32211] = "1/75/75/75",
[32212] = "1/375/375/375",
[32215] = "1/75/75/75",
[32217] = "1/75/75/75",
[32218] = "1/75/75/75",
[32220] = "1/375/375/375",
[32221] = "1/75/75/75",
[32222] = "1/75/75/75",
[32223] = "1/75/75/75",
[32224] = "1/75/75/75",
[32225] = "1/375/375/375",
[32226] = "1/75/75/75",
[32409] = "1/75/75/75",
[32410] = "1/75/75/75",
[32508] = "1/40/55/70",
[32772] = "1/35/45/55",
[32774] = "1/40/50/60",
[32776] = "1/75/75/75",
[32833] = "1/25/32/40",
[32836] = "1/50/60/70",
[33131] = "1/65/70/75",
[33133] = "1/65/70/75",
[33134] = "1/65/70/75",
[33135] = "1/65/70/75",
[33140] = "1/65/70/75",
[33143] = "1/65/70/75",
[33144] = "1/65/70/75",
[33782] = "1/50/60/70",
[34220] = "1/75/75/75",
[34358] = "1/365/365/365",
[34359] = "1/365/365/365",
[34360] = "1/365/365/365",
[34361] = "1/365/365/365",
[34362] = "1/365/365/365",
[34363] = "1/365/365/365",
[35315] = "1/50/60/70",
[35318] = "1/50/60/70",
[35501] = "1/75/75/75",
[35503] = "1/75/75/75",
[35693] = "1/75/75/75",
[35694] = "1/75/75/75",
[35700] = "1/75/75/75",
[35702] = "1/75/75/75",
[35703] = "1/75/75/75",
[35707] = "1/350/350/350",
[35758] = "1/75/75/75",
[35759] = "1/75/75/75",
[35760] = "1/375/375/375",
[35761] = "1/75/75/75",
[35945] = "1/50/60/70",
[36767] = "1/15/40/65",
[39900] = "1/1/20/40",
[39905] = "1/1/20/40",
[39907] = "1/1/20/40",
[39908] = "1/1/20/40",
[39909] = "1/1/20/40",
[39910] = "1/1/20/40",
[39912] = "1/1/20/40",
[39915] = "1/1/20/40",
[39917] = "1/1/20/40",
[39918] = "1/1/20/40",
[39919] = "1/1/20/40",
[39927] = "1/1/20/40",
[39932] = "1/1/20/40",
[39933] = "1/1/20/40",
[39934] = "1/1/20/40",
[39935] = "1/1/20/40",
[39939] = "1/1/20/40",
[39940] = "1/1/20/40",
[39942] = "1/1/20/40",
[39945] = "1/1/20/40",
[39947] = "1/1/20/40",
[39948] = "1/1/20/40",
[39949] = "1/1/20/40",
[39950] = "1/1/20/40",
[39951] = "1/1/20/40",
[39952] = "1/1/20/40",
[39954] = "1/350/350/350",
[39955] = "1/1/20/40",
[39956] = "1/1/20/40",
[39957] = "1/1/20/40",
[39958] = "1/1/20/40",
[39959] = "1/1/20/40",
[39965] = "1/1/20/40",
[39966] = "1/1/20/40",
[39967] = "1/1/20/40",
[39968] = "1/1/20/40",
[39975] = "1/1/20/40",
[39976] = "1/1/20/40",
[39977] = "1/1/20/40",
[39978] = "1/1/20/40",
[39979] = "1/1/20/40",
[39980] = "1/1/20/40",
[39981] = "1/1/20/40",
[39982] = "1/350/350/350",
[39983] = "1/1/20/40",
[39991] = "1/1/20/40",
[39992] = "1/1/20/40",
[39996] = "1/35/50/65",
[39997] = "1/35/50/65",
[40000] = "1/390/390/390",
[40001] = "1/35/50/65",
[40003] = "1/35/50/65",
[40008] = "1/35/50/65",
[40010] = "1/35/50/65",
[40011] = "1/35/50/65",
[40013] = "1/390/390/390",
[40014] = "1/35/50/65",
[40016] = "1/35/50/65",
[40017] = "1/35/50/65",
[40022] = "1/35/50/65",
[40023] = "1/35/50/65",
[40025] = "1/390/390/390",
[40026] = "1/390/390/390",
[40028] = "1/35/50/65",
[40032] = "1/35/50/65",
[40034] = "1/35/50/65",
[40037] = "1/35/50/65",
[40038] = "1/35/50/65",
[40039] = "1/35/50/65",
[40040] = "1/35/50/65",
[40041] = "1/35/50/65",
[40044] = "1/390/390/390",
[40045] = "1/450/450/450",
[40048] = "1/35/50/65",
[40049] = "1/35/50/65",
[40050] = "1/35/50/65",
[40051] = "1/390/390/390",
[40052] = "1/35/50/65",
[40055] = "1/390/390/390",
[40057] = "1/390/390/390",
[40058] = "1/35/50/65",
[40059] = "1/35/50/65",
[40086] = "1/35/50/65",
[40088] = "1/35/50/65",
[40089] = "1/390/390/390",
[40090] = "1/35/50/65",
[40091] = "1/35/50/65",
[40095] = "1/390/390/390",
[40098] = "1/390/390/390",
[40100] = "1/390/390/390",
[40102] = "1/390/390/390",
[40105] = "1/390/390/390",
[40106] = "1/35/50/65",
[40111] = "1/65/70/75",
[40112] = "1/450/450/450",
[40113] = "1/450/450/450",
[40115] = "1/450/450/450",
[40116] = "1/65/70/75",
[40118] = "1/65/70/75",
[40119] = "1/65/70/75",
[40120] = "1/450/450/450",
[40122] = "1/65/70/75",
[40124] = "1/450/450/450",
[40125] = "1/65/70/75",
[40127] = "1/65/70/75",
[40128] = "1/65/70/75",
[40129] = "1/65/70/75",
[40130] = "1/450/450/450",
[40133] = "1/450/450/450",
[40135] = "1/65/70/75",
[40139] = "1/65/70/75",
[40141] = "1/65/70/75",
[40142] = "1/65/70/75",
[40143] = "1/65/70/75",
[40144] = "1/65/70/75",
[40145] = "1/65/70/75",
[40146] = "1/65/70/75",
[40147] = "1/65/70/75",
[40149] = "1/450/450/450",
[40150] = "1/450/450/450",
[40152] = "1/65/70/75",
[40153] = "1/65/70/75",
[40154] = "1/65/70/75",
[40155] = "1/65/70/75",
[40157] = "1/450/450/450",
[40160] = "1/450/450/450",
[40162] = "1/65/70/75",
[40163] = "1/65/70/75",
[40164] = "1/450/450/450",
[40165] = "1/450/450/450",
[40166] = "1/65/70/75",
[40167] = "1/450/450/450",
[40168] = "1/65/70/75",
[40169] = "1/65/70/75",
[40171] = "1/65/70/75",
[40173] = "1/450/450/450",
[40177] = "1/450/450/450",
[40179] = "1/450/450/450",
[40180] = "1/450/450/450",
[40182] = "1/65/70/75",
[41285] = "1/440/440/440",
[41307] = "1/440/440/440",
[41333] = "1/440/440/440",
[41335] = "1/440/440/440",
[41339] = "1/440/440/440",
[41367] = "1/1/3/5",
[41375] = "1/440/440/440",
[41376] = "1/440/440/440",
[41377] = "1/440/440/440",
[41378] = "1/440/440/440",
[41379] = "1/440/440/440",
[41380] = "1/440/440/440",
[41381] = "1/440/440/440",
[41382] = "1/440/440/440",
[41385] = "1/440/440/440",
[41389] = "1/440/440/440",
[41395] = "1/440/440/440",
[41396] = "1/440/440/440",
[41397] = "1/440/440/440",
[41398] = "1/440/440/440",
[41400] = "1/440/440/440",
[41401] = "1/440/440/440",
[42142] = "1/15/40/65",
[42143] = "1/370/370/370",
[42144] = "1/370/370/370",
[42145] = "1/370/370/370",
[42149] = "1/370/370/370",
[42150] = "1/15/40/65",
[42151] = "1/370/370/370",
[42152] = "1/15/40/65",
[42154] = "1/15/40/65",
[42155] = "1/15/40/65",
[42156] = "1/15/40/65",
[42158] = "1/15/40/65",
[42336] = "1/5/25/45",
[42337] = "1/5/25/45",
[42338] = "1/25/35/45",
[42339] = "1/25/35/45",
[42340] = "1/65/70/75",
[42341] = "1/55/65/75",
[42395] = "1/55/65/75",
[42413] = "1/55/65/75",
[42418] = "1/55/65/75",
[42420] = "1/1/8/15",
[42421] = "1/5/15/25",
[42642] = "1/75/75/75",
[42643] = "1/75/75/75",
[42644] = "1/75/75/75",
[42645] = "1/75/75/75",
[42646] = "1/75/75/75",
[42647] = "1/75/75/75",
[42701] = "1/5/25/45",
[42702] = "1/35/50/65",
[43244] = "1/5/25/45",
[43245] = "1/5/25/45",
[43246] = "1/15/30/45",
[43247] = "1/15/30/45",
[43248] = "1/35/45/55",
[43249] = "1/35/45/55",
[43250] = "1/65/70/75",
[43251] = "1/65/70/75",
[43252] = "1/65/70/75",
[43253] = "1/65/70/75",
[43482] = "1/65/70/75",
[43498] = "1/65/70/75",
[43582] = "1/65/70/75",
[44063] = "1/55/65/75",
[44943] = "1/70/72/75",
[45054] = "1/300/300/300",
[45627] = "200/210/220/230",
[45808] = "1/65/70/75",
[45809] = "1/65/70/75",
[45812] = "1/65/70/75",
[45813] = "1/65/70/75",
[49110] = "1/65/70/75",
[52081] = "1/1/18/35",
[52082] = "1/1/18/35",
[52083] = "1/1/18/35",
[52084] = "1/1/18/35",
[52085] = "1/1/18/35",
[52086] = "1/1/18/35",
[52087] = "1/1/18/35",
[52088] = "1/1/18/35",
[52089] = "1/1/18/35",
[52090] = "1/1/18/35",
[52091] = "1/1/18/35",
[52093] = "1/1/18/35",
[52094] = "1/1/18/35",
[52095] = "1/1/18/35",
[52096] = "1/1/18/35",
[52097] = "1/1/18/35",
[52098] = "1/1/18/35",
[52099] = "1/1/18/35",
[52100] = "1/1/18/35",
[52101] = "1/1/18/35",
[52102] = "1/1/18/35",
[52103] = "1/1/18/35",
[52104] = "1/1/18/35",
[52105] = "1/1/18/35",
[52106] = "1/1/18/35",
[52108] = "1/1/18/35",
[52109] = "1/1/18/35",
[52110] = "1/1/18/35",
[52111] = "1/1/18/35",
[52112] = "1/1/18/35",
[52113] = "1/1/18/35",
[52114] = "1/1/18/35",
[52115] = "1/1/18/35",
[52116] = "1/1/18/35",
[52117] = "1/1/18/35",
[52118] = "1/1/18/35",
[52119] = "1/1/18/35",
[52120] = "1/1/18/35",
[52121] = "1/1/18/35",
[52122] = "1/1/18/35",
[52123] = "1/1/18/35",
[52124] = "1/1/18/35",
[52125] = "1/1/18/35",
[52126] = "1/1/18/35",
[52127] = "1/1/18/35",
[52128] = "1/1/18/35",
[52203] = "1/50/57/65",
[52204] = "1/50/57/65",
[52205] = "1/50/57/65",
[52206] = "1/50/57/65",
[52207] = "1/50/57/65",
[52208] = "1/50/57/65",
[52209] = "1/50/57/65",
[52210] = "1/50/57/65",
[52211] = "1/50/57/65",
[52212] = "1/50/57/65",
[52213] = "1/50/57/65",
[52214] = "1/50/57/65",
[52215] = "1/50/57/65",
[52216] = "1/50/57/65",
[52217] = "1/50/57/65",
[52218] = "1/50/57/65",
[52219] = "1/50/57/65",
[52220] = "1/50/57/65",
[52221] = "1/50/57/65",
[52222] = "1/50/57/65",
[52223] = "1/50/57/65",
[52224] = "1/50/57/65",
[52225] = "1/50/57/65",
[52226] = "1/50/57/65",
[52227] = "1/50/57/65",
[52228] = "1/50/57/65",
[52229] = "1/50/57/65",
[52230] = "1/50/57/65",
[52231] = "1/50/57/65",
[52232] = "1/50/57/65",
[52233] = "1/50/57/65",
[52234] = "1/50/57/65",
[52235] = "1/50/57/65",
[52236] = "1/50/57/65",
[52237] = "1/50/57/65",
[52238] = "1/50/57/65",
[52239] = "1/50/57/65",
[52240] = "1/50/57/65",
[52241] = "1/50/57/65",
[52242] = "1/50/57/65",
[52243] = "1/50/57/65",
[52244] = "1/50/57/65",
[52245] = "1/50/57/65",
[52246] = "1/50/57/65",
[52247] = "1/50/57/65",
[52248] = "1/50/57/65",
[52249] = "1/50/57/65",
[52250] = "1/50/57/65",
[52255] = "1/55/57/60",
[52257] = "1/55/57/60",
[52258] = "1/55/57/60",
[52259] = "1/55/57/60",
[52260] = "1/55/57/60",
[52261] = "1/55/57/60",
[52262] = "1/55/57/60",
[52263] = "1/55/57/60",
[52264] = "1/55/57/60",
[52265] = "1/55/57/60",
[52266] = "1/55/57/60",
[52267] = "1/55/57/60",
[52268] = "1/55/57/60",
[52269] = "1/55/57/60",
[52289] = "1/65/70/75",
[52291] = "1/65/70/75",
[52292] = "1/65/70/75",
[52293] = "1/65/70/75",
[52294] = "1/65/70/75",
[52295] = "1/65/70/75",
[52296] = "1/65/70/75",
[52297] = "1/65/70/75",
[52298] = "1/65/70/75",
[52299] = "1/65/70/75",
[52300] = "1/65/70/75",
[52301] = "1/65/70/75",
[52302] = "1/65/70/75",
[52304] = "1/75/75/75",
[52306] = "1/1/18/35",
[52307] = "1/1/18/35",
[52308] = "1/35/45/55",
[52309] = "1/45/55/65",
[52318] = "1/75/75/75",
[52319] = "1/75/75/75",
[52320] = "1/75/75/75",
[52321] = "1/75/75/75",
[52322] = "1/75/75/75",
[52323] = "1/75/75/75",
[52348] = "1/75/75/75",
[52350] = "1/75/75/75",
[52485] = "1/30/40/50",
[52486] = "1/35/45/55",
[52487] = "1/40/50/60",
[52489] = "1/75/75/75",
[52490] = "1/1/8/15",
[52492] = "1/20/25/30",
[52493] = "1/50/55/60",
[68356] = "1/50/57/65",
[68357] = "1/50/57/65",
[68358] = "1/50/57/65",
[68741] = "1/50/57/65",
[68778] = "1/65/70/75",
[68779] = "1/65/70/75",
[68780] = "1/65/70/75",
[69852] = "1/75/75/75",
[71817] = "1/75/75/75",
[71818] = "1/75/75/75",
[71819] = "1/75/75/75",
[71820] = "1/75/75/75",
[71822] = "1/75/75/75",
[71823] = "1/75/75/75",
[71824] = "1/75/75/75",
[71825] = "1/75/75/75",
[71826] = "1/75/75/75",
[71827] = "1/75/75/75",
[71828] = "1/75/75/75",
[71829] = "1/75/75/75",
[71830] = "1/75/75/75",
[71831] = "1/75/75/75",
[71832] = "1/75/75/75",
[71833] = "1/75/75/75",
[71834] = "1/75/75/75",
[71835] = "1/75/75/75",
[71836] = "1/75/75/75",
[71837] = "1/75/75/75",
[71838] = "1/75/75/75",
[71839] = "1/75/75/75",
[71840] = "1/75/75/75",
[71841] = "1/75/75/75",
[71842] = "1/75/75/75",
[71843] = "1/75/75/75",
[71844] = "1/75/75/75",
[71845] = "1/75/75/75",
[71846] = "1/75/75/75",
[71847] = "1/75/75/75",
[71848] = "1/75/75/75",
[71849] = "1/75/75/75",
[71850] = "1/75/75/75",
[71851] = "1/75/75/75",
[71852] = "1/75/75/75",
[71853] = "1/75/75/75",
[71854] = "1/75/75/75",
[71855] = "1/75/75/75",
[71856] = "1/75/75/75",
[71857] = "1/75/75/75",
[71858] = "1/75/75/75",
[71859] = "1/75/75/75",
[71860] = "1/75/75/75",
[71861] = "1/75/75/75",
[71862] = "1/75/75/75",
[71863] = "1/75/75/75",
[71864] = "1/75/75/75",
[71865] = "1/75/75/75",
[71866] = "1/75/75/75",
[71867] = "1/75/75/75",
[71868] = "1/75/75/75",
[71869] = "1/75/75/75",
[71870] = "1/75/75/75",
[71871] = "1/75/75/75",
[71872] = "1/75/75/75",
[71873] = "1/75/75/75",
[71874] = "1/75/75/75",
[71875] = "1/75/75/75",
[71876] = "1/75/75/75",
[71877] = "1/75/75/75",
[71878] = "1/75/75/75",
[71879] = "1/75/75/75",
[71880] = "1/75/75/75",
[71881] = "1/75/75/75",
[71882] = "1/75/75/75",
[71883] = "1/75/75/75",
[75067] = "1/65/70/75",
[75068] = "1/65/70/75",
[75071] = "1/65/70/75",
[75074] = "1/75/75/75",
[75075] = "1/75/75/75",
[75078] = "1/75/75/75",
[76132] = "1/75/75/75",
[76502] = "1/50/55/60",
[76504] = "1/50/55/60",
[76505] = "1/50/55/60",
[76506] = "1/50/55/60",
[76507] = "1/50/55/60",
[76508] = "1/50/55/60",
[76509] = "1/50/55/60",
[76510] = "1/50/55/60",
[76511] = "1/50/55/60",
[76512] = "1/50/55/60",
[76513] = "1/50/55/60",
[76514] = "1/50/55/60",
[76515] = "1/50/55/60",
[76517] = "1/50/55/60",
[76518] = "1/50/55/60",
[76519] = "1/50/55/60",
[76520] = "1/50/55/60",
[76521] = "1/50/55/60",
[76522] = "1/50/55/60",
[76524] = "1/50/55/60",
[76525] = "1/50/55/60",
[76526] = "1/50/55/60",
[76527] = "1/50/55/60",
[76528] = "1/50/55/60",
[76529] = "1/50/55/60",
[76530] = "1/50/55/60",
[76531] = "1/50/55/60",
[76532] = "1/50/55/60",
[76533] = "1/50/55/60",
[76534] = "1/50/55/60",
[76535] = "1/50/55/60",
[76536] = "1/50/55/60",
[76537] = "1/50/55/60",
[76538] = "1/50/55/60",
[76539] = "1/50/55/60",
[76540] = "1/50/55/60",
[76541] = "1/50/55/60",
[76542] = "1/50/55/60",
[76543] = "1/50/55/60",
[76544] = "1/50/55/60",
[76545] = "1/50/55/60",
[76546] = "1/50/55/60",
[76547] = "1/50/55/60",
[76548] = "1/50/55/60",
[76549] = "1/50/55/60",
[76550] = "1/50/55/60",
[76551] = "1/50/55/60",
[76552] = "1/50/55/60",
[76553] = "1/50/55/60",
[76554] = "1/50/55/60",
[76555] = "1/50/55/60",
[76556] = "1/50/55/60",
[76557] = "1/50/55/60",
[76558] = "1/50/55/60",
[76559] = "1/50/55/60",
[76560] = "1/50/55/60",
[76561] = "1/50/55/60",
[76562] = "1/50/55/60",
[76563] = "1/50/55/60",
[76564] = "1/50/55/60",
[76565] = "1/50/55/60",
[76566] = "1/50/55/60",
[76567] = "1/50/55/60",
[76568] = "1/50/55/60",
[76569] = "1/50/55/60",
[76636] = "1/75/75/75",
[76637] = "1/75/75/75",
[76638] = "1/75/75/75",
[76639] = "1/75/75/75",
[76640] = "1/75/75/75",
[76641] = "1/75/75/75",
[76642] = "1/75/75/75",
[76643] = "1/75/75/75",
[76644] = "1/75/75/75",
[76645] = "1/75/75/75",
[76646] = "1/75/75/75",
[76647] = "1/75/75/75",
[76648] = "1/75/75/75",
[76649] = "1/75/75/75",
[76650] = "1/75/75/75",
[76651] = "1/75/75/75",
[76652] = "1/75/75/75",
[76653] = "1/75/75/75",
[76654] = "1/75/75/75",
[76656] = "1/75/75/75",
[76657] = "1/75/75/75",
[76658] = "1/75/75/75",
[76659] = "1/75/75/75",
[76660] = "1/75/75/75",
[76661] = "1/75/75/75",
[76662] = "1/75/75/75",
[76663] = "1/75/75/75",
[76664] = "1/75/75/75",
[76665] = "1/75/75/75",
[76666] = "1/75/75/75",
[76667] = "1/75/75/75",
[76668] = "1/75/75/75",
[76669] = "1/75/75/75",
[76670] = "1/75/75/75",
[76671] = "1/75/75/75",
[76672] = "1/75/75/75",
[76673] = "1/75/75/75",
[76674] = "1/75/75/75",
[76675] = "1/75/75/75",
[76676] = "1/75/75/75",
[76677] = "1/75/75/75",
[76678] = "1/75/75/75",
[76679] = "1/75/75/75",
[76680] = "1/75/75/75",
[76681] = "1/75/75/75",
[76682] = "1/75/75/75",
[76683] = "1/75/75/75",
[76684] = "1/75/75/75",
[76685] = "1/75/75/75",
[76686] = "1/75/75/75",
[76687] = "1/75/75/75",
[76688] = "1/75/75/75",
[76689] = "1/75/75/75",
[76690] = "1/75/75/75",
[76691] = "1/75/75/75",
[76692] = "1/75/75/75",
[76693] = "1/75/75/75",
[76694] = "1/75/75/75",
[76695] = "1/75/75/75",
[76696] = "1/75/75/75",
[76697] = "1/75/75/75",
[76698] = "1/75/75/75",
[76699] = "1/75/75/75",
[76700] = "1/75/75/75",
[76701] = "1/75/75/75",
[76879] = "1/75/75/75",
[76884] = "1/75/75/75",
[76885] = "1/75/75/75",
[76886] = "1/75/75/75",
[76887] = "1/75/75/75",
[76888] = "1/75/75/75",
[76890] = "1/75/75/75",
[76891] = "1/75/75/75",
[76892] = "1/75/75/75",
[76893] = "1/75/75/75",
[76894] = "1/75/75/75",
[76895] = "1/75/75/75",
[76896] = "1/75/75/75",
[76897] = "1/75/75/75",
[82453] = "1/75/75/75",
[82774] = "1/75/75/75",
[82775] = "1/75/75/75",
[83087] = "1/75/75/75",
[83088] = "1/75/75/75",
[83089] = "1/75/75/75",
[83090] = "1/75/75/75",
[83141] = "1/50/55/60",
[83142] = "1/50/55/60",
[83143] = "1/50/55/60",
[83144] = "1/50/55/60",
[83145] = "1/50/55/60",
[83146] = "1/50/55/60",
[83147] = "1/50/55/60",
[83148] = "1/50/55/60",
[83149] = "1/50/55/60",
[83150] = "1/50/55/60",
[83151] = "1/50/55/60",
[83152] = "1/50/55/60",
[83793] = "1/50/55/60",
[83794] = "1/50/55/60",
[83795] = "1/50/55/60",
[83796] = "1/75/75/75",
[83798] = "1/75/75/75",
[83799] = "1/75/75/75",
[83800] = "1/75/75/75",
[83801] = "1/75/75/75",
[83802] = "1/75/75/75",
[83803] = "1/75/75/75",
[83804] = "1/75/75/75",
[83805] = "1/75/75/75",
[83806] = "1/75/75/75",
[89674] = "1/75/75/75",
[89675] = "1/50/55/60",
[89678] = "1/50/55/60",
[89680] = "1/75/75/75",
[90395] = "1/75/75/75",
[90397] = "1/75/75/75",
[90398] = "1/75/75/75",
[90399] = "1/75/75/75",
[90400] = "1/75/75/75",
[90401] = "1/75/75/75",
[90406] = "1/75/75/75",
[93404] = "1/50/55/60",
[93405] = "1/50/55/60",
[93406] = "1/50/55/60",
[93408] = "1/50/55/60",
[93409] = "1/50/55/60",
[93410] = "1/50/55/60",
[93705] = "1/75/75/75",
[93706] = "1/50/55/60",
[95469] = "1/75/75/75",
[112384] = "1/50/55/60",
[112498] = "1/50/55/60",
[115524] = {[170700] = "1/1/50/100", [182127] = "1/100/100/100"},
[115526] = "1/100/100/100",
[115794] = "1/100/100/100",
[115796] = "1/100/100/100",
[115798] = "1/100/100/100",
[115799] = "1/100/100/100",
[115800] = "1/100/100/100",
[115801] = "1/100/100/100",
[115803] = "1/100/100/100",
[115804] = "1/100/100/100",
[115805] = "1/100/100/100",
[115807] = "1/100/100/100",
[115808] = "1/100/100/100",
[115809] = "1/100/100/100",
[115811] = "1/100/100/100",
[115812] = "1/100/100/100",
[115814] = "1/100/100/100",
[115815] = "1/100/100/100",
[115987] = "1/50/55/60",
[115988] = "1/50/55/60",
[115989] = "1/50/55/60",
[115990] = "1/50/55/60",
[115991] = "1/50/55/60",
[115992] = "1/50/55/60",
[115993] = "1/50/55/60",
[115994] = "1/50/55/60",
[115995] = "1/50/55/60",
[118723] = "1/1/50/100",
[123918] = "1/1/1/1",
[123919] = "1/1/1/1",
[127760] = "1/100/100/100",
[127761] = "1/100/100/100",
[127762] = "1/100/100/100",
[127764] = "1/100/100/100",
[127765] = "1/100/100/100",
[130215] = "1/20/35/50",
[130216] = "1/20/35/50",
[130217] = "1/20/35/50",
[130218] = "1/20/35/50",
[130219] = "1/40/55/70",
[130220] = "1/40/55/70",
[130221] = "1/40/55/70",
[130222] = "1/40/55/70",
[130223] = {[195856] = "1/20/30/40", [195902] = "1/40/50/60", [195923] = "1/60/70/80"},
[130224] = {[195857] = "1/20/30/40", [195903] = "1/40/50/60", [195924] = "1/60/70/80"},
[130225] = {[195858] = "1/20/30/40", [195904] = "1/40/50/60", [195925] = "1/60/70/80"},
[130226] = {[195859] = "1/40/50/60", [195905] = "1/60/70/80", [195926] = "1/80/90/100"},
[130227] = {[195860] = "1/40/50/60", [195906] = "1/60/70/80", [195927] = "1/80/90/100"},
[130228] = {[195861] = "1/40/50/60", [195907] = "1/60/70/80", [195928] = "1/80/90/100"},
[130229] = {[195862] = "1/40/50/60", [195908] = "1/60/70/80", [195929] = "1/80/90/100"},
[130230] = {[195863] = "1/40/50/60", [195909] = "1/60/70/80", [195930] = "1/80/90/100"},
[130231] = {[195864] = "1/40/50/60", [195910] = "1/60/70/80", [195931] = "1/80/90/100"},
[130233] = {[195865] = "1/60/70/80", [195911] = "1/80/90/100", [195932] = "1/100/100/100"},
[130234] = {[195866] = "1/60/70/80", [195912] = "1/80/90/100", [195933] = "1/100/100/100"},
[130235] = {[195867] = "1/60/70/80", [195913] = "1/80/90/100", [195934] = "1/100/100/100"},
[130236] = {[195868] = "1/60/70/80", [195914] = "1/80/90/100", [195935] = "1/100/100/100"},
[130237] = {[195869] = "1/60/70/80", [195915] = "1/80/90/100", [195936] = "1/100/100/100"},
[130238] = {[195870] = "1/60/70/80", [195916] = "1/80/90/100", [195937] = "1/100/100/100"},
[130239] = {[195871] = "1/60/70/80", [195917] = "1/80/90/100", [195938] = "1/100/100/100"},
[130240] = {[195872] = "1/60/70/80", [195918] = "1/80/90/100", [195939] = "1/100/100/100"},
[130241] = {[195873] = "1/60/70/80", [195919] = "1/80/90/100", [195940] = "1/100/100/100"},
[130242] = {[195874] = "1/60/70/80", [195920] = "1/80/90/100", [195941] = "1/100/100/100"},
[130243] = {[195875] = "1/60/70/80", [195921] = "1/80/90/100", [195942] = "1/100/100/100"},
[130244] = {[195876] = "1/60/70/80", [195922] = "1/80/90/100", [195943] = "1/100/100/100"},
[130245] = "1/70/80/90",
[130246] = "1/80/90/100",
[130247] = "1/80/90/100",
[130248] = "1/80/90/100",
[130250] = "1/20/40/60",
[130251] = "1/100/100/100",
[130254] = "1/20/40/60",
[136711] = {[209603] = "1/20/30/40", [209606] = "1/40/50/60", [209609] = "1/60/70/80"},
[136712] = {[209604] = "1/40/50/60", [209607] = "1/60/70/80", [209610] = "1/80/90/100"},
[136713] = {[209605] = "1/40/50/60", [209608] = "1/60/70/80", [209611] = "1/80/90/100"},
[151564] = "1/1/1/1",
[151580] = "1/80/90/100",
[151583] = "1/80/90/100",
[151584] = "1/80/90/100",
[151585] = "1/80/90/100",
[151587] = {[247751] = "1/90/95/100", [247754] = "1/90/95/100", [247755] = "1/90/95/100"},
[151588] = {[247756] = "1/90/95/100", [247757] = "1/90/95/100", [247758] = "1/90/95/100"},
[151589] = {[247762] = "1/90/95/100", [247763] = "1/90/95/100", [247764] = "1/90/95/100"},
[151590] = {[247765] = "1/90/95/100", [247766] = "1/90/95/100", [247767] = "1/90/95/100"},
[152512] = "1/80/85/90",
[152513] = "1/80/85/90",
[152579] = "1/80/85/90",
[153637] = "1/50/75/100",
[153638] = "1/50/75/100",
[153639] = {[256255] = "1/105/120/135", [256256] = "1/150/150/150", [256257] = "1/150/150/150"},
[153640] = {[256258] = "1/105/120/135", [256259] = "1/150/150/150", [256260] = "1/150/150/150"},
[153683] = {[256513] = "1/75/105/135", [256520] = "1/105/127/150", [256521] = "1/125/137/150"},
[153684] = {[256512] = "1/75/105/135", [256518] = "1/105/127/150", [256519] = "1/125/137/150"},
[153685] = {[256511] = "1/75/105/135", [256516] = "1/105/127/150", [256517] = "1/125/137/150"},
[153686] = {[256510] = "1/75/105/135", [256514] = "1/105/127/150", [256515] = "1/125/137/150"},
[153687] = "1/25/50/75",
[153688] = "1/25/50/75",
[153689] = "1/25/50/75",
[153690] = "1/25/50/75",
[153707] = "1/150/150/150",
[153708] = "1/150/150/150",
[153709] = "1/150/150/150",
[153710] = "1/15/50/85",
[153711] = "1/15/50/85",
[153712] = "1/15/50/85",
[153713] = "1/15/50/85",
[153714] = "1/15/50/85",
[153715] = "1/15/50/85",
[153716] = "1/150/150/150",
[154126] = "1/105/125/145",
[154127] = "1/105/125/145",
[154128] = "1/105/125/145",
[154129] = "1/105/125/145",
[159939] = {[269734] = "1/105/120/135", [269735] = "1/115/130/145", [269736] = "1/125/137/150"},
[162460] = "1/1/25/50",
[162461] = "1/1/25/50",
[164681] = {[282343] = "1/135/142/150", [282344] = "1/140/145/150", [282345] = "1/145/147/150"},
[165743] = "1/100/112/125",
[166519] = "1/140/145/150",
[166520] = "1/145/147/150",
[166521] = "1/150/150/150",
[166522] = "1/145/147/150",
[166523] = "1/150/150/150",
[166524] = "1/150/150/150",
[167943] = {[294793] = "1/165/170/175", [294794] = "1/170/172/175", [294795] = "1/175/175/175"},
[168185] = "1/150/162/175",
[168636] = "1/175/175/175",
[168637] = "1/175/175/175",
[168638] = "1/175/175/175",
[168639] = "1/165/170/175",
[168640] = "1/165/170/175",
[168641] = "1/165/170/175",
[168642] = "1/165/170/175",
[168701] = "1/175/175/175",
[168702] = "1/175/175/175",
[168703] = "1/175/175/175",
[169220] = "1/165/170/175",
[170318] = {[305168] = "1/165/170/175", [305170] = "1/165/170/175", [305171] = "1/165/170/175"},
[171075] = "1/175/175/175",
[171076] = "1/175/175/175",
[171077] = "1/175/175/175",
[171320] = "1/200/200/200",
[171828] = "1/30/45/60",
[171829] = "1/40/50/60",
[171830] = "1/40/50/60",
[171831] = "1/40/50/60",
[171832] = "1/40/50/60",
[171833] = "1/50/60/70",
[173121] = "1/25/42/60",
[173122] = "1/30/45/60",
[173123] = "1/15/37/60",
[173124] = "1/25/42/60",
[173125] = "1/30/45/60",
[173126] = "1/15/37/60",
[173127] = "1/65/82/100",
[173128] = "1/70/85/100",
[173129] = "1/65/82/100",
[173130] = "1/70/85/100",
[173131] = "1/100/100/100",
[173132] = "1/100/100/100",
[173133] = "1/100/100/100",
[173134] = "1/100/100/100",
[173135] = "1/40/50/60",
[173136] = "1/30/45/60",
[173137] = "1/35/47/60",
[173138] = "1/25/42/60",
[173140] = "1/50/62/75",
[173141] = "1/40/52/65",
[173142] = "1/50/62/75",
[173143] = "1/40/52/65",
[173144] = "1/100/100/100",
[173145] = "1/100/100/100",
[173146] = "1/100/100/100",
[173147] = "1/100/100/100",
[173381] = "1/50/52/55",
[173382] = "1/95/95/95",
[173383] = "1/100/100/100",
[173384] = "1/200/200/200",
[178926] = {[327920] = "1/100/100/100", [332039] = "1/100/100/100", [332074] = "1/100/100/100", [338978] = "1/100/100/100"},
[178927] = {[327921] = "1/100/100/100", [332040] = "1/100/100/100", [332075] = "1/100/100/100", [338977] = "1/100/100/100"},
[180760] = "1/10/15/20",
[183942] = "1/45/47/50",
[185960] = "1/100/100/100",
[186981] = "1/60/65/70",
[186982] = "1/100/100/100",
-- Unknown item created by: Northrend Designs (215) - Brilliant Scarlet Ruby (53946)
-- Invalid recipe: Legion Designs (110) - Empyrial Circlet (248937)
-- Invalid recipe: Legion Designs (110) - Empyrial Hesselian Setting (248938)
-- Invalid recipe: Legion Designs (110) - Empyrial Florid Malachite Setting (248939)
-- Invalid recipe: Legion Designs (110) - Empyrial Crown (248940)
-- Invalid recipe: Shadowlands Designs (61) - Gem Studded Bangle (338238)
-- Invalid recipe: Shadowlands Designs (61) - Engraved Phaedrum Band (338239)
-- Invalid recipe: Shadowlands Designs (61) - Polished Gemstones (338240)
-- Invalid recipe: Shadowlands Designs (61) - Gleaming Kyranite Necklace (338241)
-- Invalid recipe: Shadowlands Designs (61) - Kyranite Dangle (338242)
-- Invalid recipe: Shadowlands Designs (61) - Solenium Wire (338243)
-- Invalid recipe: Shadowlands Designs (61) - Carved Crystal Ring (338244)
-- Invalid recipe: Shadowlands Designs (61) - Hollowed Crystal (338245)
-- Invalid recipe: Shadowlands Designs (61) - Faceted Crystal (338246)
-- Invalid recipe: Shadowlands Designs (61) - Sinister Choker (338247)
-- Invalid recipe: Shadowlands Designs (61) - Brilliant Bauble (338248)
-- Invalid recipe: Shadowlands Designs (61) - Fine Sinvyr Chain (338249)



-- leatherworking
[2300] = "40/70/85/100",
[2302] = "1/40/55/70",
[2303] = "15/45/60/75",
[2304] = "1/30/45/60",
[2307] = "1/120/135/150",
[2308] = "85/105/120/135",
[2309] = "55/85/100/115",
[2310] = "60/90/105/120",
[2311] = "1/90/105/120",
[2312] = "1/105/120/135",
[2313] = "100/115/122/130",
[2314] = "120/145/157/170",
[2315] = "100/125/137/150",
[2316] = "110/135/147/160",
[2317] = "1/125/137/150",
[2318] = "1/20/30/40",
[2319] = "100/100/105/110",
[3719] = "150/170/180/190",
[4231] = "35/55/65/75",
[4233] = "100/115/122/130",
[4234] = "150/150/155/160",
[4236] = "150/160/165/170",
[4237] = "25/55/70/85",
[4239] = "55/85/100/115",
[4242] = "75/105/120/135",
[4243] = "85/115/130/145",
[4244] = "1/125/137/150",
[4246] = "80/110/125/140",
[4247] = "145/170/182/195",
[4248] = "1/155/167/180",
[4249] = "125/150/162/175",
[4250] = "1/145/157/170",
[4251] = "130/155/167/180",
[4252] = "1/165/177/190",
[4253] = "135/160/172/185",
[4254] = "1/170/180/190",
[4255] = "1/175/185/195",
[4256] = "1/195/205/215",
[4257] = "160/180/190/200",
[4258] = "1/190/200/210",
[4259] = "180/200/210/220",
[4260] = "1/215/225/235",
[4262] = "1/205/215/225",
[4264] = "1/220/230/240",
[4265] = "150/170/180/190",
[4304] = "200/200/202/205",
[4455] = "1/185/195/205",
[4456] = "1/185/195/205",
[5081] = "1/70/85/100",
[5739] = "190/210/220/230",
[5780] = "1/120/135/150",
[5781] = "1/125/140/155",
[5782] = "1/190/200/210",
[5783] = "1/210/220/230",
[5957] = "1/40/55/70",
[5958] = "1/130/142/155",
[5961] = "115/140/152/165",
[5962] = "160/180/190/200",
[5963] = "1/190/200/210",
[5964] = "175/195/205/215",
[5965] = "1/205/215/225",
[5966] = "190/210/220/230",
[6466] = "1/120/135/150",
[6467] = "1/130/142/155",
[6468] = "1/140/152/165",
[6709] = "1/115/130/145",
[7276] = "1/40/55/70",
[7277] = "1/40/55/70",
[7280] = "1/65/80/95",
[7281] = "70/100/115/130",
[7282] = "95/125/140/155",
[7283] = "1/125/137/150",
[7284] = "1/145/157/170",
[7285] = "120/145/157/170",
[7348] = "125/150/162/175",
[7349] = "1/160/172/185",
[7352] = "1/160/172/185",
[7358] = "1/165/177/190",
[7359] = "1/170/182/195",
[7373] = "1/185/195/205",
[7374] = "175/195/205/215",
[7375] = "1/195/205/215",
[7377] = "180/200/210/220",
[7378] = "185/205/215/225",
[7386] = "1/210/220/230",
[7387] = "195/215/225/235",
[7390] = "1/220/230/240",
[7391] = "1/220/230/240",
[8170] = "250/250/250/250",
[8172] = "200/200/200/200",
[8173] = "200/220/230/240",
[8174] = "1/220/230/240",
[8175] = "205/225/235/245",
[8176] = "205/225/235/245",
[8185] = "235/255/265/275",
[8187] = "1/225/235/245",
[8189] = "210/230/240/250",
[8191] = "230/250/260/270",
[8192] = "1/230/240/250",
[8193] = "230/250/260/270",
[8197] = "235/255/265/275",
[8198] = "210/230/240/250",
[8200] = "1/235/245/255",
[8201] = "1/240/250/260",
[8202] = "1/260/270/280",
[8203] = "1/240/250/260",
[8204] = "1/245/255/265",
[8205] = "1/240/250/260",
[8206] = "1/265/275/285",
[8207] = "1/260/270/280",
[8208] = "1/270/280/290",
[8209] = "1/255/265/275",
[8210] = "1/240/250/260",
[8211] = "1/245/255/265",
[8212] = "1/270/280/290",
[8213] = "1/265/275/285",
[8214] = "1/245/255/265",
[8215] = "1/270/280/290",
[8216] = "1/260/270/280",
[8345] = "1/245/255/265",
[8346] = "230/250/260/270",
[8347] = "1/245/255/265",
[8348] = "250/270/280/290",
[8349] = "250/270/280/290",
[8367] = "255/275/285/295",
[15045] = "1/280/290/300",
[15046] = "1/290/300/310",
[15047] = "1/320/330/340",
[15048] = "1/305/315/325",
[15049] = "1/315/325/335",
[15050] = "1/310/320/330",
[15051] = "1/320/330/340",
[15052] = "1/320/330/340",
[15053] = "1/305/315/325",
[15054] = "1/290/300/310",
[15055] = "1/320/330/340",
[15056] = "1/305/315/325",
[15057] = "1/295/305/315",
[15058] = "1/315/325/335",
[15059] = "1/320/330/340",
[15060] = "1/305/315/325",
[15061] = "1/290/300/310",
[15062] = "1/320/330/340",
[15063] = "1/310/320/330",
[15064] = "1/295/305/315",
[15065] = "1/305/315/325",
[15066] = "1/310/320/330",
[15067] = "1/290/300/310",
[15068] = "1/320/330/340",
[15069] = "1/305/315/325",
[15070] = "1/315/325/335",
[15071] = "1/295/305/315",
[15072] = "1/300/310/320",
[15073] = "1/295/305/315",
[15074] = "1/285/295/305",
[15075] = "1/310/320/330",
[15076] = "1/285/295/305",
[15077] = "1/275/285/295",
[15078] = "1/295/305/315",
[15079] = "1/305/315/325",
[15080] = "1/315/325/335",
[15081] = "1/320/330/340",
[15082] = "1/300/310/320",
[15083] = "1/280/290/300",
[15084] = "265/285/295/305",
[15085] = "300/320/330/340",
[15086] = "280/300/310/320",
[15087] = "290/310/320/330",
[15088] = "300/320/330/340",
[15090] = "300/320/330/340",
[15091] = "270/290/300/310",
[15092] = "275/295/305/315",
[15093] = "280/300/310/320",
[15094] = "290/310/320/330",
[15095] = "300/320/330/340",
[15096] = "300/320/330/340",
[15138] = "1/320/330/340",
[15407] = "250/250/255/260",
[15564] = "250/255/265/275",
[16982] = "1/315/325/335",
[16983] = "1/320/330/340",
[16984] = "1/320/330/340",
[17721] = "1/210/220/230",
[18238] = "1/210/220/230",
[18251] = "1/320/330/340",
[18258] = "1/285/290/295",
[18504] = "1/320/330/340",
[18506] = "1/320/330/340",
[18508] = "1/320/330/340",
[18509] = "1/320/330/340",
[18510] = "1/320/330/340",
[18511] = "1/320/330/340",
[18662] = "1/150/155/160",
[18948] = "1/175/185/195",
[19044] = "1/310/320/330",
[19049] = "1/320/330/340",
[19052] = "1/310/320/330",
[19058] = "1/320/330/340",
[19149] = "1/320/330/340",
[19157] = "1/320/330/340",
[19162] = "1/320/330/340",
[19163] = "1/320/330/340",
[19685] = "1/320/330/340",
[19686] = "1/320/330/340",
[19687] = "1/320/330/340",
[19688] = "1/320/330/340",
[19689] = "1/320/330/340",
[20295] = "300/320/330/340",
[20296] = "280/300/310/320",
[20380] = "1/320/330/340",
[20476] = "1/320/330/340",
[20477] = "1/320/330/340",
[20478] = "1/320/330/340",
[20479] = "1/320/330/340",
[20480] = "1/320/330/340",
[20481] = "1/320/330/340",
[20575] = "1/125/137/150",
[21278] = "1/320/330/340",
[21887] = "1/1/5/10",
[22661] = "1/320/330/340",
[22662] = "1/320/330/340",
[22663] = "1/320/330/340",
[22664] = "1/320/330/340",
[22665] = "1/320/330/340",
[22666] = "1/320/330/340",
[22759] = "1/320/330/340",
[22760] = "1/320/330/340",
[22761] = "1/320/330/340",
[23793] = "1/25/30/35",
[25650] = "1/10/25/40",
[25651] = "1/35/40/45",
[25652] = "1/35/40/45",
[25653] = "1/60/67/75",
[25654] = "1/10/20/30",
[25655] = "1/20/30/40",
[25656] = "1/30/40/50",
[25657] = "1/45/55/65",
[25659] = "1/45/55/65",
[25660] = "1/35/45/55",
[25661] = "1/20/30/40",
[25662] = "1/10/20/30",
[25668] = "1/30/40/50",
[25669] = "1/10/20/30",
[25670] = "1/25/35/45",
[25671] = "1/40/50/60",
[25673] = "1/10/20/30",
[25674] = "1/20/30/40",
[25675] = "1/30/40/50",
[25676] = "1/40/50/60",
[25679] = "1/1/5/10",
[25680] = "1/60/67/75",
[25681] = "1/60/67/75",
[25682] = "1/60/67/75",
[25683] = "1/60/67/75",
[25685] = "1/50/60/70",
[25686] = "1/60/67/75",
[25687] = "1/60/67/75",
[25689] = "1/70/72/75",
[25690] = "1/65/70/75",
[25691] = "1/65/70/75",
[25692] = "1/50/60/70",
[25693] = "1/60/67/75",
[25694] = "1/50/60/70",
[25695] = "1/60/67/75",
[25696] = "1/70/72/75",
[25697] = "1/70/72/75",
[25699] = "1/1/5/10",
[25700] = "1/1/5/10",
[25707] = "1/1/5/10",
[25708] = "1/1/5/10",
[29489] = "1/60/67/75",
[29490] = "1/60/67/75",
[29491] = "1/60/67/75",
[29492] = "1/60/67/75",
[29493] = "1/60/67/75",
[29494] = "1/60/67/75",
[29495] = "1/60/67/75",
[29496] = "1/60/67/75",
[29497] = "1/60/67/75",
[29498] = "1/60/67/75",
[29499] = "1/60/67/75",
[29500] = "1/60/67/75",
[29502] = "1/75/75/75",
[29503] = "1/75/75/75",
[29504] = "1/75/75/75",
[29505] = "1/75/75/75",
[29506] = "1/75/75/75",
[29507] = "1/75/75/75",
[29508] = "1/75/75/75",
[29509] = "1/75/75/75",
[29510] = "1/75/75/75",
[29511] = "1/75/75/75",
[29512] = "1/75/75/75",
[29514] = "1/75/75/75",
[29515] = "1/75/75/75",
[29516] = "1/75/75/75",
[29517] = "1/75/75/75",
[29519] = "1/75/75/75",
[29520] = "1/75/75/75",
[29521] = "1/75/75/75",
[29522] = "1/75/75/75",
[29523] = "1/75/75/75",
[29524] = "1/75/75/75",
[29525] = "1/75/75/75",
[29526] = "1/75/75/75",
[29527] = "1/75/75/75",
[29528] = "1/40/47/55",
[29529] = "1/65/70/75",
[29530] = "1/45/52/60",
[29531] = "1/50/57/65",
[29532] = "1/70/72/75",
[29533] = "1/35/45/55",
[29534] = "1/35/45/55",
[29535] = "1/65/70/75",
[29536] = "1/65/70/75",
[29539] = "1/1/5/10",
[29540] = "1/35/40/45",
[29547] = "1/1/5/10",
[29548] = "1/1/5/10",
[29964] = "260/300/300/300",
[29970] = "260/300/300/300",
[29971] = "260/300/300/300",
[29973] = "1/50/60/70",
[29974] = "1/50/60/70",
[29975] = "1/50/60/70",
[30039] = "1/75/75/75",
[30040] = "1/75/75/75",
[30041] = "1/75/75/75",
[30042] = "1/75/75/75",
[30043] = "1/75/75/75",
[30044] = "1/75/75/75",
[30045] = "1/75/75/75",
[30046] = "1/75/75/75",
[32393] = "1/75/75/75",
[32394] = "1/75/75/75",
[32395] = "1/75/75/75",
[32396] = "1/75/75/75",
[32397] = "1/75/75/75",
[32398] = "1/75/75/75",
[32399] = "1/75/75/75",
[32400] = "1/75/75/75",
[32574] = "1/375/375/375",
[32575] = "1/375/375/375",
[32577] = "1/375/375/375",
[32579] = "1/375/375/375",
[32580] = "1/375/375/375",
[32581] = "1/75/75/75",
[32582] = "1/375/375/375",
[32583] = "1/375/375/375",
[33122] = "1/70/72/75",
[33204] = "1/75/75/75",
[33568] = "1/1/3/5",
[34105] = "1/60/67/75",
[34207] = "1/55/60/65",
[34330] = "1/55/60/65",
[34369] = "1/365/365/365",
[34370] = "1/365/365/365",
[34371] = "1/365/365/365",
[34372] = "1/365/365/365",
[34373] = "1/365/365/365",
[34374] = "1/365/365/365",
[34375] = "1/365/365/365",
[34376] = "1/365/365/365",
[34482] = "1/10/20/30",
[34490] = "1/350/350/350",
[38347] = "1/45/47/50",
[38371] = "1/35/40/45",
[38372] = "1/30/35/40",
[38373] = "1/60/65/70",
[38374] = "1/60/65/70",
[38375] = "1/1/5/10",
[38376] = "1/25/27/30",
[38399] = "1/45/47/50",
[38400] = "1/10/20/30",
[38401] = "1/15/25/35",
[38402] = "1/20/30/40",
[38403] = "1/15/25/35",
[38404] = "1/10/20/30",
[38405] = "1/20/30/40",
[38406] = "1/5/12/20",
[38407] = "1/15/25/35",
[38408] = "1/15/25/35",
[38409] = "1/10/20/30",
[38410] = "1/10/20/30",
[38411] = "1/20/30/40",
[38412] = "1/10/20/30",
[38413] = "1/20/30/40",
[38414] = "1/15/25/35",
[38415] = "1/20/30/40",
[38416] = "1/10/20/30",
[38417] = "1/20/30/40",
[38418] = "1/15/25/35",
[38419] = "1/20/30/40",
[38420] = "1/15/25/35",
[38421] = "1/10/20/30",
[38422] = "1/10/20/30",
[38424] = "1/15/25/35",
[38425] = "1/10/20/30",
[38433] = "1/25/35/45",
[38434] = "1/25/35/45",
[38435] = "1/25/35/45",
[38436] = "1/25/35/45",
[38437] = "1/25/35/45",
[38438] = "1/25/35/45",
[38439] = "1/25/35/45",
[38440] = "1/25/35/45",
[38441] = "1/15/25/35",
[38557] = "1/1/3/5",
[38558] = "1/1/3/5",
[38561] = "1/1/3/5",
[38590] = "1/40/50/60",
[38591] = "1/35/45/55",
[38592] = "1/35/45/55",
[41238] = "1/30/40/50",
[42731] = "1/55/60/65",
[43129] = "1/55/60/65",
[43130] = "1/50/55/60",
[43131] = "1/50/55/60",
[43132] = "1/55/60/65",
[43133] = "1/50/55/60",
[43255] = "1/50/55/60",
[43256] = "1/50/55/60",
[43257] = "1/55/60/65",
[43258] = "1/50/55/60",
[43260] = "1/50/55/60",
[43261] = "1/50/55/60",
[43262] = "1/50/55/60",
[43263] = "1/50/55/60",
[43264] = "1/50/55/60",
[43265] = "1/55/60/65",
[43266] = "1/55/60/65",
[43271] = "1/55/60/65",
[43273] = "1/55/60/65",
[43433] = "1/50/55/60",
[43434] = "1/50/55/60",
[43435] = "1/50/55/60",
[43436] = "1/55/60/65",
[43437] = "1/55/60/65",
[43438] = "1/55/60/65",
[43439] = "1/55/60/65",
[43442] = "1/55/60/65",
[43443] = "1/55/60/65",
[43444] = "1/50/55/60",
[43445] = "1/50/55/60",
[43446] = "1/55/60/65",
[43447] = "1/50/55/60",
[43448] = "1/55/60/65",
[43449] = "1/50/55/60",
[43450] = "1/55/60/65",
[43451] = "1/55/60/65",
[43452] = "1/50/55/60",
[43453] = "1/50/55/60",
[43454] = "1/55/60/65",
[43455] = "1/50/55/60",
[43456] = "1/55/60/65",
[43457] = "1/50/55/60",
[43458] = "1/75/75/75",
[43459] = "1/75/75/75",
[43461] = "1/75/75/75",
[43469] = "1/75/75/75",
[43481] = "1/75/75/75",
[43484] = "1/75/75/75",
[43495] = "1/75/75/75",
[43502] = "1/75/75/75",
[43565] = "1/75/75/75",
[43566] = "1/75/75/75",
[43590] = "1/60/67/75",
[43591] = "1/55/65/75",
[43592] = "1/55/65/75",
[43593] = "1/60/67/75",
[43594] = "1/55/65/75",
[43595] = "1/55/65/75",
[44436] = "1/35/45/55",
[44437] = "1/35/45/55",
[44438] = "1/40/50/60",
[44440] = "1/35/45/55",
[44441] = "1/35/45/55",
[44442] = "1/40/50/60",
[44443] = "1/35/45/55",
[44444] = "1/35/45/55",
[44445] = "1/40/50/60",
[44446] = "1/45/47/50",
[44930] = "1/75/75/75",
[44931] = "1/75/75/75",
[44963] = "1/60/65/70",
[45553] = "1/75/75/75",
[45554] = "1/75/75/75",
[45555] = "1/75/75/75",
[45556] = "1/75/75/75",
[45562] = "1/75/75/75",
[45563] = "1/75/75/75",
[45564] = "1/75/75/75",
[45565] = "1/75/75/75",
[47576] = "1/75/75/75",
[47577] = "1/75/75/75",
[47579] = "1/75/75/75",
[47580] = "1/75/75/75",
[47581] = "1/75/75/75",
[47582] = "1/75/75/75",
[47583] = "1/75/75/75",
[47584] = "1/75/75/75",
[47595] = "1/75/75/75",
[47596] = "1/75/75/75",
[47597] = "1/75/75/75",
[47598] = "1/75/75/75",
[47599] = "1/75/75/75",
[47600] = "1/75/75/75",
[47601] = "1/75/75/75",
[47602] = "1/75/75/75",
[49633] = "1/65/70/75",
[49634] = "1/65/70/75",
[49894] = "1/75/75/75",
[49895] = "1/75/75/75",
[49896] = "1/75/75/75",
[49897] = "1/75/75/75",
[49898] = "1/75/75/75",
[49899] = "1/75/75/75",
[49900] = "1/75/75/75",
[49901] = "1/75/75/75",
[52976] = "1/1/3/5",
[52979] = "1/1/3/5",
[52982] = "1/1/3/5",
[56477] = "1/1/3/5",
[56480] = "1/425/425/425",
[56481] = "1/425/425/425",
[56482] = "1/425/425/425",
[56483] = "1/425/425/425",
[56484] = "1/425/425/425",
[56489] = "1/425/425/425",
[56490] = "1/425/425/425",
[56491] = "1/425/425/425",
[56494] = "1/425/425/425",
[56495] = "1/425/425/425",
[56498] = "1/425/425/425",
[56499] = "1/425/425/425",
[56502] = "1/425/425/425",
[56503] = "1/425/425/425",
[56504] = "1/425/425/425",
[56505] = "1/425/425/425",
[56508] = "1/425/425/425",
[56509] = "1/425/425/425",
[56512] = "1/425/425/425",
[56513] = "1/425/425/425",
[56516] = "1/425/425/425",
[56517] = "1/425/425/425",
[56518] = "1/425/425/425",
[56519] = "1/425/425/425",
[56536] = "1/70/72/75",
[56537] = "1/70/72/75",
[56538] = "1/70/72/75",
[56539] = "1/70/72/75",
[56548] = "1/75/75/75",
[56549] = "1/75/75/75",
[56550] = "1/75/75/75",
[56551] = "1/75/75/75",
[56561] = "1/75/75/75",
[56562] = "1/75/75/75",
[56563] = "1/75/75/75",
[56564] = "1/75/75/75",
[69939] = "1/75/75/75",
[69941] = "1/75/75/75",
[69942] = "1/75/75/75",
[69943] = "1/75/75/75",
[69949] = "1/75/75/75",
[69950] = "1/75/75/75",
[69951] = "1/75/75/75",
[69952] = "1/75/75/75",
[70136] = "1/70/72/75",
[70137] = "1/70/72/75",
[71720] = "1/75/75/75",
[71985] = "1/75/75/75",
[71986] = "1/75/75/75",
[71987] = "1/75/75/75",
[71988] = "1/75/75/75",
[71994] = "1/75/75/75",
[71995] = "1/75/75/75",
[71996] = "1/75/75/75",
[71997] = "1/75/75/75",
[72120] = "1/1/5/10",
[72163] = {[131865] = "1/25/40/55", [140040] = "1/75/75/75", [140041] = "1/75/75/75"},
[75061] = "1/75/75/75",
[75076] = "1/60/62/65",
[75077] = "1/60/62/65",
[75080] = "1/75/75/75",
[75081] = "1/70/72/75",
[75083] = "1/70/72/75",
[75084] = "1/75/75/75",
[75085] = "1/65/70/75",
[75090] = "1/75/75/75",
[75092] = "1/70/72/75",
[75094] = "1/65/70/75",
[75097] = "1/75/75/75",
[75099] = "1/75/75/75",
[75100] = "1/75/75/75",
[75101] = "1/70/72/75",
[75102] = "1/75/75/75",
[75103] = "1/75/75/75",
[75104] = "1/65/70/75",
[75105] = "1/75/75/75",
[75106] = "1/65/70/75",
[75107] = "1/75/75/75",
[75108] = "1/75/75/75",
[75109] = "1/70/72/75",
[75110] = "1/70/72/75",
[75111] = "1/75/75/75",
[75112] = "1/75/75/75",
[75113] = "1/70/72/75",
[75114] = "1/65/70/75",
[75115] = "1/75/75/75",
[75116] = "1/65/70/75",
[75117] = "1/65/70/75",
[75127] = "1/75/75/75",
[75130] = "1/70/72/75",
[75131] = "1/65/70/75",
[79101] = "1/1/5/10",
[83763] = "1/75/75/75",
[83764] = "1/75/75/75",
[83765] = "1/75/75/75",
[85559] = "1/10/15/20",
[85568] = "1/25/40/55",
[85569] = "1/35/50/65",
[85570] = "1/45/57/70",
[85787] = "1/75/75/75",
[85788] = "1/75/75/75",
[85789] = "1/75/75/75",
[85790] = "1/75/75/75",
[85791] = "1/75/75/75",
[85792] = "1/75/75/75",
[85793] = "1/75/75/75",
[85794] = "1/75/75/75",
[85795] = "1/75/75/75",
[85796] = "1/75/75/75",
[85797] = "1/75/75/75",
[85798] = "1/75/75/75",
[85799] = "1/75/75/75",
[85800] = "1/75/75/75",
[85801] = "1/75/75/75",
[85802] = "1/75/75/75",
[85803] = "1/75/75/75",
[85804] = "1/75/75/75",
[85805] = "1/75/75/75",
[85806] = "1/75/75/75",
[85807] = "1/75/75/75",
[85808] = "1/75/75/75",
[85809] = "1/75/75/75",
[85810] = "1/75/75/75",
[85811] = "1/75/75/75",
[85812] = "1/75/75/75",
[85813] = "1/75/75/75",
[85814] = "1/75/75/75",
[85815] = "1/75/75/75",
[85816] = "1/75/75/75",
[85817] = "1/75/75/75",
[85818] = "1/75/75/75",
[85819] = "1/75/75/75",
[85820] = "1/75/75/75",
[85821] = "1/75/75/75",
[85822] = "1/75/75/75",
[85823] = "1/75/75/75",
[85824] = "1/75/75/75",
[85825] = "1/75/75/75",
[85826] = "1/75/75/75",
[85827] = "1/75/75/75",
[85828] = "1/75/75/75",
[85829] = "1/75/75/75",
[85830] = "1/75/75/75",
[85831] = "1/75/75/75",
[85832] = "1/25/40/55",
[85833] = "1/15/30/45",
[85834] = "1/20/35/50",
[85835] = "1/50/62/75",
[85836] = "1/35/50/65",
[85837] = "1/45/57/70",
[85838] = "1/40/55/70",
[85839] = "1/30/45/60",
[85840] = "1/75/75/75",
[85841] = "1/20/35/50",
[85842] = "1/25/40/55",
[85843] = "1/15/30/45",
[85844] = "1/45/57/70",
[85845] = "1/30/45/60",
[85846] = "1/40/55/70",
[85847] = "1/50/62/75",
[85848] = "1/35/50/65",
[85849] = "1/75/75/75",
[85850] = "1/75/75/75",
[85851] = "1/45/57/70",
[85852] = "1/50/62/75",
[85853] = "1/50/62/75",
[93458] = "1/75/75/75",
[93459] = "1/75/75/75",
[93460] = "1/75/75/75",
[93461] = "1/75/75/75",
[93462] = "1/75/75/75",
[93463] = "1/75/75/75",
[93464] = "1/75/75/75",
[93465] = "1/75/75/75",
[93466] = "1/75/75/75",
[93467] = "1/75/75/75",
[93468] = "1/75/75/75",
[93469] = "1/75/75/75",
[93470] = "1/75/75/75",
[93472] = "1/75/75/75",
[93473] = "1/75/75/75",
[93474] = "1/75/75/75",
[93475] = "1/75/75/75",
[93476] = "1/75/75/75",
[93477] = "1/75/75/75",
[93478] = "1/75/75/75",
[93479] = "1/75/75/75",
[93488] = "1/75/75/75",
[93489] = "1/75/75/75",
[93490] = "1/75/75/75",
[93491] = "1/75/75/75",
[93492] = "1/75/75/75",
[93493] = "1/75/75/75",
[93494] = "1/75/75/75",
[93495] = "1/75/75/75",
[93496] = "1/75/75/75",
[93497] = "1/75/75/75",
[93498] = "1/75/75/75",
[93504] = "1/75/75/75",
[93505] = "1/75/75/75",
[93506] = "1/75/75/75",
[93507] = "1/75/75/75",
[93509] = "1/75/75/75",
[93511] = "1/75/75/75",
[93513] = "1/75/75/75",
[93515] = "1/75/75/75",
[93517] = "1/75/75/75",
[93519] = "1/75/75/75",
[93521] = "1/75/75/75",
[93523] = "1/75/75/75",
[93525] = "1/75/75/75",
[93566] = "1/75/75/75",
[93567] = "1/75/75/75",
[93568] = "1/75/75/75",
[93569] = "1/75/75/75",
[93570] = "1/75/75/75",
[93571] = "1/75/75/75",
[93572] = "1/75/75/75",
[93573] = "1/75/75/75",
[93574] = "1/75/75/75",
[93575] = "1/75/75/75",
[93576] = "1/75/75/75",
[93577] = "1/75/75/75",
[93578] = "1/75/75/75",
[93579] = "1/75/75/75",
[93580] = "1/75/75/75",
[93581] = "1/75/75/75",
[93582] = "1/75/75/75",
[93583] = "1/75/75/75",
[93584] = "1/75/75/75",
[93585] = "1/75/75/75",
[93586] = "1/75/75/75",
[93587] = "1/75/75/75",
[93588] = "1/75/75/75",
[93589] = "1/75/75/75",
[93590] = "1/75/75/75",
[93591] = "1/75/75/75",
[93592] = "1/75/75/75",
[93593] = "1/75/75/75",
[93594] = "1/75/75/75",
[94269] = "1/75/75/75",
[94270] = "1/75/75/75",
[94271] = "1/75/75/75",
[94272] = "1/75/75/75",
[94273] = "1/75/75/75",
[94274] = "1/75/75/75",
[94275] = "1/75/75/75",
[94276] = "1/75/75/75",
[95536] = "1/70/72/75",
[98600] = "1/75/75/75",
[98601] = "1/75/75/75",
[98604] = "1/75/75/75",
[98605] = "1/75/75/75",
[98609] = "1/75/75/75",
[98610] = "1/75/75/75",
[98613] = "1/75/75/75",
[98614] = "1/75/75/75",
[98617] = {[142976] = "1/75/75/75", [146923] = "1/75/75/75"},
[98789] = "1/75/75/75",
[98790] = "1/75/75/75",
[98791] = "1/75/75/75",
[98792] = "1/75/75/75",
[98793] = "1/75/75/75",
[98794] = "1/75/75/75",
[98795] = "1/75/75/75",
[98796] = "1/75/75/75",
[98797] = "1/75/75/75",
[98798] = "1/75/75/75",
[98799] = "1/75/75/75",
[98800] = "1/75/75/75",
[98801] = "1/75/75/75",
[98802] = "1/75/75/75",
[98803] = "1/75/75/75",
[98804] = "1/75/75/75",
[98805] = "1/75/75/75",
[98806] = "1/75/75/75",
[98807] = "1/75/75/75",
[98808] = "1/75/75/75",
[98809] = "1/75/75/75",
[98814] = "1/75/75/75",
[98815] = "1/75/75/75",
[98816] = "1/75/75/75",
[98817] = "1/75/75/75",
[98818] = "1/75/75/75",
[98819] = "1/75/75/75",
[98820] = "1/75/75/75",
[98821] = "1/75/75/75",
[98822] = "1/75/75/75",
[98823] = "1/75/75/75",
[98824] = "1/75/75/75",
[98830] = "1/75/75/75",
[98831] = "1/75/75/75",
[98832] = "1/75/75/75",
[98833] = "1/75/75/75",
[98834] = "1/75/75/75",
[98835] = "1/75/75/75",
[98836] = "1/75/75/75",
[98837] = "1/75/75/75",
[98838] = "1/75/75/75",
[98839] = "1/75/75/75",
[98840] = "1/75/75/75",
[98841] = "1/75/75/75",
[98842] = "1/75/75/75",
[98881] = "1/75/75/75",
[98882] = "1/75/75/75",
[98883] = "1/75/75/75",
[98884] = "1/75/75/75",
[98885] = "1/75/75/75",
[98886] = "1/75/75/75",
[98887] = "1/75/75/75",
[98888] = "1/75/75/75",
[98889] = "1/75/75/75",
[98890] = "1/75/75/75",
[98891] = "1/75/75/75",
[98892] = "1/75/75/75",
[98893] = "1/75/75/75",
[98894] = "1/75/75/75",
[98895] = "1/75/75/75",
[98896] = "1/75/75/75",
[98897] = "1/75/75/75",
[98898] = "1/75/75/75",
[98899] = "1/75/75/75",
[98900] = "1/75/75/75",
[98901] = "1/75/75/75",
[98902] = "1/75/75/75",
[98903] = "1/75/75/75",
[98904] = "1/75/75/75",
[98905] = "1/75/75/75",
[98906] = "1/75/75/75",
[98907] = "1/75/75/75",
[98908] = "1/75/75/75",
[98909] = "1/75/75/75",
[102351] = "1/70/72/75",
[108883] = "1/100/100/100",
[110611] = {[171391] = "1/1/50/100", [182121] = "1/100/100/100"},
[116164] = "1/50/55/60",
[116165] = "1/50/55/60",
[116166] = "1/50/55/60",
[116167] = "1/50/55/60",
[116168] = "1/50/55/60",
[116169] = "1/50/55/60",
[116170] = "1/100/100/100",
[116171] = "1/100/100/100",
[116174] = "1/100/100/100",
[116175] = "1/100/100/100",
[116176] = "1/100/100/100",
[116177] = "1/100/100/100",
[116178] = "1/100/100/100",
[116179] = "1/100/100/100",
[116180] = "1/100/100/100",
[116181] = "1/100/100/100",
[116182] = "1/100/100/100",
[116183] = "1/100/100/100",
[116187] = "1/100/100/100",
[116188] = "1/100/100/100",
[116189] = "1/100/100/100",
[116190] = "1/100/100/100",
[116191] = "1/100/100/100",
[116192] = "1/100/100/100",
[116193] = "1/100/100/100",
[116194] = "1/100/100/100",
[116259] = "1/100/100/100",
[116260] = "1/100/100/100",
[116261] = "1/100/100/100",
[116986] = "1/1/1/1",
[116987] = "1/1/1/1",
[116988] = "1/1/1/1",
[116989] = "1/1/1/1",
[116990] = "1/1/1/1",
[116991] = "1/1/1/1",
[116992] = "1/1/1/1",
[116993] = "1/1/1/1",
[116994] = "1/1/1/1",
[116995] = "1/1/1/1",
[116996] = "1/1/1/1",
[116997] = "1/1/1/1",
[116998] = "1/1/1/1",
[117000] = "1/1/1/1",
[117001] = "1/1/1/1",
[117002] = "1/1/1/1",
[117003] = "1/1/1/1",
[117004] = "1/1/1/1",
[117005] = "1/1/1/1",
[117006] = "1/1/1/1",
[117007] = "1/1/1/1",
[117008] = "1/1/1/1",
[117009] = "1/1/1/1",
[118721] = "1/1/50/100",
[120257] = "1/50/55/60",
[128876] = {[194702] = "1/20/30/40", [194710] = "1/40/50/60", [194718] = "1/60/70/80"},
[128877] = {[194701] = "1/20/30/40", [194709] = "1/40/50/60", [194715] = "1/60/70/80"},
[128878] = {[194700] = "1/20/30/40", [194708] = "1/40/50/60", [194714] = "1/60/70/80"},
[128879] = {[194699] = "1/20/30/40", [194707] = "1/40/50/60", [194713] = "1/60/70/80"},
[128880] = {[194698] = "1/20/30/40", [194706] = "1/40/50/60", [194712] = "1/60/70/80"},
[128881] = {[194697] = "1/20/30/40", [194705] = "1/40/50/60", [194717] = "1/60/70/80"},
[128882] = {[194696] = "1/20/30/40", [194704] = "1/40/50/60", [194716] = "1/60/70/80"},
[128883] = {[194695] = "1/20/30/40", [194703] = "1/40/50/60", [194711] = "1/60/70/80"},
[128884] = {[194726] = "1/80/90/100", [194734] = "1/100/100/100", [194791] = "1/60/70/80"},
[128885] = {[194725] = "1/80/90/100", [194733] = "1/100/100/100", [194785] = "1/60/70/80"},
[128886] = {[194724] = "1/80/90/100", [194732] = "1/100/100/100", [194790] = "1/60/70/80"},
[128887] = {[194723] = "1/80/90/100", [194731] = "1/100/100/100", [194784] = "1/60/70/80"},
[128888] = {[194722] = "1/80/90/100", [194730] = "1/100/100/100", [194786] = "1/60/70/80"},
[128889] = {[194721] = "1/80/90/100", [194729] = "1/100/100/100", [194789] = "1/60/70/80"},
[128890] = {[194720] = "1/80/90/100", [194728] = "1/100/100/100", [194788] = "1/60/70/80"},
[128891] = {[194719] = "1/80/90/100", [194727] = "1/100/100/100", [194787] = "1/60/70/80"},
[128892] = {[194742] = "1/20/30/40", [194750] = "1/40/50/60", [194758] = "1/60/70/80"},
[128893] = {[194741] = "1/20/30/40", [194749] = "1/40/50/60", [194755] = "1/60/70/80"},
[128894] = {[194740] = "1/20/30/40", [194748] = "1/40/50/60", [194754] = "1/60/70/80"},
[128895] = {[194739] = "1/20/30/40", [194747] = "1/40/50/60", [194753] = "1/60/70/80"},
[128896] = {[194738] = "1/20/30/40", [194746] = "1/40/50/60", [194752] = "1/60/70/80"},
[128897] = {[194737] = "1/20/30/40", [194745] = "1/40/50/60", [194757] = "1/60/70/80"},
[128898] = {[194736] = "1/20/30/40", [194744] = "1/40/50/60", [194756] = "1/60/70/80"},
[128899] = {[194735] = "1/20/30/40", [194743] = "1/40/50/60", [194751] = "1/60/70/80"},
[128900] = {[194766] = "1/80/90/100", [194774] = "1/100/100/100", [194795] = "1/60/70/80"},
[128901] = {[194765] = "1/80/90/100", [194773] = "1/100/100/100", [194793] = "1/60/70/80"},
[128902] = {[194764] = "1/80/90/100", [194772] = "1/100/100/100", [194799] = "1/60/70/80"},
[128903] = {[194763] = "1/80/90/100", [194771] = "1/100/100/100", [194794] = "1/60/70/80"},
[128904] = {[194762] = "1/80/90/100", [194770] = "1/100/100/100", [194792] = "1/60/70/80"},
[128905] = {[194761] = "1/80/90/100", [194769] = "1/100/100/100", [194798] = "1/60/70/80"},
[128906] = {[194760] = "1/80/90/100", [194768] = "1/100/100/100", [194797] = "1/60/70/80"},
[128907] = {[194759] = "1/80/90/100", [194767] = "1/100/100/100", [194796] = "1/60/70/80"},
[129956] = "1/20/45/70",
[129958] = "1/20/32/45",
[129960] = "1/20/45/70",
[129961] = "1/20/45/70",
[129962] = "1/100/100/100",
[129963] = "1/1/1/1",
[129964] = "1/1/1/1",
[129975] = "1/1/1/1",
[130090] = "1/1/1/1",
[130130] = "1/1/1/1",
[130869] = "1/1/1/1",
[130870] = "1/1/1/1",
[130872] = "1/1/1/1",
[130873] = {[196383] = "1/1/1/1", [196384] = "1/1/1/1"},
[130875] = {[196385] = "1/1/1/1", [208615] = "1/1/1/1"},
[130878] = "1/1/1/1",
[130879] = "1/1/1/1",
[130880] = "1/1/1/1",
[130887] = "1/1/1/1",
[130894] = "1/1/1/1",
[130895] = "1/1/1/1",
[130896] = "1/1/1/1",
[130937] = "1/1/1/1",
[131746] = "1/20/32/45",
[132487] = "85/115/130/145",
[132488] = "90/120/135/150",
[132489] = "70/110/125/140",
[132490] = "55/85/100/115",
[132491] = "70/100/115/130",
[132492] = "105/125/140/155",
[132493] = "95/125/137/150",
[132494] = "95/125/137/150",
[132495] = "120/150/162/175",
[132496] = "105/135/147/160",
[132497] = "110/140/152/165",
[132498] = "130/160/172/185",
[132499] = "115/145/157/170",
[132520] = "165/195/205/215",
[132521] = "190/220/230/240",
[132522] = "185/215/225/235",
[132532] = "155/185/195/205",
[132533] = "140/170/180/190",
[132534] = "150/180/190/200",
[132535] = "165/195/205/215",
[132536] = "190/220/230/240",
[132537] = "190/220/230/240",
[132538] = "165/195/205/215",
[132539] = "160/190/200/210",
[132540] = "180/210/220/230",
[132541] = "185/215/225/235",
[132542] = "150/180/190/200",
[132543] = "125/155/167/180",
[132544] = "190/220/230/240",
[132545] = "85/125/137/150",
[132546] = "135/165/175/185",
[132547] = "100/130/142/155",
[132548] = "90/120/135/150",
[136539] = "1/1/1/1",
[142406] = {[230936] = "1/20/40/60", [230954] = "1/40/50/60", [230955] = "1/60/70/80"},
[146668] = "1/100/100/100",
[146669] = "1/100/100/100",
[151577] = {[247800] = "1/90/95/100", [247801] = "1/90/95/100", [247802] = "1/90/95/100"},
[151578] = {[247803] = "1/90/95/100", [247804] = "1/90/95/100", [247805] = "1/90/95/100"},
[151791] = "1/300/300/300",
[152542] = "1/60/65/70",
[154138] = "1/50/75/100",
[154139] = "1/15/50/85",
[154140] = "1/15/50/85",
[154141] = "1/50/75/100",
[154142] = "1/25/55/85",
[154143] = "1/50/75/100",
[154144] = "1/15/50/85",
[154145] = "1/10/47/85",
[154146] = "1/50/75/100",
[154147] = "1/15/50/85",
[154148] = "1/15/50/85",
[154149] = "1/50/75/100",
[154150] = "1/25/55/85",
[154151] = "1/50/75/100",
[154152] = "1/15/50/85",
[154153] = "1/10/47/85",
[154159] = {[256787] = "1/100/117/135", [256788] = "1/115/132/150", [256789] = "1/120/135/150"},
[154160] = "1/25/55/85",
[154161] = "1/25/55/85",
[154162] = {[256779] = "1/100/117/135", [256780] = "1/115/132/150", [256781] = "1/120/135/150"},
[154163] = {[256782] = "1/100/117/135", [256783] = "1/115/132/150", [256784] = "1/120/135/150"},
[154166] = {[256790] = "1/85/105/125", [286019] = "1/110/120/130", [286021] = "1/115/125/135"},
[154167] = "1/150/150/150",
[154168] = "1/85/105/125",
[154169] = "1/75/100/125",
[159884] = {[269516] = "1/100/117/135", [269517] = "1/110/127/145", [269518] = "1/120/135/150"},
[159885] = {[269519] = "1/100/117/135", [269520] = "1/110/127/145", [269521] = "1/120/135/150"},
[159886] = {[269522] = "1/100/117/135", [269523] = "1/110/127/145", [269524] = "1/120/135/150"},
[159887] = {[269525] = "1/100/117/135", [269526] = "1/110/127/145", [269527] = "1/120/135/150"},
[159888] = {[269528] = "1/100/117/135", [269529] = "1/110/127/145", [269530] = "1/120/135/150"},
[159889] = {[269531] = "1/100/117/135", [269532] = "1/110/127/145", [269533] = "1/120/135/150"},
[159890] = {[269534] = "1/100/117/135", [269535] = "1/110/127/145", [269536] = "1/120/135/150"},
[159891] = {[269537] = "1/100/117/135", [269538] = "1/110/127/145", [269539] = "1/120/135/150"},
[159892] = {[269540] = "1/100/117/135", [269541] = "1/110/127/145", [269542] = "1/120/135/150"},
[159893] = {[269543] = "1/100/117/135", [269544] = "1/110/127/145", [269545] = "1/120/135/150"},
[159896] = {[269552] = "1/100/117/135", [269553] = "1/110/127/145", [269554] = "1/120/135/150"},
[161946] = "1/150/150/150",
[161947] = "1/150/150/150",
[161961] = "1/150/150/150",
[161962] = "1/150/150/150",
[162460] = "1/1/25/50",
[162461] = "1/1/25/50",
[162468] = "1/150/150/150",
[162470] = "1/150/150/150",
[162472] = "1/150/150/150",
[162474] = "1/150/150/150",
[162489] = "1/150/150/150",
[162490] = "1/150/150/150",
[162493] = "1/150/150/150",
[162494] = "1/150/150/150",
[164658] = {[282327] = "1/135/142/150", [282328] = "1/140/145/150", [282329] = "1/145/147/150"},
[164659] = {[282324] = "1/135/142/150", [282325] = "1/140/145/150", [282326] = "1/145/147/150"},
[164660] = {[282321] = "1/135/142/150", [282322] = "1/140/145/150", [282323] = "1/145/147/150"},
[164661] = {[282318] = "1/135/142/150", [282319] = "1/140/145/150", [282320] = "1/145/147/150"},
[164662] = {[282312] = "1/135/142/150", [282313] = "1/140/145/150", [282314] = "1/145/147/150"},
[164663] = {[282309] = "1/135/142/150", [282310] = "1/140/145/150", [282311] = "1/145/147/150"},
[164664] = {[282306] = "1/135/142/150", [282307] = "1/140/145/150", [282308] = "1/145/147/150"},
[164665] = {[282302] = "1/135/142/150", [282303] = "1/140/145/150", [282305] = "1/145/147/150"},
[164666] = {[282290] = "1/135/142/150", [282291] = "1/140/145/150", [282292] = "1/145/147/150"},
[164667] = {[282287] = "1/135/142/150", [282288] = "1/140/145/150", [282289] = "1/145/147/150"},
[164670] = {[282277] = "1/135/142/150", [282278] = "1/140/145/150", [282281] = "1/145/147/150"},
[164978] = "1/150/150/150",
[165382] = "1/150/150/150",
[165383] = "1/150/150/150",
[165388] = "1/150/150/150",
[165391] = "1/150/150/150",
[165396] = "1/150/150/150",
[165399] = "1/150/150/150",
[165404] = "1/150/150/150",
[165408] = "1/150/150/150",
[165412] = "1/150/150/150",
[165416] = "1/150/150/150",
[165420] = "1/150/150/150",
[165424] = "1/150/150/150",
[165699] = "1/100/112/125",
[165747] = "1/95/110/125",
[165749] = "1/95/110/125",
[167935] = {[294826] = "1/165/170/175", [294827] = "1/170/172/175", [294828] = "1/175/175/175"},
[167945] = {[294808] = "1/165/170/175", [294809] = "1/170/172/175", [294810] = "1/175/175/175"},
[167947] = {[294799] = "1/165/170/175", [294800] = "1/170/172/175", [294801] = "1/175/175/175"},
[167949] = {[294802] = "1/165/170/175", [294803] = "1/170/172/175", [294804] = "1/175/175/175"},
[167951] = {[294796] = "1/165/170/175", [294797] = "1/170/172/175", [294798] = "1/175/175/175"},
[167953] = {[294805] = "1/165/170/175", [294806] = "1/170/172/175", [294807] = "1/175/175/175"},
[167955] = {[294823] = "1/165/170/175", [294824] = "1/170/172/175", [294825] = "1/175/175/175"},
[167957] = {[294814] = "1/165/170/175", [294815] = "1/170/172/175", [294816] = "1/175/175/175"},
[167959] = {[294817] = "1/165/170/175", [294818] = "1/170/172/175", [294819] = "1/175/175/175"},
[167961] = {[294811] = "1/165/170/175", [294812] = "1/170/172/175", [294813] = "1/175/175/175"},
[167963] = {[294820] = "1/165/170/175", [294821] = "1/170/172/175", [294822] = "1/175/175/175"},
[168419] = {[301411] = "1/165/170/175", [324735] = "1/90/92/95"},
[168704] = "1/175/175/175",
[168705] = "1/175/175/175",
[168706] = "1/175/175/175",
[168707] = "1/175/175/175",
[168708] = "1/175/175/175",
[168709] = "1/175/175/175",
[168716] = "1/175/175/175",
[168717] = "1/175/175/175",
[168718] = "1/175/175/175",
[168719] = "1/175/175/175",
[168720] = "1/175/175/175",
[168721] = "1/175/175/175",
[169445] = "1/165/170/175",
[170342] = {[304415] = "1/165/170/175", [304416] = "1/165/170/175", [304417] = "1/165/170/175"},
[170343] = {[304424] = "1/165/170/175", [304425] = "1/165/170/175", [304426] = "1/165/170/175"},
[170344] = {[304418] = "1/165/170/175", [304419] = "1/165/170/175", [304420] = "1/165/170/175"},
[170345] = {[304412] = "1/165/170/175", [304413] = "1/165/170/175", [304414] = "1/165/170/175"},
[170346] = {[304421] = "1/165/170/175", [304422] = "1/165/170/175", [304423] = "1/165/170/175"},
[170352] = {[304439] = "1/165/170/175", [304440] = "1/165/170/175", [304441] = "1/165/170/175"},
[170353] = {[304430] = "1/165/170/175", [304431] = "1/165/170/175", [304432] = "1/165/170/175"},
[170354] = {[304433] = "1/165/170/175", [304434] = "1/165/170/175", [304435] = "1/165/170/175"},
[170355] = {[304427] = "1/165/170/175", [304428] = "1/165/170/175", [304429] = "1/165/170/175"},
[170356] = {[304436] = "1/165/170/175", [304437] = "1/165/170/175", [304438] = "1/165/170/175"},
[170362] = {[304442] = "1/165/167/170", [304443] = "1/165/167/170", [304444] = "1/165/167/170"},
[170432] = "1/175/175/175",
[170433] = "1/175/175/175",
[170434] = "1/175/175/175",
[170435] = "1/175/175/175",
[170436] = "1/175/175/175",
[170437] = "1/175/175/175",
[170438] = "1/175/175/175",
[170439] = "1/175/175/175",
[170440] = "1/175/175/175",
[170441] = "1/175/175/175",
[170442] = "1/175/175/175",
[170443] = "1/175/175/175",
[171320] = "1/200/200/200",
[172096] = "1/80/82/85",
[172097] = "1/90/92/95",
[172233] = "1/110/112/115",
[172234] = "1/40/45/50",
[172235] = "1/10/15/20",
[172236] = "1/25/30/35",
[172237] = "1/35/40/45",
[172238] = "1/45/50/55",
[172239] = "1/50/55/60",
[172240] = "1/20/25/30",
[172241] = "1/10/15/20",
[172242] = "1/40/45/50",
[172243] = "1/10/15/20",
[172244] = "1/25/30/35",
[172245] = "1/35/40/45",
[172246] = "1/45/50/55",
[172247] = "1/50/55/60",
[172248] = "1/20/25/30",
[172249] = "1/10/15/20",
[172250] = "1/90/95/100",
[172251] = "1/65/70/75",
[172252] = "1/75/80/85",
[172253] = "1/85/90/95",
[172254] = "1/100/100/100",
[172255] = "1/100/100/100",
[172256] = "1/70/75/80",
[172257] = "1/60/65/70",
[172258] = "1/90/95/100",
[172259] = "1/65/70/75",
[172260] = "1/75/80/85",
[172261] = "1/85/90/95",
[172262] = "1/100/100/100",
[172263] = "1/100/100/100",
[172264] = "1/70/75/80",
[172265] = "1/60/65/70",
[172314] = {[309199] = "1/110/112/115", [332015] = "1/110/112/115", [332050] = "1/110/112/115", [338979] = "1/110/112/115"},
[172315] = {[309198] = "1/110/112/115", [332014] = "1/110/112/115", [332049] = "1/110/112/115", [338980] = "1/110/112/115"},
[172316] = {[309200] = "1/110/112/115", [332016] = "1/110/112/115", [332051] = "1/110/112/115", [338981] = "1/110/112/115"},
[172317] = {[309201] = "1/110/112/115", [332017] = "1/110/112/115", [332052] = "1/110/112/115", [338982] = "1/110/112/115"},
[172318] = {[309202] = "1/110/112/115", [332018] = "1/110/112/115", [332053] = "1/110/112/115", [338983] = "1/110/112/115"},
[172319] = {[309203] = "1/110/112/115", [332019] = "1/110/112/115", [332054] = "1/110/112/115", [338984] = "1/110/112/115"},
[172320] = {[309204] = "1/110/112/115", [332020] = "1/110/112/115", [332055] = "1/110/112/115", [338985] = "1/110/112/115"},
[172321] = {[309205] = "1/110/112/115", [332021] = "1/110/112/115", [332056] = "1/110/112/115", [338986] = "1/110/112/115"},
[172322] = {[309207] = "1/110/112/115", [332023] = "1/110/112/115", [332058] = "1/110/112/115", [338987] = "1/110/112/115"},
[172323] = {[309206] = "1/110/112/115", [332022] = "1/110/112/115", [332057] = "1/110/112/115", [338988] = "1/110/112/115"},
[172324] = {[309208] = "1/110/112/115", [332024] = "1/110/112/115", [332059] = "1/110/112/115", [338989] = "1/110/112/115"},
[172325] = {[309209] = "1/110/112/115", [332025] = "1/110/112/115", [332060] = "1/110/112/115", [338990] = "1/110/112/115"},
[172326] = {[309210] = "1/110/112/115", [332026] = "1/110/112/115", [332061] = "1/110/112/115", [338991] = "1/110/112/115"},
[172327] = {[309211] = "1/110/112/115", [332027] = "1/110/112/115", [332062] = "1/110/112/115", [338992] = "1/110/112/115"},
[172328] = {[309212] = "1/110/112/115", [332028] = "1/110/112/115", [332063] = "1/110/112/115", [338993] = "1/110/112/115"},
[172329] = {[309213] = "1/110/112/115", [332029] = "1/110/112/115", [332064] = "1/110/112/115", [338994] = "1/110/112/115"},
[172346] = "1/10/12/15",
[172347] = "1/60/62/65",
[172348] = "1/25/27/30",
[172349] = "1/45/47/50",
[172350] = "1/40/42/45",
[172351] = "1/55/57/60",
[173381] = "1/55/60/65",
[173382] = "1/75/80/85",
[173383] = "1/90/92/95",
[173384] = "1/200/200/200",
[180055] = {[330180] = "1/1/10/20", [330186] = "1/1/10/20", [330191] = "1/1/10/20", [330196] = "1/1/10/20", [330201] = "1/1/10/20", [330206] = "1/1/10/20", [330211] = "1/1/10/20", [330216] = "1/1/10/20"},
[180057] = {[330181] = "1/1/10/20", [330187] = "1/1/10/20", [330192] = "1/1/10/20", [330197] = "1/1/10/20", [330202] = "1/1/10/20", [330207] = "1/1/10/20", [330212] = "1/1/10/20", [330218] = "1/1/10/20"},
[180058] = {[330183] = "1/1/10/20", [330188] = "1/1/10/20", [330193] = "1/1/10/20", [330198] = "1/1/10/20", [330203] = "1/1/10/20", [330208] = "1/1/10/20", [330213] = "1/1/10/20", [330219] = "1/1/10/20"},
[180059] = {[330184] = "1/1/10/20", [330189] = "1/1/10/20", [330194] = "1/1/10/20", [330199] = "1/1/10/20", [330204] = "1/1/10/20", [330209] = "1/1/10/20", [330214] = "1/1/10/20", [330220] = "1/1/10/20"},
[180060] = {[330185] = "1/1/10/20", [330190] = "1/1/10/20", [330195] = "1/1/10/20", [330200] = "1/1/10/20", [330205] = "1/1/10/20", [330210] = "1/1/10/20", [330215] = "1/1/10/20", [330221] = "1/1/10/20"},
[183942] = "1/50/55/60",
[185960] = "1/110/112/115",
[186686] = "1/55/60/65",
[186702] = "1/80/82/85",
[186985] = "1/100/100/100",
-- Unknown item created by: Pandaria Patterns (255) - Primal Leg Reinforcements (124559)
-- Unknown item created by: Pandaria Patterns (255) - Draconic Leg Reinforcements (124561)
-- Unknown item created by: Pandaria Patterns (255) - Heavy Leg Reinforcements (124563)
-- Invalid recipe: Legion Patterns (140) - Drum of Primal Might (293135)
-- Invalid recipe: Shadowlands Patterns (126) - Dyed Runestag Leather (338253)
-- Invalid recipe: Shadowlands Patterns (126) - Runestag Leather Strap (338254)
-- Invalid recipe: Shadowlands Patterns (126) - Stalker's Leather Quiver (338255)
-- Invalid recipe: Shadowlands Patterns (126) - Steelhide Leather Harness (338257)
-- Invalid recipe: Shadowlands Patterns (126) - Steelhide Leather Belt (338258)
-- Invalid recipe: Shadowlands Patterns (126) - Steelhide Leather Strap (338259)
-- Invalid recipe: Shadowlands Patterns (126) - Bonestudded Fist (338260)
-- Invalid recipe: Shadowlands Patterns (126) - Cleaned Hide (338262)
-- Invalid recipe: Shadowlands Patterns (126) - Courtly Leather Boots (338263)
-- Invalid recipe: Shadowlands Patterns (126) - Tortured Sole (338264)
-- Invalid recipe: Shadowlands Patterns (126) - Softened Leather (338265)



-- mining
[2840] = "1/20/40/60",
[2841] = "50/50/75/100",
[2842] = "65/100/105/110",
[3575] = "100/100/125/150",
[3576] = "1/50/57/75",
[3577] = "115/150/155/160",
[3859] = "125/125/130/135",
[3860] = "150/150/175/200",
[6037] = "165/200/205/210",
[11371] = "1/300/305/310",
[12359] = "200/200/245/290",
[12655] = "250/250/270/290",
[17771] = "1/300/300/300",
[22573] = "1/1/5/10",
[22574] = "1/1/5/10",
[23445] = "1/1/13/25",
[23446] = "1/25/32/40",
[23447] = "1/50/57/65",
[23448] = "1/40/57/75",
[23449] = "1/75/75/75",
[23573] = "1/75/75/75",
[35128] = "1/75/75/75",
[36913] = "1/50/62/75",
[36916] = "1/1/13/25",
[37663] = "1/75/75/75",
[41163] = "1/75/75/75",
[51950] = "1/75/75/75",
[52186] = "1/1/25/50",
[53039] = "1/50/62/75",
[54849] = "1/1/13/25",
[72095] = "1/75/75/75",
[72096] = "1/1/25/50",



-- tailoring
[1251] = "1/40/50/60",
[2568] = "10/45/57/70",
[2569] = "65/90/107/125",
[2570] = "1/35/47/60",
[2572] = "1/65/82/100",
[2575] = "40/65/82/100",
[2576] = "1/35/47/60",
[2577] = "40/65/82/100",
[2578] = "70/95/112/130",
[2579] = "70/95/112/130",
[2580] = "60/85/102/120",
[2581] = "1/80/90/100",
[2582] = "85/110/127/145",
[2583] = "95/120/137/155",
[2584] = "75/100/117/135",
[2585] = "1/130/147/165",
[2587] = "100/110/120/130",
[2996] = "1/25/37/50",
[2997] = "75/90/97/105",
[3530] = "1/115/132/150",
[3531] = "1/150/167/185",
[4238] = "45/70/87/105",
[4240] = "80/105/122/140",
[4241] = "1/120/137/155",
[4245] = "150/170/185/200",
[4305] = "125/135/140/145",
[4307] = "35/60/77/95",
[4308] = "60/85/102/120",
[4309] = "70/95/112/130",
[4310] = "85/110/127/145",
[4311] = "1/125/142/160",
[4312] = "80/105/122/140",
[4313] = "1/120/137/155",
[4314] = "110/135/152/170",
[4315] = "1/145/162/180",
[4316] = "110/135/152/170",
[4317] = "1/150/167/185",
[4318] = "130/150/165/180",
[4319] = "1/165/180/195",
[4320] = "125/150/167/185",
[4321] = "1/160/175/190",
[4322] = "1/185/200/215",
[4323] = "1/190/205/220",
[4324] = "150/170/185/200",
[4325] = "1/195/210/225",
[4326] = "185/205/220/235",
[4327] = "1/220/235/250",
[4328] = "1/200/215/230",
[4329] = "1/220/235/250",
[4330] = "110/135/152/170",
[4331] = "1/150/167/185",
[4332] = "1/145/150/155",
[4333] = "1/165/170/175",
[4334] = "170/180/185/190",
[4335] = "1/195/200/205",
[4336] = "1/210/215/220",
[4339] = "175/180/182/185",
[4343] = "30/55/72/90",
[4344] = "1/35/47/60",
[5542] = "90/115/132/150",
[5762] = "1/95/112/130",
[5763] = "1/140/157/175",
[5764] = "1/195/210/225",
[5765] = "1/205/220/235",
[5766] = "135/155/170/185",
[5770] = "1/170/185/200",
[6238] = "30/55/72/90",
[6239] = "1/80/97/115",
[6240] = "1/80/97/115",
[6241] = "30/55/72/90",
[6242] = "1/95/112/130",
[6263] = "1/125/142/160",
[6264] = "1/140/157/175",
[6384] = "1/145/162/180",
[6385] = "1/145/162/180",
[6450] = "1/180/195/210",
[6451] = "1/210/225/240",
[6786] = "40/65/82/100",
[6787] = "110/135/152/170",
[6795] = "160/170/175/180",
[6796] = "175/185/190/195",
[6836] = "1/255/270/285",
[7026] = "15/50/67/85",
[7046] = "140/160/175/190",
[7047] = "1/165/180/195",
[7048] = "145/155/160/165",
[7049] = "1/170/185/200",
[7050] = "160/170/175/180",
[7051] = "170/190/205/220",
[7052] = "175/195/210/225",
[7053] = "1/195/210/225",
[7054] = "190/210/225/240",
[7055] = "175/195/210/225",
[7056] = "1/200/215/230",
[7057] = "180/200/215/230",
[7058] = "185/205/215/225",
[7059] = "1/210/225/240",
[7060] = "1/210/225/240",
[7061] = "1/215/230/245",
[7062] = "195/215/225/235",
[7063] = "1/220/235/250",
[7064] = "210/225/240/255",
[7065] = "1/185/200/215",
[8544] = "1/240/245/250",
[8545] = "1/260/267/275",
[9998] = "205/220/235/250",
[9999] = "205/220/235/250",
[10001] = "210/225/240/255",
[10002] = "210/225/240/255",
[10003] = "215/230/245/260",
[10004] = "215/230/245/260",
[10007] = "1/230/245/260",
[10008] = "1/220/225/230",
[10009] = "1/230/245/260",
[10018] = "1/240/255/270",
[10019] = "225/240/255/270",
[10021] = "225/240/255/270",
[10023] = "225/240/255/270",
[10024] = "230/245/260/275",
[10025] = "1/260/275/290",
[10026] = "230/245/260/275",
[10027] = "230/245/260/275",
[10028] = "235/250/265/280",
[10029] = "1/250/265/280",
[10030] = "1/255/270/285",
[10031] = "240/255/270/285",
[10033] = "1/255/270/285",
[10034] = "1/245/250/255",
[10035] = "1/250/255/260",
[10036] = "1/265/280/295",
[10040] = "1/255/260/265",
[10041] = "250/265/280/295",
[10042] = "225/240/255/270",
[10044] = "245/260/275/290",
[10045] = "1/35/47/60",
[10046] = "20/50/67/85",
[10047] = "75/100/117/135",
[10048] = "1/145/162/180",
[10050] = "225/240/255/270",
[10051] = "235/250/265/280",
[10052] = "1/225/230/235",
[10053] = "235/240/245/250",
[10054] = "1/235/240/245",
[10055] = "1/240/245/250",
[10056] = "215/220/225/230",
[13856] = "255/270/285/300",
[13857] = "260/275/287/300",
[13858] = "260/275/287/300",
[13860] = "265/280/290/300",
[13863] = "275/290/295/300",
[13864] = "280/295/297/300",
[13865] = "285/300/300/300",
[13866] = "295/300/300/300",
[13867] = "300/300/300/300",
[13868] = "1/270/285/300",
[13869] = "255/270/285/300",
[13870] = "265/280/290/300",
[13871] = "280/295/297/300",
[14042] = "1/275/287/300",
[14043] = "1/285/292/300",
[14044] = "1/290/295/300",
[14045] = "1/295/297/300",
[14046] = "1/275/287/300",
[14048] = "250/255/257/260",
[14100] = "270/285/292/300",
[14101] = "270/285/292/300",
[14103] = "275/290/295/300",
[14104] = "1/300/300/300",
[14106] = "300/300/300/300",
[14107] = "1/290/295/300",
[14108] = "285/300/300/300",
[14111] = "290/300/300/300",
[14112] = "300/300/300/300",
[14128] = "300/300/300/300",
[14130] = "300/300/300/300",
[14132] = "275/290/295/300",
[14134] = "1/290/295/300",
[14136] = "1/300/300/300",
[14137] = "1/300/300/300",
[14138] = "1/300/300/300",
[14139] = "1/300/300/300",
[14140] = "1/300/300/300",
[14141] = "275/290/295/300",
[14142] = "270/285/292/300",
[14143] = "265/280/290/300",
[14144] = "290/300/300/300",
[14146] = "1/300/300/300",
[14152] = "1/300/300/300",
[14153] = "1/300/300/300",
[14154] = "1/300/300/300",
[14155] = "1/300/300/300",
[14156] = "1/300/300/300",
[14342] = "1/290/295/300",
[14529] = "1/290/295/300",
[14530] = "1/300/300/300",
[15802] = "1/295/297/300",
[16979] = "1/300/300/300",
[16980] = "1/300/300/300",
[17723] = "1/200/205/210",
[18258] = "1/285/290/295",
[18263] = "1/300/300/300",
[18405] = "1/300/300/300",
[18407] = "1/300/300/300",
[18408] = "1/300/300/300",
[18409] = "1/300/300/300",
[18413] = "1/300/300/300",
[18486] = "1/300/300/300",
[19047] = "1/300/300/300",
[19050] = "1/300/300/300",
[19056] = "1/300/300/300",
[19059] = "1/300/300/300",
[19156] = "1/300/300/300",
[19165] = "1/300/300/300",
[19682] = "1/300/300/300",
[19683] = "1/300/300/300",
[19684] = "1/300/300/300",
[20537] = "1/300/300/300",
[20538] = "1/300/300/300",
[20539] = "1/300/300/300",
[21340] = "1/275/287/300",
[21341] = "1/300/300/300",
[21342] = "1/300/300/300",
[21840] = "1/5/15/25",
[21841] = "1/20/30/40",
[21842] = "1/30/35/40",
[21843] = "1/40/45/50",
[21844] = "1/45/50/55",
[21845] = "1/50/55/60",
[21846] = "1/65/70/75",
[21847] = "1/75/75/75",
[21848] = "1/75/75/75",
[21849] = "1/20/25/30",
[21850] = "1/20/25/30",
[21851] = "1/30/35/40",
[21852] = "1/35/40/45",
[21853] = "1/45/50/55",
[21854] = "1/50/55/60",
[21855] = "1/55/60/65",
[21858] = "1/75/75/75",
[21859] = "1/50/55/60",
[21860] = "1/60/65/70",
[21861] = "1/70/72/75",
[21862] = "1/70/72/75",
[21863] = "1/65/70/75",
[21864] = "1/75/75/75",
[21865] = "1/75/75/75",
[21866] = "1/60/65/70",
[21867] = "1/70/72/75",
[21868] = "1/75/75/75",
[21869] = "1/65/70/75",
[21870] = "1/75/75/75",
[21871] = "1/75/75/75",
[21872] = "1/75/75/75",
[21873] = "1/65/70/75",
[21874] = "1/75/75/75",
[21875] = "1/75/75/75",
[21876] = "1/75/75/75",
[21990] = "1/30/47/65",
[21991] = "1/50/62/75",
[22246] = "1/240/255/270",
[22248] = "1/290/295/300",
[22249] = "1/15/30/45",
[22251] = "1/290/295/300",
[22252] = "1/15/30/45",
[22652] = "1/15/30/45",
[22654] = "1/15/30/45",
[22655] = "1/15/30/45",
[22658] = "1/15/30/45",
[22660] = "1/300/300/300",
[22756] = "1/300/300/300",
[22757] = "1/300/300/300",
[22758] = "1/300/300/300",
[24249] = "1/60/65/70",
[24250] = "1/60/65/70",
[24251] = "1/60/65/70",
[24252] = "1/60/65/70",
[24253] = "1/60/65/70",
[24254] = "1/60/65/70",
[24255] = "1/75/75/75",
[24256] = "1/75/75/75",
[24257] = "1/75/75/75",
[24258] = "1/75/75/75",
[24259] = "1/75/75/75",
[24260] = "1/75/75/75",
[24261] = "1/75/75/75",
[24262] = "1/75/75/75",
[24263] = "1/75/75/75",
[24264] = "1/75/75/75",
[24266] = "1/75/75/75",
[24267] = "1/75/75/75",
[24268] = "1/1/10/20",
[24270] = "1/50/55/60",
[24271] = "1/50/55/60",
[24272] = "1/50/55/60",
[24273] = "1/45/50/55",
[24274] = "1/75/75/75",
[24275] = "1/45/50/55",
[24276] = "1/75/75/75",
[30035] = "1/75/75/75",
[30036] = "1/75/75/75",
[30037] = "1/75/75/75",
[30038] = "1/75/75/75",
[30831] = "1/60/65/70",
[30837] = "1/60/65/70",
[30838] = "1/70/72/75",
[30839] = "1/75/75/75",
[32389] = "1/75/75/75",
[32390] = "1/75/75/75",
[32391] = "1/75/75/75",
[32392] = "1/75/75/75",
[32420] = "1/75/75/75",
[32584] = "1/375/375/375",
[32585] = "1/375/375/375",
[32586] = "1/375/375/375",
[32587] = "1/375/375/375",
[34364] = "1/365/365/365",
[34365] = "1/365/365/365",
[34366] = "1/365/365/365",
[34367] = "1/365/365/365",
[34721] = "1/15/25/35",
[34722] = "1/50/62/75",
[38225] = "1/75/75/75",
[38277] = "1/265/280/295",
[38278] = "1/250/255/260",
[41248] = "1/25/30/35",
[41249] = "1/25/30/35",
[41250] = "1/25/30/35",
[41251] = "1/25/30/35",
[41252] = "1/25/30/35",
[41253] = "1/25/30/35",
[41254] = "1/25/30/35",
[41255] = "1/25/30/35",
[41509] = "1/1/3/5",
[41510] = "1/1/3/5",
[41511] = "1/25/27/30",
[41512] = "1/1/3/5",
[41513] = "1/1/3/5",
[41515] = "1/1/8/15",
[41516] = "1/55/65/75",
[41519] = "1/15/25/35",
[41520] = "1/10/20/30",
[41521] = "1/15/25/35",
[41522] = "1/5/15/25",
[41523] = "1/20/30/40",
[41525] = "1/25/35/45",
[41528] = "1/20/30/40",
[41543] = "1/25/30/35",
[41544] = "1/45/50/55",
[41545] = "1/40/45/50",
[41546] = "1/30/35/40",
[41548] = "1/30/35/40",
[41549] = "1/40/45/50",
[41550] = "1/45/50/55",
[41551] = "1/35/40/45",
[41553] = "1/50/55/60",
[41554] = "1/55/60/65",
[41555] = "1/50/55/60",
[41593] = "1/50/55/60",
[41594] = "1/50/55/60",
[41595] = "1/50/55/60",
[41597] = "1/65/70/75",
[41598] = "1/70/72/75",
[41599] = "1/55/65/75",
[41600] = "1/75/75/75",
[41601] = "1/25/30/35",
[41602] = "1/60/65/70",
[41603] = "1/25/30/35",
[41604] = "1/60/65/70",
[41607] = "1/20/25/30",
[41608] = "1/25/30/35",
[41609] = "1/60/67/75",
[41610] = "1/60/67/75",
[41984] = "1/60/65/70",
[41985] = "1/55/65/75",
[41986] = "1/55/65/75",
[42093] = "1/60/65/70",
[42095] = "1/55/65/75",
[42096] = "1/55/65/75",
[42100] = "1/75/75/75",
[42101] = "1/75/75/75",
[42102] = "1/75/75/75",
[42103] = "1/70/72/75",
[42111] = "1/70/72/75",
[42113] = "1/70/72/75",
[43583] = "1/60/67/75",
[43584] = "1/55/65/75",
[43585] = "1/55/65/75",
[43969] = "1/50/60/70",
[43970] = "1/55/65/75",
[43971] = "1/55/65/75",
[43972] = "1/55/65/75",
[43973] = "1/55/65/75",
[43974] = "1/50/60/70",
[43975] = "1/55/65/75",
[44211] = "1/1/8/15",
[44554] = "1/1/3/5",
[44558] = "1/60/67/75",
[45557] = "1/75/75/75",
[45558] = "1/75/75/75",
[45566] = "1/75/75/75",
[45567] = "1/75/75/75",
[45626] = "125/150/167/185",
[45773] = "1/65/70/75",
[45810] = "1/35/40/45",
[45811] = "1/30/35/40",
[47585] = "1/75/75/75",
[47586] = "1/75/75/75",
[47587] = "1/75/75/75",
[47588] = "1/75/75/75",
[47603] = "1/75/75/75",
[47604] = "1/75/75/75",
[47605] = "1/75/75/75",
[47606] = "1/75/75/75",
[49890] = "1/75/75/75",
[49891] = "1/75/75/75",
[49892] = "1/75/75/75",
[49893] = "1/75/75/75",
[53049] = "1/25/30/35",
[53050] = "1/50/62/75",
[53051] = {[74558] = "1/30/47/65", [88893] = "1/30/47/65"},
[53643] = "1/1/3/5",
[54440] = {[75141] = "1/75/75/75", [75142] = "1/75/75/75", [75144] = "1/75/75/75", [75145] = "1/75/75/75", [75146] = "1/75/75/75", [94743] = "1/75/75/75"},
[54441] = "1/55/60/65",
[54442] = "1/1/3/5",
[54443] = "1/40/42/45",
[54444] = "1/75/75/75",
[54445] = "1/40/42/45",
[54446] = "1/50/52/55",
[54447] = "1/15/17/20",
[54448] = "1/75/75/75",
[54449] = "1/20/22/25",
[54450] = "1/75/75/75",
[54451] = "1/75/75/75",
[54471] = "1/5/10/15",
[54472] = "1/15/20/25",
[54473] = "1/5/10/15",
[54474] = "1/10/15/20",
[54475] = "1/25/27/30",
[54476] = "1/20/25/30",
[54477] = "1/10/15/20",
[54478] = "1/20/22/25",
[54479] = "1/35/37/40",
[54480] = "1/25/30/35",
[54481] = "1/25/30/35",
[54482] = "1/30/35/40",
[54483] = "1/35/40/45",
[54484] = "1/35/40/45",
[54485] = "1/50/52/55",
[54486] = "1/50/52/55",
[54503] = "1/75/75/75",
[54504] = "1/75/75/75",
[54505] = "1/75/75/75",
[54506] = "1/75/75/75",
[54797] = "1/60/67/75",
[69944] = "1/75/75/75",
[69945] = "1/75/75/75",
[69953] = "1/75/75/75",
[69954] = "1/75/75/75",
[70138] = "1/40/42/45",
[71980] = "1/75/75/75",
[71981] = "1/75/75/75",
[71989] = "1/75/75/75",
[71990] = "1/75/75/75",
[72985] = "1/25/27/30",
[72986] = "1/30/47/65",
[75062] = "1/75/75/75",
[75063] = "1/75/75/75",
[75064] = "1/60/65/70",
[75065] = "1/50/52/55",
[75070] = "1/70/72/75",
[75072] = "1/75/75/75",
[75073] = "1/75/75/75",
[75082] = "1/75/75/75",
[75086] = "1/65/70/75",
[75087] = "1/70/72/75",
[75088] = "1/75/75/75",
[75089] = "1/55/60/65",
[75091] = "1/65/70/75",
[75093] = "1/75/75/75",
[75095] = "1/75/75/75",
[75096] = "1/65/70/75",
[75098] = "1/55/60/65",
[82397] = "1/50/60/70",
[82398] = "1/30/40/50",
[82399] = "1/50/60/70",
[82400] = "1/20/30/40",
[82401] = "1/40/50/60",
[82402] = "1/20/30/40",
[82403] = "1/40/50/60",
[82404] = "1/30/40/50",
[82421] = "1/75/75/75",
[82422] = "1/75/75/75",
[82423] = "1/75/75/75",
[82424] = "1/75/75/75",
[82425] = "1/75/75/75",
[82426] = "1/75/75/75",
[82427] = "1/75/75/75",
[82428] = "1/75/75/75",
[82429] = "1/75/75/75",
[82430] = "1/75/75/75",
[82431] = "1/75/75/75",
[82432] = "1/75/75/75",
[82433] = "1/75/75/75",
[82434] = "1/75/75/75",
[82435] = "1/75/75/75",
[82436] = "1/75/75/75",
[82437] = "1/75/75/75",
[82438] = "1/75/75/75",
[82439] = "1/75/75/75",
[82440] = "1/75/75/75",
[82441] = "1/1/5/10",
[82442] = "1/25/35/45",
[82443] = "1/35/45/55",
[82444] = "1/75/75/75",
[82445] = "1/75/75/75",
[82446] = "1/75/75/75",
[82447] = "1/75/75/75",
[86311] = "1/75/75/75",
[86312] = "1/75/75/75",
[86313] = "1/75/75/75",
[86314] = "1/75/75/75",
[92726] = "1/1/3/5",
[92960] = "1/45/55/65",
[93420] = "1/75/75/75",
[93421] = "1/75/75/75",
[93428] = "1/75/75/75",
[93429] = "1/75/75/75",
[93430] = "1/75/75/75",
[93431] = "1/75/75/75",
[93432] = "1/75/75/75",
[93433] = "1/75/75/75",
[93434] = "1/75/75/75",
[93435] = "1/75/75/75",
[93436] = "1/75/75/75",
[93437] = "1/75/75/75",
[93438] = "1/75/75/75",
[93439] = "1/75/75/75",
[93499] = "1/75/75/75",
[93500] = "1/75/75/75",
[93501] = "1/75/75/75",
[93502] = "1/75/75/75",
[93503] = "1/75/75/75",
[93550] = "1/75/75/75",
[93551] = "1/75/75/75",
[93552] = "1/75/75/75",
[93553] = "1/75/75/75",
[93554] = "1/75/75/75",
[93555] = "1/75/75/75",
[93556] = "1/75/75/75",
[93557] = "1/75/75/75",
[93558] = "1/75/75/75",
[93559] = "1/75/75/75",
[93607] = "1/75/75/75",
[93608] = "1/75/75/75",
[93615] = "1/75/75/75",
[93616] = "1/75/75/75",
[93617] = "1/75/75/75",
[93618] = "1/75/75/75",
[93619] = "1/75/75/75",
[94277] = "1/75/75/75",
[94278] = "1/75/75/75",
[94279] = "1/75/75/75",
[94280] = "1/75/75/75",
[98599] = "1/75/75/75",
[98603] = "1/75/75/75",
[98608] = "1/75/75/75",
[98612] = "1/75/75/75",
[98619] = {[143011] = "1/75/75/75", [146925] = "1/75/75/75"},
[98756] = "1/75/75/75",
[98757] = "1/75/75/75",
[98763] = "1/75/75/75",
[98764] = "1/75/75/75",
[98765] = "1/75/75/75",
[98766] = "1/75/75/75",
[98767] = "1/75/75/75",
[98768] = "1/75/75/75",
[98769] = "1/75/75/75",
[98770] = "1/75/75/75",
[98771] = "1/75/75/75",
[98772] = "1/75/75/75",
[98773] = "1/75/75/75",
[98774] = "1/75/75/75",
[98825] = "1/75/75/75",
[98826] = "1/75/75/75",
[98827] = "1/75/75/75",
[98828] = "1/75/75/75",
[98829] = "1/75/75/75",
[98865] = "1/75/75/75",
[98866] = "1/75/75/75",
[98867] = "1/75/75/75",
[98868] = "1/75/75/75",
[98869] = "1/75/75/75",
[98870] = "1/75/75/75",
[98871] = "1/75/75/75",
[98872] = "1/75/75/75",
[98873] = "1/75/75/75",
[98874] = "1/75/75/75",
[98913] = "1/75/75/75",
[98914] = "1/75/75/75",
[98921] = "1/75/75/75",
[98922] = "1/75/75/75",
[98923] = "1/75/75/75",
[98924] = "1/75/75/75",
[98925] = "1/75/75/75",
[111556] = {[168835] = "1/1/50/100", [182123] = "1/100/100/100"},
[111603] = "1/1/25/50",
[113216] = "1/100/100/100",
[114809] = "1/100/100/100",
[114810] = "1/100/100/100",
[114811] = "1/100/100/100",
[114812] = "1/100/100/100",
[114813] = "1/100/100/100",
[114814] = "1/100/100/100",
[114815] = "1/100/100/100",
[114816] = "1/100/100/100",
[114817] = "1/100/100/100",
[114818] = "1/100/100/100",
[114819] = "1/100/100/100",
[114821] = "1/100/100/100",
[114828] = "1/50/55/60",
[114829] = "1/50/55/60",
[114831] = "1/50/55/60",
[114836] = "1/100/100/100",
[115363] = "1/100/100/100",
[118115] = "1/1/1/1",
[118123] = "1/1/1/1",
[118670] = "1/1/1/1",
[118722] = "1/1/50/100",
[119035] = "1/1/1/1",
[126987] = {[185925] = "1/20/30/40", [185941] = "1/40/50/60", [185945] = "1/60/70/80"},
[126988] = {[185924] = "1/20/30/40", [185940] = "1/40/50/60", [208352] = "1/60/70/80"},
[126989] = {[185923] = "1/20/30/40", [185939] = "1/40/50/60", [208350] = "1/60/70/80"},
[126990] = {[185922] = "1/20/30/40", [185938] = "1/40/50/60", [208351] = "1/60/70/80"},
[126991] = {[185921] = "1/20/30/40", [185937] = "1/40/50/60", [208353] = "1/60/70/80"},
[126992] = {[185920] = "1/20/30/40", [185936] = "1/40/50/60", [185944] = "1/60/70/80"},
[126993] = {[185919] = "1/20/30/40", [185935] = "1/40/50/60", [185943] = "1/60/70/80"},
[126994] = {[185918] = "1/20/30/40", [185934] = "1/40/50/60", [185942] = "1/60/70/80"},
[126995] = {[185933] = "1/60/70/80", [185953] = "1/80/90/100", [185961] = "1/100/100/100"},
[126996] = {[185932] = "1/60/70/80", [185952] = "1/80/90/100", [185960] = "1/100/100/100"},
[126997] = {[185931] = "1/60/70/80", [185951] = "1/80/90/100", [185959] = "1/100/100/100"},
[126998] = {[185930] = "1/60/70/80", [185950] = "1/80/90/100", [185958] = "1/100/100/100"},
[126999] = {[185929] = "1/60/70/80", [185949] = "1/80/90/100", [185957] = "1/100/100/100"},
[127000] = {[185928] = "1/60/70/80", [185948] = "1/80/90/100", [185956] = "1/100/100/100"},
[127001] = {[185927] = "1/60/70/80", [185947] = "1/80/90/100", [185955] = "1/100/100/100"},
[127002] = {[185926] = "1/60/70/80", [185946] = "1/80/90/100", [185954] = "1/100/100/100"},
[127004] = "1/60/70/80",
[127016] = "1/20/40/60",
[127017] = "1/20/40/60",
[127019] = {[186112] = "1/60/70/80", [186113] = "1/80/90/100", [186114] = "1/100/100/100"},
[127020] = {[186115] = "1/60/70/80", [186116] = "1/80/90/100", [186117] = "1/100/100/100"},
[127031] = "1/20/40/60",
[127032] = "1/20/40/60",
[127033] = {[186106] = "1/60/70/80", [186107] = "1/80/90/100", [186108] = "1/100/100/100"},
[127034] = {[186109] = "1/60/70/80", [186110] = "1/80/90/100", [186111] = "1/100/100/100"},
[127035] = "1/20/40/60",
[127294] = "1/1/1/1",
[127344] = "1/1/1/1",
[127345] = "1/1/1/1",
[127359] = "1/1/1/1",
[127360] = "1/1/1/1",
[127361] = "1/1/1/1",
[127363] = "1/1/1/1",
[127364] = "1/1/1/1",
[127367] = "1/1/1/1",
[127370] = "1/1/1/1",
[127372] = "1/1/1/1",
[127373] = "1/1/1/1",
[133940] = "1/10/20/30",
[133942] = "1/70/80/90",
[137556] = "1/20/40/60",
[137557] = "1/20/40/60",
[137558] = "1/20/40/60",
[139503] = "1/20/40/60",
[142075] = {[229041] = "1/100/100/100", [229043] = "1/100/100/100", [229045] = "1/100/100/100"},
[142332] = "1/40/50/60",
[146666] = "1/100/105/110",
[151571] = {[247807] = "1/90/95/100", [247808] = "1/90/95/100", [247809] = "1/90/95/100"},
[151771] = "1/265/280/295",
[151772] = "1/265/280/295",
[151790] = "1/250/250/250",
[151792] = "1/250/250/250",
[154685] = "1/75/87/100",
[154686] = "1/15/50/85",
[154687] = "1/15/50/85",
[154688] = "1/50/75/100",
[154689] = "1/25/55/85",
[154690] = "1/50/75/100",
[154691] = "1/15/50/85",
[154692] = "1/10/47/85",
[154695] = {[257125] = "1/85/105/125", [257126] = "1/110/127/145", [257127] = "1/125/137/150"},
[154696] = {[257128] = "1/150/150/150", [257129] = "1/150/150/150", [257130] = "1/150/150/150"},
[154697] = "1/50/75/100",
[154700] = {[257114] = "1/100/117/135", [257115] = "1/150/150/150", [257116] = "1/150/150/150"},
[154705] = {[257137] = "1/90/95/100", [257138] = "1/150/150/150", [257139] = "1/150/150/150"},
[154706] = {[257134] = "1/90/95/100", [257135] = "1/150/150/150", [257136] = "1/150/150/150"},
[154707] = {[257131] = "1/90/95/100", [257132] = "1/150/150/150", [257133] = "1/150/150/150"},
[158378] = "1/100/125/150",
[158381] = "1/10/42/75",
[158382] = "1/75/87/100",
[159791] = "1/10/42/75",
[159792] = "1/85/105/125",
[159912] = {[269599] = "1/100/117/135", [269600] = "1/110/127/145", [269601] = "1/125/137/150"},
[159913] = {[269602] = "1/100/117/135", [269603] = "1/110/127/145", [269604] = "1/125/137/150"},
[159914] = {[269605] = "1/100/117/135", [269606] = "1/110/127/145", [269607] = "1/125/137/150"},
[159915] = {[269608] = "1/100/117/135", [269609] = "1/110/127/145", [269610] = "1/125/137/150"},
[159916] = {[269611] = "1/100/117/135", [269612] = "1/110/127/145", [269613] = "1/125/137/150"},
[159917] = {[269596] = "1/100/117/135", [269597] = "1/110/127/145", [269598] = "1/125/137/150"},
[161985] = "1/150/150/150",
[161986] = "1/150/150/150",
[162460] = "1/1/25/50",
[162461] = "1/1/25/50",
[162476] = "1/150/150/150",
[162478] = "1/150/150/150",
[162487] = "1/150/150/150",
[162488] = "1/150/150/150",
[164671] = {[282194] = "1/135/142/150", [282195] = "1/140/145/150", [282196] = "1/145/147/150"},
[164672] = {[282191] = "1/135/142/150", [282192] = "1/140/145/150", [282193] = "1/145/147/150"},
[164673] = {[282175] = "1/135/142/150", [282176] = "1/140/145/150", [282177] = "1/145/147/150"},
[164674] = {[282168] = "1/135/142/150", [282169] = "1/140/145/150", [282170] = "1/145/147/150"},
[164675] = {[282164] = "1/135/142/150", [282165] = "1/140/145/150", [282166] = "1/145/147/150"},
[164676] = {[282204] = "1/135/142/150", [282275] = "1/140/145/150", [282276] = "1/145/147/150"},
[164733] = "1/150/150/150",
[165377] = "1/150/150/150",
[165385] = "1/150/150/150",
[165393] = "1/150/150/150",
[165402] = "1/150/150/150",
[165410] = "1/150/150/150",
[165418] = "1/150/150/150",
[165739] = "1/95/110/125",
[167977] = {[294841] = "1/165/170/175", [294842] = "1/170/172/175", [294843] = "1/175/175/175"},
[167979] = {[294832] = "1/165/170/175", [294833] = "1/170/172/175", [294834] = "1/175/175/175"},
[167981] = {[294844] = "1/165/170/175", [294845] = "1/170/172/175", [294846] = "1/175/175/175"},
[167983] = {[294829] = "1/165/170/175", [294830] = "1/170/172/175", [294831] = "1/175/175/175"},
[167985] = {[294835] = "1/165/170/175", [294836] = "1/170/172/175", [294837] = "1/175/175/175"},
[167987] = {[294838] = "1/165/170/175", [294839] = "1/170/172/175", [294840] = "1/175/175/175"},
[168427] = "1/165/170/175",
[168728] = "1/175/175/175",
[168729] = "1/175/175/175",
[168730] = "1/175/175/175",
[168731] = "1/175/175/175",
[168732] = "1/175/175/175",
[168733] = "1/175/175/175",
[169456] = "1/150/162/175",
[170320] = {[304565] = "1/165/170/175", [304566] = "1/165/170/175", [304567] = "1/165/170/175"},
[170323] = {[304580] = "1/165/170/175", [304581] = "1/165/170/175", [304582] = "1/165/170/175"},
[170324] = {[304577] = "1/165/170/175", [304578] = "1/165/170/175", [304579] = "1/165/170/175"},
[170325] = {[304574] = "1/165/170/175", [304575] = "1/165/170/175", [304576] = "1/165/170/175"},
[170327] = {[304568] = "1/165/170/175", [304569] = "1/165/170/175", [304570] = "1/165/170/175"},
[170340] = {[304571] = "1/165/170/175", [304572] = "1/165/170/175", [304573] = "1/165/170/175"},
[170456] = "1/175/175/175",
[170457] = "1/175/175/175",
[170458] = "1/175/175/175",
[170459] = "1/175/175/175",
[170460] = "1/175/175/175",
[170461] = "1/175/175/175",
[171320] = "1/200/200/200",
[173191] = "1/55/65/75",
[173192] = "1/10/15/20",
[173193] = "1/40/45/50",
[173194] = "1/30/35/40",
[173195] = "1/10/15/20",
[173196] = "1/25/30/35",
[173197] = "1/35/40/45",
[173198] = "1/45/50/55",
[173199] = "1/50/55/60",
[173200] = "1/20/25/30",
[173201] = "1/10/15/20",
[173214] = "1/90/95/100",
[173215] = "1/80/85/90",
[173216] = "1/65/70/75",
[173217] = "1/75/80/85",
[173218] = "1/85/90/95",
[173219] = "1/100/100/100",
[173220] = "1/100/100/100",
[173221] = "1/70/75/80",
[173222] = "1/60/65/70",
[173241] = {[310879] = "1/100/100/100", [332031] = "1/100/100/100", [332066] = "1/100/100/100", [338996] = "1/100/100/100"},
[173242] = {[310880] = "1/100/100/100", [332032] = "1/100/100/100", [332067] = "1/100/100/100", [338995] = "1/100/100/100"},
[173243] = {[310878] = "1/100/100/100", [332030] = "1/100/100/100", [332065] = "1/100/100/100", [338997] = "1/100/100/100"},
[173244] = {[310881] = "1/100/100/100", [332033] = "1/100/100/100", [332068] = "1/100/100/100", [338998] = "1/100/100/100"},
[173245] = {[310882] = "1/100/100/100", [332034] = "1/100/100/100", [332069] = "1/100/100/100", [339000] = "1/100/100/100"},
[173246] = {[310883] = "1/100/100/100", [332035] = "1/100/100/100", [332070] = "1/100/100/100", [339001] = "1/100/100/100"},
[173247] = {[310884] = "1/100/100/100", [332036] = "1/100/100/100", [332071] = "1/100/100/100", [339002] = "1/100/100/100"},
[173248] = {[310885] = "1/100/100/100", [332037] = "1/100/100/100", [332072] = "1/100/100/100", [339003] = "1/100/100/100"},
[173249] = {[310886] = "1/100/100/100", [332038] = "1/100/100/100", [332073] = "1/100/100/100", [339004] = "1/100/100/100"},
[173381] = "1/55/60/65",
[173382] = "1/75/80/85",
[173383] = "1/90/92/95",
[173384] = "1/100/105/110",
[180055] = {[330222] = "1/1/10/20", [330227] = "1/1/10/20", [330232] = "1/1/10/20", [330237] = "1/1/10/20", [330242] = "1/1/10/20", [330247] = "1/1/10/20", [330252] = "1/1/10/20", [330257] = "1/1/10/20"},
[180057] = {[330223] = "1/1/10/20", [330228] = "1/1/10/20", [330233] = "1/1/10/20", [330238] = "1/1/10/20", [330243] = "1/1/10/20", [330248] = "1/1/10/20", [330253] = "1/1/10/20", [330258] = "1/1/10/20"},
[180058] = {[330224] = "1/1/10/20", [330229] = "1/1/10/20", [330234] = "1/1/10/20", [330239] = "1/1/10/20", [330244] = "1/1/10/20", [330249] = "1/1/10/20", [330254] = "1/1/10/20", [330259] = "1/1/10/20"},
[180059] = {[330225] = "1/1/10/20", [330230] = "1/1/10/20", [330235] = "1/1/10/20", [330240] = "1/1/10/20", [330245] = "1/1/10/20", [330250] = "1/1/10/20", [330255] = "1/1/10/20", [330260] = "1/1/10/20"},
[180060] = {[330226] = "1/1/10/20", [330231] = "1/1/10/20", [330236] = "1/1/10/20", [330241] = "1/1/10/20", [330246] = "1/1/10/20", [330251] = "1/1/10/20", [330256] = "1/1/10/20", [330261] = "1/1/10/20"},
[180752] = "1/15/20/25",
[183942] = "1/55/60/65",
[184479] = "1/25/32/40",
[184480] = "1/75/80/85",
[185960] = "1/100/100/100",
[186975] = "1/15/20/25",
-- Unknown item created by: Pandaria Patterns (132) - Master's Spellthread (125496)
-- Unknown item created by: Pandaria Patterns (132) - Sanctified Spellthread (125497)
-- Unknown item created by: Kul Tiran Patterns (143) - Resilient Spellthread (279182)
-- Unknown item created by: Kul Tiran Patterns (143) - Discreet Spellthread (279183)
-- Unknown item created by: Kul Tiran Patterns (143) - Feathery Spellthread (279184)
-- Invalid recipe: Shadowlands Patterns (78) - Cloak of Camouflage (338267)
-- Invalid recipe: Shadowlands Patterns (78) - Bolt of Ardensilk Cloth (338269)
-- Invalid recipe: Shadowlands Patterns (78) - Ardensilk Cloth (338270)
-- Invalid recipe: Shadowlands Patterns (78) - Woven Gossamer Tunic (338271)
-- Invalid recipe: Shadowlands Patterns (78) - Bolt of Woven Gossamer (338272)
-- Invalid recipe: Shadowlands Patterns (78) - Gossamer Cloth (338273)
-- Invalid recipe: Shadowlands Patterns (78) - Haunting Hood (338275)
-- Invalid recipe: Shadowlands Patterns (78) - Bolt of Bleakcloth (338276)
-- Invalid recipe: Shadowlands Patterns (78) - Bleakcloth (338277)
-- Invalid recipe: Shadowlands Patterns (78) - Looming Tapestry (338278)
-- Invalid recipe: Shadowlands Patterns (78) - Bolt of Prideweave (338279)
-- Invalid recipe: Shadowlands Patterns (78) - Prideweave Cloth (338280)



-- cooking
[724] = "1/90/110/130",
[733] = "1/115/135/155",
[787] = "1/45/65/85",
[1017] = "1/140/160/180",
[1082] = "1/135/155/175",
[2679] = "1/45/65/85",
[2680] = "10/50/70/90",
[2681] = "1/45/65/85",
[2682] = "1/125/145/165",
[2683] = "75/115/135/155",
[2684] = "50/90/110/130",
[2685] = "1/130/150/170",
[2687] = "80/120/140/160",
[2888] = "1/60/80/100",
[3220] = "1/100/120/140",
[3662] = "1/120/140/160",
[3663] = "1/130/150/170",
[3664] = "1/160/180/200",
[3665] = "1/170/190/210",
[3666] = "1/150/170/190",
[3726] = "1/150/170/190",
[3727] = "1/175/195/215",
[3728] = "150/190/210/230",
[3729] = "175/215/235/255",
[4457] = "175/215/235/255",
[4592] = "1/90/110/130",
[4593] = "1/140/160/180",
[4594] = "1/190/210/230",
[5095] = "1/90/110/130",
[5472] = "10/50/70/90",
[5473] = "1/60/80/100",
[5474] = "1/75/95/115",
[5476] = "50/90/110/130",
[5477] = "1/90/110/130",
[5478] = "1/130/150/170",
[5479] = "1/140/160/180",
[5480] = "1/150/170/190",
[5525] = "50/90/110/130",
[5526] = "1/130/150/170",
[5527] = "125/165/185/205",
[6038] = "1/215/235/255",
[6290] = "1/45/65/85",
[6316] = "1/90/110/130",
[6657] = "1/125/145/165",
[6887] = "225/250/262/275",
[6888] = "1/45/65/85",
[6890] = "1/80/100/120",
[7676] = "1/100/120/140",
[8364] = "1/215/235/255",
[10841] = "1/175/190/205",
[12209] = "1/165/185/205",
[12210] = "1/215/235/255",
[12212] = "1/215/235/255",
[12213] = "1/215/235/255",
[12214] = "1/215/235/255",
[12215] = "1/225/237/250",
[12216] = "1/250/262/275",
[12217] = "1/225/237/250",
[12218] = "1/250/262/275",
[12224] = "1/45/65/85",
[13851] = "1/215/235/255",
[13927] = "1/250/262/275",
[13928] = "240/265/277/290",
[13929] = "1/265/277/290",
[13930] = "1/250/262/275",
[13931] = "250/275/285/295",
[13932] = "250/275/285/295",
[13933] = "1/300/300/300",
[13934] = "1/300/300/300",
[13935] = "1/300/300/300",
[16766] = "1/250/262/275",
[17197] = "1/45/65/85",
[17198] = "1/75/95/115",
[17222] = "200/225/237/250",
[18045] = "1/250/262/275",
[18254] = "1/300/300/300",
[20074] = "1/160/180/200",
[20452] = "1/300/300/300",
[21023] = "1/300/300/300",
[21072] = "1/120/140/160",
[21217] = "1/215/235/255",
[22645] = "1/100/120/140",
[24105] = "1/45/65/85",
[27635] = "1/45/65/85",
[27636] = "1/90/110/130",
[27651] = "1/20/30/40",
[27655] = "1/20/30/40",
[27657] = "1/35/45/55",
[27658] = "1/45/55/65",
[27659] = "1/45/55/65",
[27660] = "1/45/55/65",
[27661] = "1/20/30/40",
[27662] = "1/20/30/40",
[27663] = "1/30/40/50",
[27664] = "1/40/50/60",
[27665] = "1/40/50/60",
[27666] = "1/45/55/65",
[27667] = "1/70/72/75",
[30155] = "1/20/30/40",
[30816] = "1/30/35/40",
[31672] = "1/55/65/75",
[31673] = "1/55/65/75",
[33004] = "1/250/275/300",
[33048] = "1/35/45/55",
[33052] = "1/75/75/75",
[33053] = "1/75/75/75",
[33825] = "1/35/45/55",
[33866] = "1/20/30/40",
[33867] = "1/20/30/40",
[33872] = "1/35/45/55",
[33874] = "1/45/55/65",
[33924] = "1/50/62/75",
[34411] = "1/300/300/300",
[34747] = "1/1/3/5",
[34748] = "1/1/20/40",
[34749] = "1/1/20/40",
[34750] = "1/1/20/40",
[34751] = "1/1/20/40",
[34752] = "1/1/20/40",
[34753] = "1/1/25/50",
[34754] = "1/50/62/75",
[34755] = "1/50/62/75",
[34756] = "1/50/62/75",
[34757] = "1/50/62/75",
[34758] = "1/50/62/75",
[34759] = "1/1/3/5",
[34760] = "1/1/3/5",
[34761] = "1/1/3/5",
[34762] = "1/1/20/40",
[34763] = "1/1/20/40",
[34764] = "1/1/20/40",
[34765] = "1/1/20/40",
[34766] = "1/50/62/75",
[34767] = "1/50/62/75",
[34768] = "1/50/62/75",
[34769] = "1/50/62/75",
[34832] = "1/100/105/110",
[35563] = "250/275/285/295",
[35565] = "250/275/285/295",
[39520] = "1/1/13/25",
[42942] = "1/1/20/40",
[42993] = "1/50/62/75",
[42994] = "1/50/62/75",
[42995] = "1/50/62/75",
[42996] = "1/50/62/75",
[42997] = "1/50/62/75",
[42998] = "1/50/62/75",
[42999] = "1/50/62/75",
[43000] = "1/50/62/75",
[43001] = "1/50/62/75",
[43004] = "1/50/62/75",
[43005] = "1/50/62/75",
[43015] = "1/75/75/75",
[43268] = "1/1/20/40",
[43478] = "1/60/67/75",
[43480] = "1/75/75/75",
[43488] = "1/1/3/5",
[43490] = "1/1/3/5",
[43491] = "1/1/8/15",
[43492] = "1/1/3/5",
[44836] = {[62044] = "1/150/162/175", [66036] = "1/150/162/175"},
[44837] = {[62050] = "1/90/102/115", [66038] = "1/90/102/115"},
[44838] = {[62045] = "1/205/217/230", [66037] = "1/205/217/230"},
[44839] = {[62051] = "1/270/282/295", [66034] = "1/270/282/295"},
[44840] = {[62049] = "1/210/222/235", [66035] = "1/210/222/235"},
[44953] = "1/1/43/85",
[45932] = "1/25/37/50",
[46691] = "1/30/35/40",
[62289] = "1/75/75/75",
[62290] = "1/75/75/75",
[62649] = "1/75/75/75",
[62651] = "1/15/27/40",
[62652] = "1/15/27/40",
[62653] = "1/15/27/40",
[62654] = "1/15/27/40",
[62655] = "1/15/27/40",
[62656] = "1/15/27/40",
[62657] = "1/15/27/40",
[62658] = "1/40/47/55",
[62659] = "1/40/47/55",
[62660] = "1/40/47/55",
[62661] = "1/65/70/75",
[62662] = "1/65/70/75",
[62663] = "1/65/70/75",
[62664] = "1/65/70/75",
[62665] = "1/65/70/75",
[62666] = "1/65/70/75",
[62667] = "1/65/70/75",
[62668] = "1/65/70/75",
[62669] = "1/65/70/75",
[62670] = "1/65/70/75",
[62671] = "1/65/70/75",
[62672] = "1/75/75/75",
[62673] = "1/1/10/20",
[62674] = "1/5/10/15",
[62675] = "1/5/10/15",
[62676] = "1/1/8/15",
[62677] = "1/40/50/60",
[62680] = "1/60/62/65",
[62790] = "1/1/5/10",
[67230] = "40/80/100/120",
[68687] = "1/40/50/60",
[74636] = "1/1/5/10",
[74641] = "1/1/5/10",
[74642] = "1/25/27/30",
[74643] = "1/25/27/30",
[74644] = "1/25/27/30",
[74645] = "1/50/50/50",
[74646] = "1/75/75/75",
[74647] = "1/50/50/50",
[74648] = "1/75/75/75",
[74649] = "1/50/50/50",
[74650] = "1/75/75/75",
[74651] = "1/25/27/30",
[74652] = "1/50/50/50",
[74653] = "1/75/75/75",
[74654] = "1/25/27/30",
[74655] = "1/50/50/50",
[74656] = "1/75/75/75",
[74919] = "1/75/75/75",
[75016] = "1/75/75/75",
[75026] = "1/25/27/30",
[75037] = "1/50/50/50",
[75038] = "1/75/75/75",
[81400] = "1/1/5/10",
[81401] = "1/1/5/10",
[81402] = "1/1/5/10",
[81403] = "1/1/5/10",
[81404] = "1/1/5/10",
[81405] = "1/1/5/10",
[81406] = "1/1/5/10",
[81408] = "1/1/5/10",
[81409] = "1/1/5/10",
[81410] = "1/1/5/10",
[81411] = "1/1/5/10",
[81412] = "1/1/5/10",
[81413] = "1/1/5/10",
[81414] = "1/1/5/10",
[85501] = "1/5/15/25",
[85504] = "1/5/15/25",
[86026] = "1/1/5/10",
[86057] = "1/1/5/10",
[86069] = "1/5/15/25",
[86070] = "1/1/5/10",
[86073] = "1/75/75/75",
[86074] = "1/75/75/75",
[86432] = "1/75/75/75",
[87226] = "1/75/75/75",
[87228] = "1/75/75/75",
[87230] = "1/75/75/75",
[87232] = "1/75/75/75",
[87234] = "1/75/75/75",
[87236] = "1/75/75/75",
[87238] = "1/75/75/75",
[87240] = "1/75/75/75",
[87242] = "1/75/75/75",
[87244] = "1/75/75/75",
[87246] = "1/75/75/75",
[87248] = "1/75/75/75",
[87264] = "1/75/75/75",
[101630] = "1/75/75/75",
[101661] = "1/75/75/75",
[101662] = "1/75/75/75",
[101745] = "1/75/75/75",
[101746] = "1/75/75/75",
[101747] = "1/75/75/75",
[101748] = "1/75/75/75",
[101749] = "1/75/75/75",
[101750] = "1/75/75/75",
[111431] = "1/50/75/100",
[111433] = "1/50/75/100",
[111434] = "1/50/75/100",
[111436] = "1/50/75/100",
[111437] = "1/50/75/100",
[111438] = "1/50/75/100",
[111439] = "1/50/75/100",
[111441] = "1/50/75/100",
[111442] = "1/50/75/100",
[111444] = "1/50/75/100",
[111445] = "1/50/75/100",
[111446] = "1/50/75/100",
[111447] = "1/75/87/100",
[111449] = "1/75/87/100",
[111450] = "1/75/87/100",
[111452] = "1/75/87/100",
[111453] = "1/75/87/100",
[111454] = "1/75/87/100",
[111455] = "1/1/25/50",
[111456] = "1/1/25/50",
[111457] = "1/100/100/100",
[111458] = "1/100/100/100",
[122343] = "1/1/8/15",
[122344] = "1/1/8/15",
[122345] = "1/1/8/15",
[122346] = "1/1/8/15",
[122347] = "1/1/8/15",
[122348] = "1/1/8/15",
[126934] = "1/50/75/100",
[126935] = "1/245/265/285",
[126936] = "1/125/150/175",
[128498] = "1/1/8/15",
[133557] = {[201413] = "1/20/30/40", [201524] = "1/40/50/60", [201544] = "1/60/70/80"},
[133561] = {[201496] = "1/20/30/40", [201525] = "1/40/50/60", [201545] = "1/60/70/80"},
[133562] = {[201497] = "1/20/30/40", [201526] = "1/40/50/60", [201546] = "1/60/70/80"},
[133563] = {[201498] = "1/20/30/40", [201527] = "1/40/50/60", [201547] = "1/60/70/80"},
[133564] = {[201499] = "1/20/30/40", [201528] = "1/40/50/60", [201548] = "1/60/70/80"},
[133565] = {[201500] = "1/40/50/60", [201529] = "1/60/70/80", [201549] = "1/80/90/100"},
[133566] = {[201501] = "1/40/50/60", [201530] = "1/60/70/80", [201550] = "1/80/90/100"},
[133567] = {[201502] = "1/40/50/60", [201531] = "1/60/70/80", [201551] = "1/80/90/100"},
[133568] = {[201503] = "1/40/50/60", [201532] = "1/60/70/80", [201552] = "1/80/90/100"},
[133569] = {[201504] = "1/40/50/60", [201533] = "1/60/70/80", [201553] = "1/80/90/100"},
[133570] = {[201505] = "1/60/70/80", [201534] = "1/80/90/100", [201554] = "1/100/100/100"},
[133571] = {[201506] = "1/60/70/80", [201535] = "1/80/90/100", [201555] = "1/100/100/100"},
[133572] = {[201507] = "1/60/70/80", [201536] = "1/80/90/100", [201556] = "1/100/100/100"},
[133573] = {[201508] = "1/60/70/80", [201537] = "1/80/90/100", [201557] = "1/100/100/100"},
[133574] = {[201511] = "1/60/70/80", [201538] = "1/80/90/100", [201558] = "1/100/100/100"},
[133575] = {[201512] = "1/20/30/40", [201539] = "1/40/50/60", [201559] = "1/60/70/80"},
[133576] = {[201513] = "1/20/30/40", [201540] = "1/40/50/60", [201560] = "1/60/70/80"},
[133577] = {[201514] = "1/20/30/40", [201541] = "1/40/50/60", [201561] = "1/60/70/80"},
[133578] = {[201515] = "1/40/50/60", [201542] = "1/60/70/80", [201562] = "1/80/90/100"},
[133579] = {[201516] = "1/60/70/80", [201543] = "1/80/90/100", [201563] = "1/100/100/100"},
[133681] = {[201683] = "1/60/70/80", [201684] = "1/80/90/100", [201685] = "1/100/100/100"},
[142334] = "1/80/90/100",
[152564] = "1/50/70/90",
[154881] = {[259411] = "1/35/67/100", [259412] = "1/50/80/110", [259413] = "1/60/90/120"},
[154882] = {[259414] = "1/90/105/120", [259415] = "1/110/130/150", [259416] = "1/150/150/150"},
[154883] = {[259424] = "1/35/67/100", [259425] = "1/50/80/110", [259426] = "1/60/90/120"},
[154884] = {[259427] = "1/90/105/120", [259428] = "1/110/130/150", [259429] = "1/150/150/150"},
[154885] = {[259442] = "1/35/67/100", [259443] = "1/50/80/110", [259444] = "1/60/90/120"},
[154886] = {[259445] = "1/90/105/120", [259446] = "1/110/130/150", [259447] = "1/150/150/150"},
[154887] = {[259436] = "1/35/67/100", [259437] = "1/50/80/110", [259438] = "1/60/90/120"},
[154888] = {[259439] = "1/90/105/120", [259440] = "1/110/130/150", [259441] = "1/150/150/150"},
[154889] = {[259430] = "1/15/45/75", [259431] = "1/35/67/100", [259432] = "1/50/80/110"},
[154891] = {[259433] = "1/85/102/120", [259434] = "1/110/130/150", [259435] = "1/150/150/150"},
[156525] = {[259418] = "1/110/125/140", [259419] = "1/150/150/150", [259420] = "1/150/150/150"},
[156526] = {[259421] = "1/150/150/150", [259422] = "1/150/150/150", [259423] = "1/150/150/150"},
[163781] = "1/50/75/100",
[165755] = "1/100/117/135",
[166240] = {[287108] = "1/150/150/150", [287110] = "1/150/150/150", [287112] = "1/150/150/150"},
[166343] = {[288027] = "1/35/67/100", [288028] = "1/50/80/110", [288029] = "1/60/90/120"},
[166344] = {[288030] = "1/90/105/120", [288032] = "1/110/130/150", [288033] = "1/150/150/150"},
[166804] = {[290471] = "1/120/125/130", [290472] = "1/125/127/130", [290473] = "1/130/132/135"},
[168310] = {[297078] = "1/165/170/175", [297079] = "1/170/172/175", [297080] = "1/175/175/175"},
[168311] = {[297084] = "1/165/170/175", [297085] = "1/170/172/175", [297086] = "1/175/175/175"},
[168312] = {[297074] = "1/175/175/175", [297075] = "1/170/172/175", [297077] = "1/165/170/175"},
[168313] = {[297081] = "1/165/170/175", [297082] = "1/170/172/175", [297083] = "1/175/175/175"},
[168314] = {[297087] = "1/165/170/175", [297088] = "1/170/172/175", [297089] = "1/175/175/175"},
[168315] = {[297105] = "1/165/170/175", [297106] = "1/170/172/175", [297107] = "1/175/175/175"},
[169280] = "1/175/175/175",
[169449] = "1/165/170/175",
[172040] = "1/30/32/35",
[172041] = "1/70/72/75",
[172042] = "1/75/75/75",
[172043] = "1/75/75/75",
[172044] = "1/40/42/45",
[172045] = "1/60/62/65",
[172046] = "1/20/22/25",
[172047] = "1/50/52/55",
[172048] = "1/35/37/40",
[172049] = "1/65/67/70",
[172050] = "1/30/32/35",
[172051] = "1/60/62/65",
[172061] = "1/75/75/75",
[172062] = "1/75/75/75",
[172063] = "1/75/75/75",
[172068] = "1/20/22/25",
[172069] = "1/50/52/55",
[174348] = "1/165/170/175",
[174349] = "1/165/170/175",
[174350] = "1/165/170/175",
[174351] = "1/165/170/175",
[174352] = "1/165/170/175",
[184624] = "1/125/150/175",
[184682] = "1/10/15/20",
[184690] = "1/15/20/25",
[186704] = "1/75/75/75",
[186725] = "1/50/52/55",
[186726] = "1/30/32/35",
-- Invalid recipe: Shadowlands Cuisine (31) - Arden Apple Pie (338100)
-- Invalid recipe: Shadowlands Cuisine (31) - Oat Pie Crust (338101)
-- Invalid recipe: Shadowlands Cuisine (31) - Sliced Arden Apples (338102)
-- Invalid recipe: Shadowlands Cuisine (31) - Steward Stew (338105)
-- Invalid recipe: Shadowlands Cuisine (31) - Grazer Bone Broth (338106)
-- Invalid recipe: Shadowlands Cuisine (31) - Diced Vegetables (338107)
-- Invalid recipe: Shadowlands Cuisine (31) - Spider Jerky (338110)
-- Invalid recipe: Shadowlands Cuisine (31) - Thick Spider Meat (338113)
-- Invalid recipe: Shadowlands Cuisine (31) - Ember Sauce (338115)
-- Invalid recipe: Shadowlands Cuisine (31) - Skewered Meats (338116)
-- Invalid recipe: Shadowlands Cuisine (31) - Seared Cutlets (338117)
	
	}
end
